@@ -1,4 +1,5 @@
 import * as React from 'react';
+import { useTranslation } from 'react-i18next';
 import * as _ from 'lodash';
 import DashboardCard from '@console/shared/src/components/dashboard/dashboard-card/DashboardCard';
 import DashboardCardBody from '@console/shared/src/components/dashboard/dashboard-card/DashboardCardBody';
@@ -22,7 +23,13 @@ import {
   StorageClassModel,
 } from '@console/internal/models';
 import { ResourceInventoryItem } from '@console/shared/src/components/dashboard/inventory-card/InventoryItem';
-import { getCephNodes, getCephPVs, getCephPVCs, getCephSC } from '../../../selectors';
+import {
+  getCephNodes,
+  getCephPVs,
+  getCephPVCs,
+  getCephSC,
+  cephStorageLabel,
+} from '../../../selectors';
 
 const k8sResources: FirehoseResource[] = [
   {
@@ -52,6 +59,8 @@ const InventoryCard: React.FC<DashboardItemProps> = ({
   stopWatchK8sResource,
   resources,
 }) => {
+  const { t } = useTranslation();
+
   React.useEffect(() => {
     k8sResources.forEach((r) => watchK8sResource(r));
     return () => {
@@ -74,22 +83,25 @@ const InventoryCard: React.FC<DashboardItemProps> = ({
   const scData = _.get(resources.sc, 'data', []) as K8sResourceKind[];
   const filteredCephSC = getCephSC(scData);
   const filteredSCNames = filteredCephSC.map((sc) => _.get(sc, 'metadata.name'));
+  const ocsNodesHref = `/search?kind=${NodeModel.kind}&q=${cephStorageLabel}`;
 
   return (
     <DashboardCard>
       <DashboardCardHeader>
-        <DashboardCardTitle>Inventory</DashboardCardTitle>
+        <DashboardCardTitle>{t('ceph-storage-plugin~Inventory')}</DashboardCardTitle>
       </DashboardCardHeader>
       <DashboardCardBody>
         <ResourceInventoryItem
+          dataTest="inventory-nodes"
           isLoading={!nodesLoaded}
           error={!!nodesLoadError}
           kind={NodeModel}
           resources={getCephNodes(nodesData)}
           mapper={getNodeStatusGroups}
-          showLink={false}
+          basePath={ocsNodesHref}
         />
         <ResourceInventoryItem
+          dataTest="inventory-pvc"
           isLoading={!pvcsLoaded}
           error={!!pvcsLoadError}
           kind={PersistentVolumeClaimModel}
@@ -99,6 +111,7 @@ const InventoryCard: React.FC<DashboardItemProps> = ({
           showLink={false}
         />
         <ResourceInventoryItem
+          dataTest="inventory-pv"
           isLoading={!pvsLoaded}
           error={!!pvsLoadError}
           kind={PersistentVolumeModel}
