@@ -1,4 +1,5 @@
 import * as React from 'react';
+import { useTranslation } from 'react-i18next';
 import * as _ from 'lodash';
 import * as classNames from 'classnames';
 import {
@@ -9,46 +10,24 @@ import {
   hasLabel,
 } from '@console/shared';
 import { useSelectList } from '@console/shared/src/hooks/select-list';
-import { humanizeCpuCores, ResourceLink, pluralize } from '@console/internal/components/utils/';
+import { humanizeCpuCores, ResourceLink } from '@console/internal/components/utils/';
 import { NodeKind } from '@console/internal/module/k8s';
 import { Table } from '@console/internal/components/factory';
-import { IRow } from '@patternfly/react-table';
-import { hasOCSTaint, hasTaints, getConvertedUnits } from '../../utils/install';
+import { IRow, sortable } from '@patternfly/react-table';
+import { getConvertedUnits, nodesWithoutTaints, getZone } from '../../utils/install';
 import { cephStorageLabel } from '../../selectors';
 import { GetRows, NodeTableProps } from './types';
-
 import './ocs-install.scss';
 
 const tableColumnClasses = [
-  classNames('pf-u-w-50-on-sm'),
-  classNames('pf-m-hidden', 'pf-m-visible-on-sm', 'pf-u-w-10-on-sm'),
-  classNames('pf-m-hidden', 'pf-m-visible-on-sm', 'pf-u-w-10-on-sm'),
-  classNames('pf-m-hidden', 'pf-m-visible-on-sm', 'pf-u-w-10-on-sm'),
-  classNames('pf-m-hidden', 'pf-m-visible-on-sm', 'pf-u-w-10-on-sm'),
+  classNames('pf-u-w-33-on-md', 'pf-u-w-50-on-sm'),
+  classNames('pf-m-hidden', 'pf-m-visible-on-lg', 'pf-u-w-inherit-on-lg'),
+  classNames('pf-m-hidden', 'pf-m-visible-on-lg', 'pf-u-w-inherit-on-lg'),
+  classNames('pf-m-hidden', 'pf-m-visible-on-md', 'pf-u-w-inherit-on-md'),
+  classNames('pf-u-w-inherit'),
 ];
 
-export const getColumns = () => [
-  {
-    title: 'Name',
-    props: { className: tableColumnClasses[0] },
-  },
-  {
-    title: 'Role',
-    props: { className: tableColumnClasses[1] },
-  },
-  {
-    title: 'Zone',
-    props: { className: tableColumnClasses[2] },
-  },
-  {
-    title: 'CPU',
-    props: { className: tableColumnClasses[3] },
-  },
-  {
-    title: 'Memory',
-    props: { className: tableColumnClasses[4] },
-  },
-];
+// Same columns are used for attached devices mode tables
 
 const getRows: GetRows = (
   { componentProps },
@@ -59,7 +38,7 @@ const getRows: GetRows = (
 ) => {
   const { data } = componentProps;
 
-  const filteredData = data.filter((node: NodeKind) => hasOCSTaint(node) || !hasTaints(node));
+  const filteredData = nodesWithoutTaints(data);
 
   const rows = filteredData.map((node: NodeKind) => {
     const roles = getNodeRoles(node).sort();
@@ -72,15 +51,15 @@ const getRows: GetRows = (
       {
         title: roles.join(', ') ?? '-',
       },
-      {
-        title: node.metadata.labels?.['failure-domain.beta.kubernetes.io/zone'] ?? '-',
-      },
       {
         title: `${humanizeCpuCores(cpuSpec).string || '-'}`,
       },
       {
         title: `${getConvertedUnits(memSpec)}`,
       },
+      {
+        title: getZone(node) || '-',
+      },
     ];
     return {
       cells,
@@ -106,35 +85,56 @@ const getRows: GetRows = (
   return rows;
 };
 
-const NodeTable: React.FC<NodeTableProps> = (props) => {
-  const [visibleRows, setVisibleRows] = React.useState<Set<string>>();
+const InternalNodeTable: React.FC<NodeTableProps> = (props) => {
+  const { t } = useTranslation();
 
+  const [visibleRows, setVisibleRows] = React.useState<Set<string>>(props.customData.nodes);
   const {
     onSelect,
     selectedRows: selectedNodes,
     updateSelectedRows: setSelectedNodes,
   } = useSelectList<NodeKind>(props.data, visibleRows, props.customData.onRowSelected);
 
+  const getColumns = () => [
+    {
+      title: t('ceph-storage-plugin~Name'),
+      sortField: 'metadata.name',
+      transforms: [sortable],
+      props: { className: tableColumnClasses[0] },
+    },
+    {
+      title: t('ceph-storage-plugin~Role'),
+      props: { className: tableColumnClasses[1] },
+    },
+    {
+      title: t('ceph-storage-plugin~CPU'),
+      props: { className: tableColumnClasses[2] },
+    },
+    {
+      title: t('ceph-storage-plugin~Memory'),
+      props: { className: tableColumnClasses[3] },
+    },
+    {
+      title: t('ceph-storage-plugin~Zone'),
+      props: { className: tableColumnClasses[4] },
+    },
+  ];
+
   return (
-    <>
-      <div className="ceph-node-list__max-height ceph-ocs-install__node-list">
-        <Table
-          aria-label="Node Table"
-          data-test-id="select-nodes-table"
-          {...props}
-          Rows={(rowProps) =>
-            getRows(rowProps, visibleRows, setVisibleRows, selectedNodes, setSelectedNodes)
-          }
-          Header={getColumns}
-          virtualize={false}
-          onSelect={onSelect}
-        />
-      </div>
-      <p className="control-label help-block" data-test-id="nodes-selected">
-        {pluralize(selectedNodes?.size, 'node')} selected
-      </p>
-    </>
+    <div className="ceph-ocs-install__select-nodes-table">
+      <Table
+        aria-label={t('ceph-storage-plugin~Node Table')}
+        data-test-id="select-nodes-table"
+        {...props}
+        Rows={(rowProps) =>
+          getRows(rowProps, visibleRows, setVisibleRows, selectedNodes, setSelectedNodes)
+        }
+        Header={getColumns}
+        virtualize={false}
+        onSelect={onSelect}
+      />
+    </div>
   );
 };
 
-export default NodeTable;
+export default InternalNodeTable;
