@@ -1,15 +1,16 @@
 import * as React from 'react';
 import * as _ from 'lodash';
+import { useTranslation } from 'react-i18next';
 import { useFormikContext, FormikValues } from 'formik';
 import { ResourceName } from '@console/internal/components/utils';
 import { K8sResourceKind } from '@console/internal/module/k8s';
 import { ImageStreamTagModel } from '@console/internal/models';
+import { DropdownField } from '@console/shared';
 import {
   BuilderImage,
   getTagDataWithDisplayName,
   getPorts,
 } from '../../../utils/imagestream-utils';
-import { DropdownField } from '../../formik-fields';
 import { useSafeK8s } from '../../../utils/safe-k8s-hook';
 import ImageStreamInfo from './ImageStreamInfo';
 
@@ -22,6 +23,7 @@ const BuilderImageTagSelector: React.FC<BuilderImageTagSelectorProps> = ({
   selectedBuilderImage,
   selectedImageTag,
 }) => {
+  const { t } = useTranslation();
   const { setFieldValue, setFieldError } = useFormikContext<FormikValues>();
   const {
     name: imageName,
@@ -60,7 +62,7 @@ const BuilderImageTagSelector: React.FC<BuilderImageTagSelectorProps> = ({
     <>
       <DropdownField
         name="image.tag"
-        label="Builder Image Version"
+        label={t('devconsole~Builder Image version')}
         items={tagItems}
         title={tagItems[selectedImageTag]}
         fullWidth
