@@ -499,47 +499,54 @@ export const createDevfileResources = async (
     };
   }, {} as DevfileSuggestedResources);
 
-  return Promise.all([
-    createOrUpdateImageStream(
-      formData,
-      devfileResourceObjects.imageStream,
-      dryRun,
-      appResources,
-      verb,
-      generatedImageStreamName,
-    ),
+  const imageStreamResponse = await createOrUpdateImageStream(
+    formData,
+    devfileResourceObjects.imageStream,
+    dryRun,
+    appResources,
+    verb,
+    generatedImageStreamName,
+  );
 
-    createOrUpdateBuildConfig(
-      formData,
-      devfileResourceObjects.imageStream,
-      dryRun,
-      devfileResourceObjects.buildResource,
-      verb,
-      generatedImageStreamName,
-    ),
+  const buildConfigResponse = await createOrUpdateBuildConfig(
+    formData,
+    devfileResourceObjects.imageStream,
+    dryRun,
+    devfileResourceObjects.buildResource,
+    verb,
+    generatedImageStreamName,
+  );
 
-    createWebhookSecret(formData, 'generic', dryRun),
+  const webhookSecretResponse = await createWebhookSecret(formData, 'generic', dryRun);
 
-    createOrUpdateDeployment(
-      formData,
-      devfileResourceObjects.imageStream,
-      dryRun,
-      devfileResourceObjects.deployResource,
-      verb,
-    ),
+  const deploymentResponse = await createOrUpdateDeployment(
+    formData,
+    devfileResourceObjects.imageStream,
+    dryRun,
+    devfileResourceObjects.deployResource,
+    verb,
+  );
 
-    k8sCreate(
-      ServiceModel,
-      createService(formData, devfileResourceObjects.imageStream, devfileResourceObjects.service),
-      dryRun ? dryRunOpt : {},
-    ),
+  const serviceModelResponse = await k8sCreate(
+    ServiceModel,
+    createService(formData, devfileResourceObjects.imageStream, devfileResourceObjects.service),
+    dryRun ? dryRunOpt : {},
+  );
 
-    k8sCreate(
-      RouteModel,
-      createRoute(formData, devfileResourceObjects.imageStream, devfileResourceObjects.route),
-      dryRun ? dryRunOpt : {},
-    ),
-  ]);
+  const routeResponse = await k8sCreate(
+    RouteModel,
+    createRoute(formData, devfileResourceObjects.imageStream, devfileResourceObjects.route),
+    dryRun ? dryRunOpt : {},
+  );
+
+  return [
+    imageStreamResponse,
+    buildConfigResponse,
+    webhookSecretResponse,
+    deploymentResponse,
+    serviceModelResponse,
+    routeResponse,
+  ];
 };
 
 export const createOrUpdateResources = async (
@@ -571,7 +578,7 @@ export const createOrUpdateResources = async (
 
   createNewProject && (await createProject(formData.project));
 
-  const requests: Promise<K8sResourceKind>[] = [];
+  const responses: K8sResourceKind[] = [];
   let generatedImageStreamName: string = '';
   const imageStreamList = appResources?.imageStream?.data;
   if (
@@ -590,23 +597,23 @@ export const createOrUpdateResources = async (
     return createDevfileResources(formData, dryRun, appResources, generatedImageStreamName);
   }
 
-  requests.push(
-    createOrUpdateImageStream(
-      formData,
-      imageStream,
-      dryRun,
-      appResources,
-      generatedImageStreamName ? 'create' : verb,
-      generatedImageStreamName,
-    ),
+  const imageStreamResponse = await createOrUpdateImageStream(
+    formData,
+    imageStream,
+    dryRun,
+    appResources,
+    generatedImageStreamName ? 'create' : verb,
+    generatedImageStreamName,
   );
+  responses.push(imageStreamResponse);
+
   if (pipeline.enabled) {
     if (!dryRun) {
       await managePipelineResources(formData, appResources);
     }
   } else {
-    requests.push(
-      createOrUpdateBuildConfig(
+    responses.push(
+      await createOrUpdateBuildConfig(
         formData,
         imageStream,
         dryRun,
@@ -617,16 +624,17 @@ export const createOrUpdateResources = async (
     );
   }
 
-  verb === 'create' && requests.push(createWebhookSecret(formData, 'generic', dryRun));
+  if (verb === 'create') {
+    responses.push(await createWebhookSecret(formData, 'generic', dryRun));
+  }
 
   const defaultAnnotations = getGitAnnotations(repository, ref);
 
   if (formData.resources === Resources.KnativeService) {
     // knative service doesn't have dry run capability so returning the promises.
     if (dryRun) {
-      return Promise.all(requests);
+      return responses;
     }
-    const [imageStreamResponse] = await Promise.all(requests);
     const imageStreamURL = imageStreamResponse.status.dockerImageRepository;
 
     const originalAnnotations = appResources?.editAppResource?.data?.metadata?.annotations || {};
@@ -658,8 +666,8 @@ export const createOrUpdateResources = async (
   }
 
   if (formData.resources === Resources.Kubernetes) {
-    requests.push(
-      createOrUpdateDeployment(
+    responses.push(
+      await createOrUpdateDeployment(
         formData,
         imageStream,
         dryRun,
@@ -668,8 +676,8 @@ export const createOrUpdateResources = async (
       ),
     );
   } else if (formData.resources === Resources.OpenShift) {
-    requests.push(
-      createOrUpdateDeploymentConfig(
+    responses.push(
+      await createOrUpdateDeploymentConfig(
         formData,
         imageStream,
         dryRun,
@@ -682,27 +690,27 @@ export const createOrUpdateResources = async (
   if (!_.isEmpty(ports) || buildStrategy === 'Docker' || buildStrategy === 'Source') {
     const originalService = _.get(appResources, 'service.data');
     const service = createService(formData, imageStream, originalService);
-    const request =
-      verb === 'update'
-        ? !_.isEmpty(originalService)
-          ? k8sUpdate(ServiceModel, service)
-          : null
-        : k8sCreate(ServiceModel, service, dryRun ? dryRunOpt : {});
-    requests.push(request);
+
+    if (verb === 'create') {
+      responses.push(await k8sCreate(ServiceModel, service, dryRun ? dryRunOpt : {}));
+    } else if (verb === 'update' && !_.isEmpty(originalService)) {
+      responses.push(await k8sUpdate(ServiceModel, service));
+    }
+
     const originalRoute = _.get(appResources, 'route.data');
     const route = createRoute(formData, imageStream, originalRoute);
     if (verb === 'update' && disable) {
-      requests.push(k8sUpdate(RouteModel, route, namespace, name));
+      responses.push(await k8sUpdate(RouteModel, route, namespace, name));
     } else if (canCreateRoute) {
-      requests.push(k8sCreate(RouteModel, route, dryRun ? dryRunOpt : {}));
+      responses.push(await k8sCreate(RouteModel, route, dryRun ? dryRunOpt : {}));
     }
   }
 
   if (webhookTrigger && verb === 'create') {
-    requests.push(createWebhookSecret(formData, gitType, dryRun));
+    responses.push(await createWebhookSecret(formData, gitType, dryRun));
   }
 
-  return Promise.all(requests);
+  return responses;
 };
 
 export const handleRedirect = (
