@@ -1,5 +1,6 @@
 import * as React from 'react';
 import * as _ from 'lodash';
+import { useTranslation } from 'react-i18next';
 import { match as RMatch } from 'react-router-dom';
 import { connect } from 'react-redux';
 import { Helmet } from 'react-helmet';
@@ -7,8 +8,8 @@ import Dashboard from '@console/shared/src/components/dashboard/Dashboard';
 import { RootState } from '@console/internal/redux';
 import {
   getURLSearchParams,
-  setQueryArgument,
-  removeQueryArgument,
+  setQueryArguments,
+  removeQueryArguments,
 } from '@console/internal/components/utils';
 import {
   TimespanDropdown,
@@ -37,65 +38,31 @@ type StateProps = {
 type Props = MonitoringDashboardProps & StateProps;
 
 export const MonitoringDashboard: React.FC<Props> = ({ match, timespan, pollInterval }) => {
+  const { t } = useTranslation();
   const namespace = match.params.ns;
   const params = getURLSearchParams();
   const [workloadName, setWorkloadName] = React.useState(
     params.workloadName || OptionTypes.selectAll,
   );
   const [workloadType, setWorkloadType] = React.useState(params.workloadType);
-  const [initialRun, setInitialRun] = React.useState(true);
-  const selectedTaskRef = React.useRef<string>(workloadName);
-  selectedTaskRef.current = workloadName;
 
-  const getQueries = React.useCallback(() => {
+  const queries = React.useMemo(() => {
     return workloadName && workloadType && workloadName !== OptionTypes.selectAll
-      ? [...topWorkloadMetricsQueries, ...workloadMetricsQueries]
-      : monitoringDashboardQueries;
-  }, [workloadName, workloadType]);
-
-  const [queries, setQueries] = React.useState(getQueries());
-
-  const removeQueryParams = React.useCallback(() => {
-    if (!initialRun) {
-      removeQueryArgument('workloadName');
-      removeQueryArgument('workloadType');
-      setWorkloadType(null);
-      setWorkloadName(OptionTypes.selectAll);
-      setQueries(getQueries());
-    }
-  }, [getQueries, initialRun]);
-
-  React.useEffect(
-    () => {
-      setQueries(getQueries());
-      if (workloadName !== OptionTypes.selectAll && workloadType) {
-        setQueryArgument('workloadName', workloadName);
-        setQueryArgument('workloadType', workloadType);
-      } else if (
-        workloadName === OptionTypes.selectAll &&
-        !initialRun &&
-        !_.isEmpty(getURLSearchParams())
-      ) {
-        removeQueryParams();
-      }
-    }, // eslint-disable-next-line react-hooks/exhaustive-deps
-    [workloadName, workloadType, getQueries, namespace],
-  );
-
-  React.useEffect(
-    () => {
-      initialRun ? setInitialRun(false) : removeQueryParams();
-    },
-    // eslint-disable-next-line react-hooks/exhaustive-deps
-    [namespace],
-  );
+      ? [...topWorkloadMetricsQueries(t), ...workloadMetricsQueries(t)]
+      : monitoringDashboardQueries(t);
+  }, [t, workloadName, workloadType]);
 
   const onSelect = React.useCallback(
     (key: string, type: string = null): void => {
-      if (selectedTaskRef.current !== key) {
-        selectedTaskRef.current = key;
-        setWorkloadName(key);
-        setWorkloadType(type);
+      setWorkloadName(key);
+      setWorkloadType(type);
+      if (key && type && key !== OptionTypes.selectAll) {
+        setQueryArguments({
+          workloadName: key,
+          workloadType: type,
+        });
+      } else {
+        removeQueryArguments('workloadName', 'workloadType');
       }
     },
     [setWorkloadType, setWorkloadName],
@@ -104,21 +71,26 @@ export const MonitoringDashboard: React.FC<Props> = ({ match, timespan, pollInte
   return (
     <>
       <Helmet>
-        <title>Dashboard</title>
+        <title>{t('devconsole~Dashboard')}</title>
       </Helmet>
       <div className="odc-monitoring-dashboard">
-        <div className="odc-monitoring-dashboard__dropdown-options">
-          <TimespanDropdown />
-          <PollIntervalDropdown />
-        </div>
-        <div className="row odc-monitoring-dashboard__resource-toolbar">
-          <div className="col-lg-3 col-md-3 col-sm-4 col-xs-6">
+        <div className="odc-monitoring-dashboard__resource-toolbar">
+          <div className="odc-monitoring-dashboard__workload">
+            <label htmlFor="odc-monitoring-dashboard-workload-filter">
+              {t('devconsole~Workload')}
+            </label>
             <MonitoringWorkloadFilter
               name={workloadName}
               namespace={namespace}
               onChange={onSelect}
             />
           </div>
+          <div className="odc-monitoring-dashboard__dropdown-options">
+            <div className="odc-monitoring-dashboard__dropdown-time-interval">
+              <TimespanDropdown />
+              <PollIntervalDropdown />
+            </div>
+          </div>
         </div>
         <Dashboard>
           {_.map(queries, (q) => (
