@@ -14,6 +14,16 @@ describe('Gitlab Service', () => {
 
     const gitService = new GitlabService(gitSource);
 
+    const metaData = gitService.getRepoMetadata();
+    expect(metaData).toEqual({
+      repoName: 'devconsole-git',
+      owner: 'jpratik999',
+      host: 'https://gitlab.com',
+      defaultBranch: 'master',
+      fullName: 'jpratik999/devconsole-git',
+      contextDir: '',
+    });
+
     return nockBack('repo.json').then(async ({ nockDone, context }) => {
       const isReachable = await gitService.isRepoReachable();
       expect(isReachable).toEqual(true);
@@ -27,6 +37,16 @@ describe('Gitlab Service', () => {
 
     const gitService = new GitlabService(gitSource);
 
+    const metaData = gitService.getRepoMetadata();
+    expect(metaData).toEqual({
+      repoName: 'devconsole-git',
+      owner: 'jpratik99',
+      host: 'https://gitlab.com',
+      defaultBranch: 'master',
+      fullName: 'jpratik99/devconsole-git',
+      contextDir: '',
+    });
+
     return nockBack('repo-not-reachable.json').then(async ({ nockDone, context }) => {
       const isReachable = await gitService.isRepoReachable();
       expect(isReachable).toEqual(false);
@@ -35,6 +55,29 @@ describe('Gitlab Service', () => {
     });
   });
 
+  it('should return ok on public custom domain with subdomain', async () => {
+    const gitSource: GitSource = { url: 'https://version.helsinki.fi/random-user/public-project' };
+
+    const gitService = new GitlabService(gitSource);
+
+    const metaData = gitService.getRepoMetadata();
+    expect(metaData).toEqual({
+      repoName: 'public-project',
+      owner: 'random-user',
+      host: 'https://version.helsinki.fi',
+      defaultBranch: 'master',
+      fullName: 'random-user/public-project',
+      contextDir: '',
+    });
+
+    return nockBack('custom-domain-with-subdomain.json').then(async ({ nockDone, context }) => {
+      const isReachable = await gitService.isRepoReachable();
+      expect(isReachable).toEqual(true);
+      context.assertScopesFinished();
+      nockDone();
+    });
+  });
+
   it('should list all branches of existing public gitlab repo', () => {
     const gitSource: GitSource = { url: 'https://gitlab.com/jpratik999/devconsole-git.git' };
 
@@ -74,6 +117,23 @@ describe('Gitlab Service', () => {
     });
   });
 
+  it('should detect DotNet build type inside context directory', () => {
+    const gitSource: GitSource = {
+      url: 'https://gitlab.com/rottencandy/s2i-dotnetcore-ex',
+      contextDir: 'app',
+    };
+
+    const gitService = new GitlabService(gitSource);
+
+    return nockBack('files-dotnet.json').then(async ({ nockDone, context }) => {
+      const buildTypes: BuildType[] = await gitService.detectBuildTypes();
+      expect(buildTypes.length).toBeGreaterThanOrEqual(1);
+      expect(buildTypes[0].buildType).toBe('dotnet');
+      context.assertScopesFinished();
+      nockDone();
+    });
+  });
+
   it('should detect Golang language', () => {
     const gitSource: GitSource = { url: 'https://gitlab.com/jpratik999/devconsole-git.git' };
 
@@ -129,4 +189,30 @@ describe('Gitlab Service', () => {
       nockDone();
     });
   });
+
+  it('should detect Devfile', () => {
+    const gitSource = { url: 'https://gitlab.com/aballant/nodejs-starter-devfile' };
+
+    const gitService = new GitlabService(gitSource);
+
+    return nockBack('devfile.json').then(async ({ nockDone, context }) => {
+      const isDevfilePresent = await gitService.isDevfilePresent();
+      expect(isDevfilePresent).toBe(true);
+      context.assertScopesFinished();
+      nockDone();
+    });
+  });
+
+  it('should not detect Devfile', () => {
+    const gitSource: GitSource = { url: 'https://gitlab.com/jpratik999/devconsole-git.git' };
+
+    const gitService = new GitlabService(gitSource);
+
+    return nockBack('no-devfile.json').then(async ({ nockDone, context }) => {
+      const isDevfilePresent = await gitService.isDevfilePresent();
+      expect(isDevfilePresent).toBe(false);
+      context.assertScopesFinished();
+      nockDone();
+    });
+  });
 });
