@@ -1,4 +1,5 @@
 import * as React from 'react';
+import { useTranslation } from 'react-i18next';
 import { PodControllerOverviewItem } from '@console/shared';
 import { ResourceLink, SidebarSectionHeading } from '@console/internal/components/utils';
 
@@ -7,12 +8,13 @@ type DeploymentOverviewListProps = {
 };
 
 const DeploymentOverviewList: React.FC<DeploymentOverviewListProps> = ({ current }) => {
+  const { t } = useTranslation();
   const { obj } = current || {};
   const namespace = obj?.metadata?.namespace;
   const deploymentData = obj?.metadata?.ownerReferences[0];
   return (
     <>
-      <SidebarSectionHeading text="Deployment" />
+      <SidebarSectionHeading text={t('knative-plugin~Deployment')} />
       {deploymentData && deploymentData.name ? (
         <ul className="list-group">
           <li className="list-group-item">
@@ -24,7 +26,9 @@ const DeploymentOverviewList: React.FC<DeploymentOverviewListProps> = ({ current
           </li>
         </ul>
       ) : (
-        <span className="text-muted">No Deployment found for this resource.</span>
+        <span className="text-muted">
+          {t('knative-plugin~No Deployment found for this resource.')}
+        </span>
       )}
     </>
   );
