@@ -1,6 +1,5 @@
 import * as React from 'react';
 import { shallow } from 'enzyme';
-import { MockKnativeResources } from '@console/dev-console/src/components/topology/__tests__/topology-knative-test-data';
 import OperatorBackedOwnerReferences from '@console/internal/components/utils';
 import * as fetchDynamicEventSources from '../../../utils/fetch-dynamic-eventsources-utils';
 import OverviewDetailsKnativeResourcesTab from '../OverviewDetailsKnativeResourcesTab';
@@ -9,7 +8,17 @@ import KnativeRevisionResources from '../KnativeRevisionResources';
 import RevisionsOverviewList from '../RevisionsOverviewList';
 import KSRoutesOverviewList from '../RoutesOverviewList';
 import ConfigurationsOverviewList from '../ConfigurationsOverviewList';
-import EventSinkServicesOverviewList from '../EventSinkServicesOverviewList';
+import EventSourceResources from '../EventSourceResources';
+import EventPubSubResources from '../EventPubSubResources';
+import {
+  MockKnativeResources,
+  getEventSourceResponse,
+  sampleEventSourceSinkbinding,
+  sampleSourceKameletBinding,
+  EventIMCObj,
+  EventSubscriptionObj,
+} from '../../../topology/__tests__/topology-knative-test-data';
+import { EventSourceCronJobModel } from '../../../models';
 
 type OverviewDetailsKnativeResourcesTabProps = React.ComponentProps<
   typeof OverviewDetailsKnativeResourcesTab
@@ -25,9 +34,6 @@ describe('OverviewDetailsKnativeResourcesTab', () => {
         revisions: MockKnativeResources.revisions.data,
         ksservices: MockKnativeResources.ksservices.data,
         ksroutes: MockKnativeResources.ksroutes.data,
-        buildConfigs: [],
-        routes: [],
-        services: [],
         isOperatorBackedService: false,
       },
     };
@@ -43,28 +49,28 @@ describe('OverviewDetailsKnativeResourcesTab', () => {
     expect(wrapper.find(KnativeRevisionResources)).toHaveLength(1);
   });
 
-  it('should render EventSinkServicesOverviewList on sidebar', () => {
+  it('should render EventSourceResources on sidebar', () => {
     jest
       .spyOn(fetchDynamicEventSources, 'isDynamicEventResourceKind')
       .mockImplementationOnce(() => true);
     knItem.item = {
       ...knItem.item,
-      ...{ obj: MockKnativeResources.eventSourceContainers.data[0] },
+      ...{ obj: getEventSourceResponse(EventSourceCronJobModel).data[0] },
     };
     const wrapper = shallow(<OverviewDetailsKnativeResourcesTab {...knItem} />);
-    expect(wrapper.find(EventSinkServicesOverviewList)).toHaveLength(1);
+    expect(wrapper.find(EventSourceResources)).toHaveLength(1);
   });
 
-  it('should render EventSinkServicesOverviewList on sidebar for sinkBinding', () => {
+  it('should render EventSourceResources on sidebar for sinkBinding', () => {
     jest
       .spyOn(fetchDynamicEventSources, 'isDynamicEventResourceKind')
       .mockImplementationOnce(() => true);
     knItem.item = {
       ...knItem.item,
-      ...{ obj: MockKnativeResources.eventSourceSinkbinding.data[0] },
+      ...{ obj: sampleEventSourceSinkbinding.data[0] },
     };
     const wrapper = shallow(<OverviewDetailsKnativeResourcesTab {...knItem} />);
-    expect(wrapper.find(EventSinkServicesOverviewList)).toHaveLength(1);
+    expect(wrapper.find(EventSourceResources)).toHaveLength(1);
   });
 
   it('should render OperatorBackedOwnerReferences with proper props', () => {
@@ -88,4 +94,34 @@ describe('OverviewDetailsKnativeResourcesTab', () => {
     expect(wrapper.find(KSRoutesOverviewList)).toHaveLength(1);
     expect(wrapper.find(ConfigurationsOverviewList)).toHaveLength(1);
   });
+
+  it('should render EventPubSubResources on sidebar for Subscription', () => {
+    knItem.item = {
+      ...knItem.item,
+      ...{ obj: EventSubscriptionObj },
+    };
+    const wrapper = shallow(<OverviewDetailsKnativeResourcesTab {...knItem} />);
+    expect(wrapper.find(EventPubSubResources)).toHaveLength(1);
+  });
+
+  it('should render EventPubSubResources on sidebar for channel', () => {
+    jest
+      .spyOn(fetchDynamicEventSources, 'isEventingChannelResourceKind')
+      .mockImplementationOnce(() => true);
+    knItem.item = {
+      ...knItem.item,
+      ...{ obj: EventIMCObj },
+    };
+    const wrapper = shallow(<OverviewDetailsKnativeResourcesTab {...knItem} />);
+    expect(wrapper.find(EventPubSubResources)).toHaveLength(1);
+  });
+
+  it('should render EventSourceResources on sidebar for KameletBinding', () => {
+    knItem.item = {
+      ...knItem.item,
+      ...{ obj: sampleSourceKameletBinding.data[0] },
+    };
+    const wrapper = shallow(<OverviewDetailsKnativeResourcesTab {...knItem} />);
+    expect(wrapper.find(EventSourceResources)).toHaveLength(1);
+  });
 });
