@@ -1,8 +1,11 @@
 import * as React from 'react';
 import { FormikProps, FormikValues } from 'formik';
+import { pickBy, size } from 'lodash';
+import { useTranslation } from 'react-i18next';
 import { TextInputTypes } from '@patternfly/react-core';
-import { MultiColumnField, InputField, DropdownField } from '@console/shared';
+import { MultiColumnField, InputField } from '@console/shared';
 import { RevisionItems } from '../../utils/traffic-splitting-utils';
+import TrafficModalRevisionsDropdownField from './TrafficModalRevisionsDropdownField';
 
 interface TrafficSplittingFieldProps {
   revisionItems: RevisionItems;
@@ -11,13 +14,23 @@ interface TrafficSplittingFieldProps {
 type Props = FormikProps<FormikValues> & TrafficSplittingFieldProps;
 
 const TrafficSplittingFields: React.FC<Props> = ({ revisionItems, values }) => {
+  const { t } = useTranslation();
+  const selectedRevisions: string[] = values.trafficSplitting.map(
+    (traffic) => traffic.revisionName,
+  );
+  const items = pickBy(revisionItems, (revisionItem) => !selectedRevisions.includes(revisionItem));
   return (
     <MultiColumnField
       name="trafficSplitting"
-      addLabel="Add Revision"
-      headers={[{ name: 'Split', required: true }, 'Tag', { name: 'Revision', required: true }]}
+      addLabel={t('knative-plugin~Add Revision')}
+      headers={[
+        { name: t('knative-plugin~Split'), required: true },
+        t('knative-plugin~Tag'),
+        { name: t('knative-plugin~Revision'), required: true },
+      ]}
       emptyValues={{ percent: '', tag: '', revisionName: '' }}
       disableDeleteRow={values.trafficSplitting.length === 1}
+      disableAddRow={values.trafficSplitting.length === size(revisionItems)}
       spans={[2, 3, 7]}
     >
       <InputField
@@ -27,12 +40,10 @@ const TrafficSplittingFields: React.FC<Props> = ({ revisionItems, values }) => {
         required
       />
       <InputField name="tag" type={TextInputTypes.text} />
-      <DropdownField
+      <TrafficModalRevisionsDropdownField
         name="revisionName"
-        items={revisionItems}
-        title="Select a revision"
-        fullWidth
-        required
+        revisionItems={items}
+        title={t('knative-plugin~Select a Revision')}
       />
     </MultiColumnField>
   );
