@@ -10,7 +10,12 @@ export const KNATIVE_EVENTING_APIGROUP = 'eventing.knative.dev';
 export const KNATIVE_EVENT_MESSAGE_APIGROUP = 'messaging.knative.dev';
 export const KNATIVE_EVENT_SOURCE_APIGROUP_DEP = 'sources.eventing.knative.dev';
 export const KNATIVE_EVENT_SOURCE_APIGROUP = 'sources.knative.dev';
+export const CAMEL_APIGROUP = 'camel.apache.org';
 export const STRIMZI_KAFKA_APIGROUP = 'kafka.strimzi.io';
-export const EVENT_SOURCE_LABEL = 'console.openshift.io/event-source';
 export const EVENT_SOURCE_ICON = 'console.openshift.io/icon';
-export const CAMEL_SOURCE_INTEGRATION = 'camel.apache.org/integration';
+export const CAMEL_KAMELET_ICON = `${CAMEL_APIGROUP}/kamelet.icon`;
+export const CAMEL_SOURCE_INTEGRATION = `${CAMEL_APIGROUP}/integration`;
+export const FLAG_KNATIVE_EVENTING_BROKER = 'FLAG_KNATIVE_EVENTING_BROKER';
+export const FLAG_KNATIVE_EVENTING_CHANNEL = 'FLAG_KNATIVE_EVENTING_CHANNEL';
+export const FLAG_CAMEL_KAMELETS = 'FLAG_CAMEL_KAMELETS';
+export const CAMEL_K_PROVIDER_ANNOTATION = `${CAMEL_APIGROUP}/provider`;
