@@ -1,7 +1,6 @@
 import * as _ from 'lodash';
 import { K8sResourceKind, PodKind, referenceForModel } from '@console/internal/module/k8s';
 import { FirehoseResource } from '@console/internal/components/utils';
-import { ClusterServiceVersionModel } from '@console/operator-lifecycle-manager';
 import { KNATIVE_SERVING_LABEL } from '../const';
 import { WatchK8sResources } from '@console/internal/components/utils/k8s-watch-hook';
 import {
@@ -15,6 +14,7 @@ import {
   KafkaModel,
   KafkaTopicModel,
   CamelIntegrationModel,
+  CamelKameletBindingModel,
 } from '../models';
 
 export type KnativeItem = {
@@ -22,6 +22,8 @@ export type KnativeItem = {
   configurations?: K8sResourceKind[];
   ksroutes?: K8sResourceKind[];
   ksservices?: K8sResourceKind[];
+  eventSources?: K8sResourceKind[];
+  eventingsubscription?: K8sResourceKind[];
   eventSourceCronjob?: K8sResourceKind[];
   eventSourceContainers?: K8sResourceKind[];
   eventSourceApiserver?: K8sResourceKind[];
@@ -164,23 +166,6 @@ export const knativeEventingResourcesBroker = (
   return knativeResource;
 };
 
-const EVENT_SOURCE_PROVIDER_CSV = 'console.openshift.io/event-source-provider';
-
-export const clusterServiceVersionResource = (namespace: string): FirehoseResource => {
-  return {
-    isList: true,
-    kind: referenceForModel(ClusterServiceVersionModel),
-    namespace,
-    prop: ClusterServiceVersionModel.plural,
-    selector: {
-      matchLabels: {
-        [EVENT_SOURCE_PROVIDER_CSV]: 'true',
-      },
-    },
-    optional: true,
-  };
-};
-
 export const knativeServingResourcesRevisionWatchers = (
   namespace: string,
 ): WatchK8sResources<any> => {
@@ -301,3 +286,16 @@ export const strimziResourcesWatcher = (): WatchK8sResources<any> => {
   };
   return strimziResources;
 };
+
+export const knativeCamelKameletBindingResourceWatchers = (
+  namespace: string,
+): WatchK8sResources<any> => {
+  return {
+    [CamelKameletBindingModel.plural]: {
+      isList: true,
+      kind: referenceForModel(CamelKameletBindingModel),
+      namespace,
+      optional: true,
+    },
+  };
+};
