@@ -1,17 +1,24 @@
 import { click, fillInput } from '@console/shared/src/test-utils/utils';
 import * as view from '../../views/dialogs/networkInterface.view';
-import { selectOptionByText, getSelectOptions } from '../utils/utils';
-import { NetworkResource } from '../utils/types';
+import {
+  selectOptionByText,
+  getSelectOptions,
+  selectItemFromDropdown,
+  checkForError,
+} from '../utils/utils';
+import { Network } from '../types/types';
 import { modalSubmitButton, saveButton } from '../../views/kubevirtUIResource.view';
 import { waitForNoLoaders } from '../../views/wizard.view';
+import * as wizardView from '../../views/importWizard.view';
 
 export class NetworkInterfaceDialog {
   async fillName(name: string) {
     await fillInput(view.nicName, name);
+    return checkForError(wizardView.errorHelper);
   }
 
   async selectModel(model: string) {
-    await selectOptionByText(view.nicModel, model);
+    await selectItemFromDropdown(view.nicModel, view.nicDropDownItem(model));
   }
 
   async selectNetwork(network: string) {
@@ -19,7 +26,7 @@ export class NetworkInterfaceDialog {
   }
 
   async selectType(type: string) {
-    await selectOptionByText(view.nicType, type);
+    await selectItemFromDropdown(view.nicType, view.nicDropDownItem(type));
   }
 
   async fillMAC(mac: string) {
@@ -30,7 +37,7 @@ export class NetworkInterfaceDialog {
     return getSelectOptions(view.nicNetwork);
   }
 
-  async create(NIC: NetworkResource) {
+  async create(NIC: Network) {
     await waitForNoLoaders();
     await this.fillName(NIC.name);
     await this.selectModel(NIC.model);
