@@ -1,9 +1,10 @@
-import * as _ from 'lodash';
 import * as React from 'react';
 import axios from 'axios';
 import cx from 'classnames';
 import { Helmet } from 'react-helmet';
 import { match } from 'react-router';
+import { Trans, useTranslation } from 'react-i18next';
+import { TFunction } from 'i18next';
 import {
   FileUpload,
   ActionGroup,
@@ -14,13 +15,16 @@ import {
   FormSelectOption,
   Split,
   SplitItem,
+  SelectOption,
 } from '@patternfly/react-core';
-import { isCephProvisioner, isObjectSC } from '@console/shared/src/utils';
 import {
   K8sResourceKind,
   apiVersionForModel,
   TemplateKind,
   PersistentVolumeClaimKind,
+  ConfigMapKind,
+  StorageClassResourceKind,
+  K8sVerb,
 } from '@console/internal/module/k8s';
 import {
   ButtonBar,
@@ -29,15 +33,11 @@ import {
   resourcePath,
   ExternalLink,
   ResourceLink,
+  useAccessReview2,
+  useMultipleAccessReviews,
 } from '@console/internal/components/utils';
-import { StorageClassDropdown } from '@console/internal/components/utils/storage-class-dropdown';
-import { RadioInput } from '@console/internal/components/radio';
-import { StorageClass } from '@console/internal/components/storage-class-form';
 import {
-  cephRBDProvisionerSuffix,
   provisionerAccessModeMapping,
-  initialAccessModes,
-  accessModeRadios,
   dropdownUnits,
   getAccessModeForProvisioner,
 } from '@console/internal/components/storage/shared';
@@ -45,20 +45,30 @@ import {
   useK8sWatchResource,
   WatchK8sResource,
 } from '@console/internal/components/utils/k8s-watch-hook';
-import { usePVCBaseImages } from '../../../hooks/use-pvc-base-images';
+import { useBaseImages } from '../../../hooks/use-base-images';
 import { DataVolumeModel } from '../../../models';
-import { createUploadPVC } from '../../../k8s/requests/cdi-upload/cdi-upload-requests';
+import {
+  createUploadPVC,
+  PVCInitError,
+} from '../../../k8s/requests/cdi-upload/cdi-upload-requests';
 import { CDIUploadContext } from '../cdi-upload-provider';
-import { UploadPVCFormStatus } from './upload-pvc-form-status';
-import { PersistentVolumeClaimModel, TemplateModel } from '@console/internal/models';
+import { UploadPVCFormStatus, uploadErrorType } from './upload-pvc-form-status';
+import {
+  PersistentVolumeClaimModel,
+  StorageClassModel,
+  TemplateModel,
+} from '@console/internal/models';
 import { getName, getNamespace } from '@console/shared';
 import { V1alpha1DataVolume } from '../../../types/vm/disk/V1alpha1DataVolume';
 import { getTemplateOperatingSystems } from '../../../selectors/vm-template/advanced';
 import { FormSelectPlaceholderOption } from '../../form/form-select-placeholder-option';
 import {
+  AccessMode,
+  TEMPLATE_BASE_IMAGE_NAMESPACE_PARAMETER,
   TEMPLATE_TYPE_BASE,
   TEMPLATE_TYPE_LABEL,
   TEMPLATE_VM_COMMON_NAMESPACE,
+  VolumeMode,
 } from '../../../constants';
 import {
   CDI_UPLOAD_OS_URL_PARAM,
@@ -66,6 +76,16 @@ import {
   CDI_UPLOAD_URL_BUILDER,
 } from '../consts';
 import { OperatingSystemRecord } from '../../../types';
+import { useStorageClassConfigMap } from '../../../hooks/storage-class-config-map';
+import { FormPFSelect } from '../../form/form-pf-select';
+import {
+  getDefaultSCAccessModes,
+  getDefaultSCVolumeMode,
+  getDefaultStorageClass,
+  isConfigMapContainsScModes,
+} from '../../../selectors/config-map/sc-defaults';
+import { ConfigMapDefaultModesAlert } from '../../Alerts/ConfigMapDefaultModesAlert';
+import { getParameterValue } from '../../../selectors/selectors';
 import './upload-pvc-form.scss';
 
 const templatesResource: WatchK8sResource = {
@@ -78,40 +98,19 @@ const templatesResource: WatchK8sResource = {
   },
 };
 
-enum uploadErrorType {
-  MISSING = 'missing',
-  ALLOCATE = 'allocate',
-  TYPE = 'type',
-  CERT = 'cert',
-}
-
-const uploadErrorMessage = {
-  [uploadErrorType.MISSING]: 'File input is missing',
-  [uploadErrorType.ALLOCATE]: 'Could not create persistent volume claim',
-  [uploadErrorType.TYPE]: (
-    <>
-      <p>
-        The format of the file you are uploading is not supported. Please use one of the supported
-        formats
-      </p>
-      <p>
-        <ExternalLink
-          text="Learn more about supported formats"
-          href={CDI_UPLOAD_SUPPORTED_TYPES_URL}
-        />
-      </p>
-    </>
-  ),
+export const uploadErrorMessage = (t: TFunction) => ({
+  [uploadErrorType.MISSING]: t('kubevirt-plugin~File input is missing'),
+  [uploadErrorType.ALLOCATE]: t('kubevirt-plugin~Could not create persistent volume claim'),
   [uploadErrorType.CERT]: (uploadProxy) => (
-    <>
+    <Trans ns="kubevirt-plugin" t={t}>
       It seems that your browser does not trust the certificate of the upload proxy. Please{' '}
       <a href={`https://${uploadProxy}`} rel="noopener noreferrer" target="_blank">
         approve this certificate
       </a>{' '}
       and try again
-    </>
+    </Trans>
   ),
-};
+});
 
 export const UploadPVCForm: React.FC<UploadPVCFormProps> = ({
   onChange,
@@ -124,21 +123,65 @@ export const UploadPVCForm: React.FC<UploadPVCFormProps> = ({
   isLoading,
   setIsFileRejected,
   setDisableFormSubmit,
+  scConfigMap,
+  storageClasses,
   ...props
 }) => {
+  const { t } = useTranslation();
   const operatingSystems = getTemplateOperatingSystems(commonTemplates);
-  const [accessModeHelp, setAccessModeHelp] = React.useState('Permissions to the mounted drive.');
-  const [allowedAccessModes, setAllowedAccessModes] = React.useState(initialAccessModes);
-  const [storageClass, setStorageClass] = React.useState('');
+  const operatingSystemHaveDV = operatingSystems.find(
+    (os) => os?.baseImageName && os?.baseImageNamespace,
+  );
+  const [storageClassName, setStorageClass] = React.useState('');
   const [pvcName, setPvcName] = React.useState('');
   const [namespace, setNamespace] = React.useState(props.namespace);
-  const [accessMode, setAccessMode] = React.useState('ReadWriteOnce');
+  const [accessMode, setAccessMode] = React.useState('');
+  const [volumeMode, setVolumeMode] = React.useState('');
   const [requestSizeValue, setRequestSizeValue] = React.useState('');
   const [requestSizeUnit, setRequestSizeUnit] = React.useState('Gi');
-  const [storageProvisioner, setStorageProvisioner] = React.useState('');
   const [isGolden, setIsGolden] = React.useState(!!osParam);
   const [os, setOs] = React.useState<OperatingSystemRecord>();
   const [osImageExists, setOsImageExists] = React.useState(false);
+  const defaultSCName = getDefaultStorageClass(storageClasses)?.metadata.name;
+  const updatedStorageClass = storageClasses?.find((sc) => sc.metadata.name === storageClassName);
+  const provisioner = updatedStorageClass?.provisioner || '';
+  let accessModes: string[] =
+    provisionerAccessModeMapping[provisioner] || getAccessModeForProvisioner(provisioner);
+
+  if (storageClasses?.length === 0 && scConfigMap) {
+    accessModes = getDefaultSCAccessModes(scConfigMap).map((am) => am.getValue());
+  }
+
+  const [defaultAccessMode, defaultVolumeMode, isScModesKnown] = React.useMemo(() => {
+    return [
+      getDefaultSCAccessModes(scConfigMap, storageClassName)?.[0],
+      getDefaultSCVolumeMode(scConfigMap, storageClassName),
+      isConfigMapContainsScModes(scConfigMap, storageClassName),
+    ];
+  }, [scConfigMap, storageClassName]);
+
+  React.useEffect(() => {
+    if (!storageClassName) {
+      if (defaultSCName) {
+        setStorageClass(defaultSCName);
+      } else {
+        setStorageClass(storageClasses?.[0]?.metadata?.name);
+      }
+    }
+  }, [defaultSCName, storageClassName, storageClasses]);
+
+  React.useEffect(() => {
+    if (storageClassName) {
+      if (defaultAccessMode.getValue() !== accessMode) {
+        setAccessMode(defaultAccessMode.getValue());
+      }
+
+      if (defaultVolumeMode.getValue() !== volumeMode) {
+        setVolumeMode(defaultVolumeMode.getValue());
+      }
+    }
+    // eslint-disable-next-line react-hooks/exhaustive-deps
+  }, [defaultAccessMode, defaultVolumeMode, storageClassName]);
 
   React.useEffect(() => {
     const updateDV = (): K8sResourceKind => {
@@ -154,7 +197,9 @@ export const UploadPVCForm: React.FC<UploadPVCFormProps> = ({
             upload: {},
           },
           pvc: {
+            storageClassName,
             accessModes: [accessMode],
+            volumeMode,
             resources: {
               requests: {
                 storage: `${requestSizeValue}${requestSizeUnit}`,
@@ -164,51 +209,20 @@ export const UploadPVCForm: React.FC<UploadPVCFormProps> = ({
         },
       };
 
-      if (storageClass) {
-        obj.spec.pvc.storageClassName = storageClass;
-
-        // should set block only for RBD + RWX
-        if (
-          _.endsWith(storageProvisioner, cephRBDProvisionerSuffix) &&
-          accessMode === 'ReadWriteMany'
-        ) {
-          obj.spec.volumeMode = 'Block';
-        }
-      }
-
       return obj;
     };
     onChange(updateDV);
   }, [
     accessMode,
+    volumeMode,
     namespace,
     pvcName,
     onChange,
-    storageClass,
+    storageClassName,
     requestSizeValue,
     requestSizeUnit,
-    storageProvisioner,
   ]);
 
-  const handleStorageClass = (updatedStorageClass) => {
-    const provisioner: string = updatedStorageClass?.provisioner || '';
-    // if the provisioner is unknown or no storage class selected, user should be able to set any access mode
-    const modes = provisionerAccessModeMapping[provisioner]
-      ? provisionerAccessModeMapping[provisioner]
-      : getAccessModeForProvisioner(provisioner);
-    // setting message to display for various modes when a storage class of a know provisioner is selected
-    const displayMessage =
-      provisionerAccessModeMapping[provisioner] || isCephProvisioner(provisioner)
-        ? 'Access mode is set by storage class and cannot be changed'
-        : 'Permissions to the mounted drive';
-    setAccessMode('ReadWriteOnce');
-    setAccessModeHelp(displayMessage);
-    // setting accessMode to default with the change to Storage Class selection
-    setAllowedAccessModes(modes);
-    setStorageClass(updatedStorageClass?.metadata?.name);
-    setStorageProvisioner(provisioner);
-  };
-
   const handleRequestSizeInputChange = (obj) => {
     setRequestSizeValue(obj.value);
     setRequestSizeUnit(obj.unit);
@@ -218,18 +232,14 @@ export const UploadPVCForm: React.FC<UploadPVCFormProps> = ({
     setPvcName(event.currentTarget.value);
   };
 
-  const handleAccessMode: React.ReactEventHandler<HTMLInputElement> = (event) => {
-    setAccessMode(event.currentTarget.value);
-  };
-
   const handleGoldenCheckbox = (checked) => {
     setIsGolden(checked);
     if (checked) {
-      setNamespace(os?.dataVolumeNamespace);
+      setNamespace(os?.baseImageNamespace);
       if (pvcName && !os) {
         setPvcName('');
       } else {
-        setPvcName(os?.dataVolumeName);
+        setPvcName(os?.baseImageName);
       }
     }
     if (!checked) {
@@ -240,14 +250,16 @@ export const UploadPVCForm: React.FC<UploadPVCFormProps> = ({
   const handleOs = (newOs: string) => {
     const operatingSystem = operatingSystems.find((o) => o.id === newOs);
     setOs(operatingSystem);
-    setPvcName(operatingSystem?.dataVolumeName);
-    if (operatingSystem?.dataVolumeNamespace) {
-      setNamespace(operatingSystem.dataVolumeNamespace);
+    setPvcName(operatingSystem?.baseImageName);
+    if (operatingSystem?.baseImageNamespace) {
+      setNamespace(operatingSystem.baseImageNamespace);
+    }
+    if (operatingSystem?.baseImageRecomendedSize) {
+      setRequestSizeValue(operatingSystem?.baseImageRecomendedSize[0]);
+      setRequestSizeUnit(operatingSystem?.baseImageRecomendedSize[1]);
     }
   };
 
-  const onlyPvcSCs = React.useCallback((sc: StorageClass) => !isObjectSC(sc), []);
-
   React.useEffect(() => {
     if (!isLoading && osParam) {
       handleOs(osParam);
@@ -257,7 +269,7 @@ export const UploadPVCForm: React.FC<UploadPVCFormProps> = ({
 
   React.useEffect(() => {
     const goldenImagePVC = goldenPvcs?.find(
-      (pvc) => getName(pvc) === os?.dataVolumeName && getNamespace(pvc) === os?.dataVolumeNamespace,
+      (pvc) => getName(pvc) === os?.baseImageName && getNamespace(pvc) === os?.baseImageNamespace,
     );
     if (goldenImagePVC) {
       setOsImageExists(true);
@@ -272,13 +284,14 @@ export const UploadPVCForm: React.FC<UploadPVCFormProps> = ({
   return (
     <div>
       <div className="form-group">
-        <Alert title="Persistent volume creation" variant="info" isInline>
-          This Persistent Volume Claim will be created using a DataVolume through Containerized Data
-          Importer (CDI)
+        <Alert title={t('kubevirt-plugin~Persistent volume creation')} variant="info" isInline>
+          {t(
+            'kubevirt-plugin~This Persistent Volume Claim will be created using a DataVolume through Containerized Data Importer (CDI)',
+          )}
         </Alert>
       </div>
       <label className="control-label co-required" htmlFor="file-upload">
-        Upload Data
+        {t('kubevirt-plugin~Upload Data')}
       </label>
       <div className="form-group">
         <FileUpload
@@ -295,19 +308,21 @@ export const UploadPVCForm: React.FC<UploadPVCFormProps> = ({
             onDropAccepted: () => setIsFileRejected(false),
           }}
         />
-        <Checkbox
-          id="golden-os-switch"
-          className="kv--create-upload__golden-switch"
-          label="Attach this data to a Virtual Machine operating system"
-          isChecked={isGolden}
-          onChange={handleGoldenCheckbox}
-          isDisabled={isLoading}
-        />
+        {operatingSystemHaveDV && (
+          <Checkbox
+            id="golden-os-switch"
+            className="kv--create-upload__golden-switch"
+            label={t('kubevirt-plugin~Attach this data to a Virtual Machine operating system')}
+            isChecked={isGolden}
+            onChange={handleGoldenCheckbox}
+            isDisabled={isLoading}
+          />
+        )}
       </div>
       {isGolden && (
         <>
           <label className="control-label co-required" htmlFor="golden-os">
-            Operating System
+            {t('kubevirt-plugin~Operating System')}
           </label>
           <div className="form-group">
             <FormSelect
@@ -318,25 +333,30 @@ export const UploadPVCForm: React.FC<UploadPVCFormProps> = ({
               isRequired
             >
               <FormSelectPlaceholderOption
-                placeholder="--- Pick an Operating system ---"
+                placeholder={t('kubevirt-plugin~--- Pick an Operating system ---')}
                 isDisabled={!!os}
               />
-              {operatingSystems.map(({ id, name, dataVolumeName, dataVolumeNamespace }) =>
+              {operatingSystems.map(({ id, name, baseImageName, baseImageNamespace }) =>
                 goldenPvcs?.find(
                   (pvc) =>
-                    getName(pvc) === dataVolumeName && getNamespace(pvc) === dataVolumeNamespace,
+                    getName(pvc) === baseImageName && getNamespace(pvc) === baseImageNamespace,
                 ) ? (
                   <FormSelectOption
                     key={id}
                     value={id}
-                    label={`${name || id} - Default data image already exists`}
+                    label={t('kubevirt-plugin~{{nameOrId}} - Default data image already exists', {
+                      nameOrId: name || id,
+                    })}
                   />
-                ) : !dataVolumeName ? (
+                ) : !baseImageName ? (
                   <FormSelectOption
                     isDisabled
                     key={id}
                     value={id}
-                    label={`${name || id} - Template missing data image definition`}
+                    label={t(
+                      'kubevirt-plugin~{{nameOrId}} - Template missing data image definition',
+                      { nameOrId: name || id },
+                    )}
                   />
                 ) : (
                   <FormSelectOption key={id} value={id} label={name || id} />
@@ -346,21 +366,27 @@ export const UploadPVCForm: React.FC<UploadPVCFormProps> = ({
           </div>
           {osImageExists && (
             <div className="form-group">
-              <Alert isInline variant="danger" title="Operating system source already defined">
-                In order to add a new source for {os?.name} you will need to delete the following
-                PVC:{' '}
+              <Alert
+                isInline
+                variant="danger"
+                title={t('kubevirt-plugin~Operating system source already defined')}
+              >
+                {t(
+                  'kubevirt-plugin~In order to add a new source for {{osName}} you will need to delete the following PVC:',
+                  { osName: os?.name },
+                )}{' '}
                 <ResourceLink
                   hideIcon
                   inline
                   kind={PersistentVolumeClaimModel.kind}
-                  name={os?.dataVolumeName}
-                  namespace={os?.dataVolumeNamespace}
+                  name={os?.baseImageName}
+                  namespace={os?.baseImageNamespace}
                 />
               </Alert>
             </div>
           )}
           <label className="control-label co-required" htmlFor="pvc-namespace">
-            Namespace
+            {t('kubevirt-plugin~Namespace')}
           </label>
           <div className="form-group">
             <input
@@ -373,13 +399,13 @@ export const UploadPVCForm: React.FC<UploadPVCFormProps> = ({
               required
             />
             <p className="help-block" id="pvc-namespace-help">
-              A unique namespace for the storage claim within the project
+              {t('kubevirt-plugin~A unique namespace for the storage claim within the project')}
             </p>
           </div>
         </>
       )}
       <label className="control-label co-required" htmlFor="pvc-name">
-        Persistent Volume Claim Name
+        {t('kubevirt-plugin~Persistent Volume Claim Name')}
       </label>
       <div className="form-group">
         <input
@@ -387,32 +413,46 @@ export const UploadPVCForm: React.FC<UploadPVCFormProps> = ({
           className="pf-c-form-control"
           type="text"
           onChange={handlePvcName}
-          placeholder={isGolden ? 'pick an operating system' : 'my-storage-claim'}
+          placeholder={
+            isGolden
+              ? t('kubevirt-plugin~pick an operating system')
+              : t('kubevirt-plugin~my-storage-claim')
+          }
           aria-describedby="pvc-name-help"
           id="pvc-name"
           value={pvcName || ''}
           required
         />
         <p className="help-block" id="pvc-name-help">
-          A unique name for the storage claim within the project
+          {t('kubevirt-plugin~A unique name for the storage claim within the project')}
         </p>
       </div>
       <div className="form-group">
         <Split hasGutter>
           <SplitItem className="kv--create-upload__flexitem">
-            <StorageClassDropdown
+            <label className="control-label co-required" htmlFor="upload-form-ds-sc-select">
+              {t('kubevirt-plugin~Storage Class')}
+            </label>
+            <FormPFSelect
+              value={storageClassName}
+              onSelect={(e, value: string) => setStorageClass(value)}
+              aria-label={t('kubevirt-plugin~Select Storage Class')}
+              selections={[storageClassName]}
               isDisabled={isLoading}
-              onChange={handleStorageClass}
-              id="storageclass-dropdown"
-              describedBy="storageclass-dropdown-help"
-              required={false}
-              name="storageClass"
-              filter={onlyPvcSCs}
-            />
+              toggleId="upload-form-ds-sc-select"
+            >
+              {storageClasses?.map((sc) => (
+                <SelectOption key={sc.metadata.uid} value={sc.metadata.name}>
+                  {defaultSCName === sc.metadata.name
+                    ? t('kubevirt-plugin~{{name}} (default)', { name: sc.metadata.name })
+                    : sc.metadata.name}
+                </SelectOption>
+              ))}
+            </FormPFSelect>
           </SplitItem>
           <SplitItem className="kv--create-upload__flexitem">
             <label className="control-label co-required" htmlFor="request-size-input">
-              Size
+              {t('kubevirt-plugin~Size')}
             </label>
             <RequestSizeInput
               name="requestSize"
@@ -425,52 +465,82 @@ export const UploadPVCForm: React.FC<UploadPVCFormProps> = ({
               inputID="request-size-input"
             />
             <p className="help-block" id="request-size-help">
-              Ensure your PVC size covers the requirements of the uncompressed image and any other
-              space requirements
+              {t(
+                'kubevirt-plugin~Ensure your PVC size covers the requirements of the uncompressed image and any other space requirements.',
+              )}
             </p>
           </SplitItem>
         </Split>
       </div>
-      <label className="control-label co-required" htmlFor="access-mode">
-        Access Mode
+      <label className="control-label co-required" htmlFor="upload-form-ds-access-mode-select">
+        {t('kubevirt-plugin~Access Mode')}
       </label>
       <div className="form-group">
-        {accessModeRadios.map((radio) => {
-          let radioObj = null;
-          const disabled = !allowedAccessModes.includes(radio.value);
-
-          allowedAccessModes.forEach((mode) => {
-            const checked = !disabled ? radio.value === accessMode : radio.value === mode;
-            radioObj = (
-              <RadioInput
-                {...radio}
-                key={radio.value}
-                onChange={handleAccessMode}
-                inline
-                disabled={disabled}
-                checked={checked}
-                aria-describedby="access-mode-help"
-                name="accessMode"
-              />
+        <FormPFSelect
+          aria-label={t('kubevirt-plugin~Select access mode')}
+          onSelect={(e, value: AccessMode) => setAccessMode(value.getValue())}
+          selections={AccessMode.fromString(accessMode)}
+          isDisabled={isLoading}
+          toggleId="upload-form-ds-access-mode-select"
+        >
+          {accessModes.map((am) => {
+            const aMode = AccessMode.fromString(am);
+            return (
+              <SelectOption key={aMode.getValue()} value={aMode}>
+                {aMode.toString().concat(
+                  aMode.getValue() !== defaultAccessMode.getValue() && isScModesKnown
+                    ? t(
+                        'kubevirt-plugin~ - Not recommended for {{storageClassName}} storage class',
+                        {
+                          storageClassName,
+                        },
+                      )
+                    : '',
+                )}
+              </SelectOption>
             );
-          });
-
-          return radioObj;
-        })}
-        <p className="help-block" id="access-mode-help">
-          {accessModeHelp}
-        </p>
+          })}
+        </FormPFSelect>
+      </div>
+      <label className="control-label co-required" htmlFor="upload-form-ds-volume-mode-select">
+        {t('kubevirt-plugin~Volume Mode')}
+      </label>
+      <div className="form-group">
+        <FormPFSelect
+          aria-label={t('kubevirt-plugin~Select volume mode')}
+          onSelect={(e, value: VolumeMode) => setVolumeMode(value.getValue())}
+          selections={VolumeMode.fromString(volumeMode)}
+          isDisabled={isLoading}
+          toggleId="upload-form-ds-volume-mode-select"
+        >
+          {VolumeMode.getAll().map((vm) => (
+            <SelectOption key={vm.getValue()} value={vm}>
+              {vm.toString().concat(
+                vm.getValue() !== defaultVolumeMode.getValue() && isScModesKnown
+                  ? t('kubevirt-plugin~ - Not recommended for {{storageClassName}} storage class', {
+                      storageClassName,
+                    })
+                  : '',
+              )}
+            </SelectOption>
+          ))}
+        </FormPFSelect>
+      </div>
+      <div className="form-group">
+        <ConfigMapDefaultModesAlert isScModesKnown={isScModesKnown} />
       </div>
     </div>
   );
 };
 
 export const UploadPVCPage: React.FC<UploadPVCPageProps> = (props) => {
+  const { t } = useTranslation();
   const [isSubmitting, setIsSubmitting] = React.useState(false);
   const [isCheckingCertificate, setCheckingCertificate] = React.useState(false);
   const [disableFormSubmit, setDisableFormSubmit] = React.useState(false);
   const [fileValue, setFileValue] = React.useState<File>(null);
   const [fileName, setFileName] = React.useState('');
+  const [fileNameExtension, setFileNameExtension] = React.useState('');
   const [isFileRejected, setIsFileRejected] = React.useState(false);
   const [error, setError] = React.useState<string>('');
   const [isAllocating, setIsAllocating] = React.useState(false);
@@ -478,20 +548,65 @@ export const UploadPVCPage: React.FC<UploadPVCPageProps> = (props) => {
   const [commonTemplates, loadedTemplates, errorTemplates] = useK8sWatchResource<TemplateKind[]>(
     templatesResource,
   );
-  const [goldenPvcs, loadedPvcs, errorPvcs] = usePVCBaseImages(commonTemplates);
+
+  const goldenNamespacesResources = React.useMemo(() => {
+    const goldenNamespaces = [
+      ...new Set(
+        (commonTemplates || [])
+          .map((template) => getParameterValue(template, TEMPLATE_BASE_IMAGE_NAMESPACE_PARAMETER))
+          .filter((ns) => !!ns),
+      ),
+    ];
+
+    return goldenNamespaces.map((ns) => ({
+      group: DataVolumeModel.apiGroup,
+      resource: DataVolumeModel.plural,
+      verb: 'create' as K8sVerb,
+      namespace: ns,
+    }));
+  }, [commonTemplates]);
+
+  const [goldenAccessReviews, rbacLoading] = useMultipleAccessReviews(goldenNamespacesResources);
+  const allowedTemplates = commonTemplates.filter((tmp) =>
+    goldenAccessReviews.some(
+      (accessReview) =>
+        accessReview.allowed &&
+        accessReview.resourceAttributes.namespace ===
+          getParameterValue(tmp, TEMPLATE_BASE_IMAGE_NAMESPACE_PARAMETER),
+    ),
+  );
+
+  const [goldenPvcs, loadedPvcs, errorPvcs] = useBaseImages(allowedTemplates);
   const { uploads, uploadData, uploadProxyURL } = React.useContext(CDIUploadContext);
+  const [scConfigMap, cmLoaded] = useStorageClassConfigMap();
+  const [scAllowed, scAllowedLoading] = useAccessReview2({
+    group: StorageClassModel.apiGroup,
+    resource: StorageClassModel.plural,
+    verb: 'list',
+  });
+  const [storageClasses, scLoaded] = useK8sWatchResource<StorageClassResourceKind[]>(
+    scAllowed
+      ? {
+          kind: StorageClassModel.kind,
+          isList: true,
+          namespaced: false,
+        }
+      : null,
+  );
+
   const initialNamespace = props?.match?.params?.ns;
   const namespace = getNamespace(dvObj) || initialNamespace;
   const urlParams = new URLSearchParams(window.location.search);
   const osParam = urlParams.get(CDI_UPLOAD_OS_URL_PARAM);
-  const title = 'Upload Data to Persistent Volume Claim';
+  const title = t('kubevirt-plugin~Upload Data to Persistent Volume Claim');
+  const fileNameExtText = fileNameExtension
+    ? t('kubevirt-plugin~detected file extension is {{fileNameExtension}}', { fileNameExtension })
+    : t('kubevirt-plugin~no file extention detected');
 
   const save = (e: React.FormEvent<EventTarget>) => {
     e.preventDefault();
     if (!fileName) {
       setError(uploadErrorType.MISSING);
-    } else if (isFileRejected) {
-      setError(uploadErrorType.TYPE);
     } else {
       // checking valid certificate for proxy
       setCheckingCertificate(true);
@@ -519,9 +634,11 @@ export const UploadPVCPage: React.FC<UploadPVCPageProps> = (props) => {
             namespace,
           });
         })
-        .catch(({ message }: { message: string }) => {
+        .catch((err) => {
           setIsAllocating(false);
-          setError(message || uploadErrorType.ALLOCATE);
+          err instanceof PVCInitError
+            ? setError(uploadErrorType.CDI_INIT)
+            : setError(err?.message || uploadErrorType.ALLOCATE);
         });
     }
   };
@@ -529,6 +646,9 @@ export const UploadPVCPage: React.FC<UploadPVCPageProps> = (props) => {
   const handleFileChange = (value, filename) => {
     setFileName(filename);
     setFileValue(value);
+
+    setFileNameExtension(/[.][^.]+$/.exec(filename)?.toString());
+    setIsFileRejected(false);
     setError('');
   };
 
@@ -540,8 +660,8 @@ export const UploadPVCPage: React.FC<UploadPVCPageProps> = (props) => {
 
   const errorMessage =
     error === uploadErrorType.CERT
-      ? uploadErrorMessage[uploadErrorType.CERT](uploadProxyURL)
-      : uploadErrorMessage[error] || error;
+      ? uploadErrorMessage(t)[uploadErrorType.CERT](uploadProxyURL)
+      : uploadErrorMessage(t)[error] || error;
 
   return (
     <>
@@ -564,16 +684,42 @@ export const UploadPVCPage: React.FC<UploadPVCPageProps> = (props) => {
             fileName={fileName}
             handleFileChange={handleFileChange}
             setIsFileRejected={setIsFileRejected}
-            commonTemplates={commonTemplates}
+            commonTemplates={allowedTemplates}
             goldenPvcs={goldenPvcs}
             osParam={osParam}
             isLoading={!loadedTemplates}
             setDisableFormSubmit={setDisableFormSubmit}
+            scConfigMap={scConfigMap}
+            storageClasses={storageClasses}
           />
           <ButtonBar
-            inProgress={!loadedTemplates || !loadedPvcs || isCheckingCertificate}
+            inProgress={
+              rbacLoading ||
+              scAllowedLoading ||
+              !scLoaded ||
+              !cmLoaded ||
+              !loadedTemplates ||
+              !loadedPvcs ||
+              isCheckingCertificate
+            }
             errorMessage={errorMessage}
           >
+            {isFileRejected && (
+              <Alert variant="warning" isInline title={t('kubevirt-plugin~File type extension')}>
+                <p>
+                  {t(
+                    'kubevirt-plugin~Based on the file extension it seems like you are trying to upload a file which is not supported ({{fileNameExtText}}).',
+                    { fileNameExtText },
+                  )}
+                </p>
+                <p>
+                  <ExternalLink
+                    text={t('kubevirt-plugin~Learn more about supported formats')}
+                    href={CDI_UPLOAD_SUPPORTED_TYPES_URL}
+                  />
+                </p>
+              </Alert>
+            )}
             <ActionGroup className="pf-c-form">
               <Button
                 isDisabled={disableFormSubmit || isCheckingCertificate}
@@ -581,10 +727,10 @@ export const UploadPVCPage: React.FC<UploadPVCPageProps> = (props) => {
                 type="submit"
                 variant="primary"
               >
-                Upload
+                {t('kubevirt-plugin~Upload')}
               </Button>
               <Button onClick={history.goBack} type="button" variant="secondary">
-                Cancel
+                {t('kubevirt-plugin~Cancel')}
               </Button>
             </ActionGroup>
           </ButtonBar>
@@ -594,9 +740,10 @@ export const UploadPVCPage: React.FC<UploadPVCPageProps> = (props) => {
         upload={uploads.find(
           (upl) => upl.pvcName === getName(dvObj) && upl.namespace === namespace,
         )}
+        dataVolume={dvObj}
         isSubmitting={isSubmitting}
         isAllocating={isAllocating}
-        allocateError={errorMessage}
+        allocateError={error}
         onErrorClick={() => {
           setIsSubmitting(false);
           setError('');
@@ -604,7 +751,7 @@ export const UploadPVCPage: React.FC<UploadPVCPageProps> = (props) => {
         onSuccessClick={() =>
           history.push(resourcePath(PersistentVolumeClaimModel.kind, getName(dvObj), namespace))
         }
-        onCancelFinish={() => history.push(resourcePath(PersistentVolumeClaimModel.kind))}
+        onCancelClick={() => history.push(resourcePath(PersistentVolumeClaimModel.kind))}
       />
     </>
   );
@@ -620,6 +767,8 @@ export type UploadPVCFormProps = {
   commonTemplates: TemplateKind[];
   goldenPvcs: PersistentVolumeClaimKind[];
   setIsFileRejected: React.Dispatch<React.SetStateAction<boolean>>;
+  scConfigMap: ConfigMapKind;
+  storageClasses: StorageClassResourceKind[];
   onChange: (K8sResourceKind) => void;
   handleFileChange: (value, filename, event) => void;
 };
