@@ -68,7 +68,7 @@ export const setStoragesTabValidity = (options: UpdateOptions) => {
   const state = getState();
 
   const iStorages = iGetStorages(state, id);
-  let error = null;
+  let errorKey: string;
 
   let hasAllRequiredFilled = iStorages.every((iStorage) =>
     iGetIn(iStorage, ['validation', 'hasAllRequiredFilled']),
@@ -80,11 +80,14 @@ export const setStoragesTabValidity = (options: UpdateOptions) => {
         iGetIn(storageBundle, ['disk', 'bootOrder']) === 1 &&
         (iGetIn(storageBundle, ['disk', 'disk']) || iGetIn(storageBundle, ['disk', 'cdrom'])) &&
         (iGetIn(storageBundle, ['volume', 'persistentVolumeClaim']) ||
+          iGetIn(storageBundle, ['volume', 'containerDisk']) ||
           iGetIn(storageBundle, ['dataVolume', 'spec', 'source', 'pvc']) ||
+          iGetIn(storageBundle, ['dataVolume', 'spec', 'source', 'registry']) ||
           iGetIn(storageBundle, ['dataVolume', 'spec', 'source', 'http'])),
     );
     if (!hasBootSource) {
-      error = 'Please select the boot source.';
+      // t('kubevirt-plugin~Please select a disk with a defined boot source.')
+      errorKey = 'kubevirt-plugin~Please select a disk with a defined boot source.';
       hasAllRequiredFilled = false;
     }
   }
@@ -96,7 +99,15 @@ export const setStoragesTabValidity = (options: UpdateOptions) => {
   }
 
   if (
-    checkTabValidityChanged(state, id, VMWizardTab.STORAGE, isValid, hasAllRequiredFilled, error)
+    checkTabValidityChanged(
+      state,
+      id,
+      VMWizardTab.STORAGE,
+      isValid,
+      hasAllRequiredFilled,
+      errorKey,
+      null,
+    )
   ) {
     dispatch(
       vmWizardInternalActions[InternalActionType.SetTabValidity](
@@ -104,7 +115,7 @@ export const setStoragesTabValidity = (options: UpdateOptions) => {
         VMWizardTab.STORAGE,
         isValid,
         hasAllRequiredFilled,
-        error,
+        errorKey,
       ),
     );
   }
