@@ -1,4 +1,5 @@
 import * as React from 'react';
+import { useTranslation } from 'react-i18next';
 import {
   Dropdown,
   humanizeBinaryBytes,
@@ -20,9 +21,7 @@ import {
 import { ByteDataTypes } from '@console/shared/src/graph-helper/data-utils';
 import { VMDashboardContext } from '../../vms/vm-dashboard-context';
 import { findVMIPod } from '../../../selectors/pod/selectors';
-import { isVMRunningWithVMI } from '../../../selectors/vm';
 import { getUtilizationQueries, getMultilineUtilizationQueries, VMQueries } from './queries';
-import { getPrometheusQueryEndTimestamp } from '@console/internal/components/graphs/helpers';
 
 // TODO: extend humanizeCpuCores() from @console/internal for the flexibility of space
 const humanizeCpuCores = (v) => {
@@ -37,7 +36,7 @@ const adjustDurationForStart = (start: number, createdAt: string): number => {
   if (!createdAt) {
     return start;
   }
-  const endTimestamp = getPrometheusQueryEndTimestamp();
+  const endTimestamp = Date.now();
   const startTimestamp = endTimestamp - start;
   const createdAtTimestamp = Date.parse(createdAt);
   const adjustedStart = endTimestamp - createdAtTimestamp;
@@ -45,6 +44,7 @@ const adjustDurationForStart = (start: number, createdAt: string): number => {
 };
 
 export const VMUtilizationCard: React.FC = () => {
+  const { t } = useTranslation();
   const [timestamps, setTimestamps] = React.useState<Date[]>();
   const [duration, setDuration] = useMetricDuration();
   const { vm, vmi, pods } = React.useContext(VMDashboardContext);
@@ -52,26 +52,24 @@ export const VMUtilizationCard: React.FC = () => {
   const vmName = getName(vmiLike);
   const namespace = getNamespace(vmiLike);
   const launcherPodName = getName(findVMIPod(vmi, pods));
-  const vmIsRunning = isVMRunningWithVMI({ vm, vmi });
+  const vmiIsRunning = !!vmi;
 
   const queries = React.useMemo(
     () =>
       getUtilizationQueries({
         vmName,
-        namespace,
         launcherPodName,
       }),
-    [vmName, namespace, launcherPodName],
+    [vmName, launcherPodName],
   );
 
   const multilineQueries = React.useMemo(
     () =>
       getMultilineUtilizationQueries({
         vmName,
-        namespace,
         launcherPodName,
       }),
-    [vmName, namespace, launcherPodName],
+    [vmName, launcherPodName],
   );
 
   const createdAt = getCreationTimestamp(vmi);
@@ -83,49 +81,49 @@ export const VMUtilizationCard: React.FC = () => {
   return (
     <DashboardCard>
       <DashboardCardHeader>
-        <DashboardCardTitle>Utilization</DashboardCardTitle>
+        <DashboardCardTitle>{t('kubevirt-plugin~Utilization')}</DashboardCardTitle>
         <Dropdown items={Duration} onChange={setDuration} selectedKey={duration} title={duration} />
       </DashboardCardHeader>
       <UtilizationBody timestamps={timestamps}>
         <PrometheusUtilizationItem
-          title="CPU"
+          title={t('kubevirt-plugin~CPU')}
           utilizationQuery={queries[VMQueries.CPU_USAGE]}
           humanizeValue={humanizeCpuCores}
           duration={duration}
           adjustDuration={adjustDuration}
           setTimestamps={setTimestamps}
           namespace={namespace}
-          isDisabled={!vmIsRunning}
+          isDisabled={!vmiIsRunning}
         />
         <PrometheusUtilizationItem
-          title="Memory"
+          title={t('kubevirt-plugin~Memory')}
           utilizationQuery={queries[VMQueries.MEMORY_USAGE]}
           humanizeValue={humanizeBinaryBytes}
           byteDataType={ByteDataTypes.BinaryBytes}
           duration={duration}
           namespace={namespace}
           adjustDuration={adjustDuration}
-          isDisabled={!vmIsRunning}
+          isDisabled={!vmiIsRunning}
         />
         <PrometheusUtilizationItem
-          title="Filesystem"
+          title={t('kubevirt-plugin~Filesystem')}
           utilizationQuery={queries[VMQueries.FILESYSTEM_USAGE]}
           humanizeValue={humanizeBinaryBytes}
           byteDataType={ByteDataTypes.BinaryBytes}
           duration={duration}
           namespace={namespace}
           adjustDuration={adjustDuration}
-          isDisabled={!vmIsRunning}
+          isDisabled={!vmiIsRunning}
         />
         <PrometheusMultilineUtilizationItem
-          title="Network Transfer"
+          title={t('kubevirt-plugin~Network Transfer')}
           queries={multilineQueries[VMQueries.NETWORK_USAGE]}
           humanizeValue={humanizeBinaryBytes}
           byteDataType={ByteDataTypes.BinaryBytes}
           duration={duration}
           namespace={namespace}
           adjustDuration={adjustDuration}
-          isDisabled={!vmIsRunning}
+          isDisabled={!vmiIsRunning}
         />
       </UtilizationBody>
     </DashboardCard>
