@@ -1,8 +1,9 @@
 import * as React from 'react';
-import { navFactory, HintBlock, ExternalLink } from '@console/internal/components/utils';
+import { useTranslation } from 'react-i18next';
+import { navFactory } from '@console/internal/components/utils';
 import { DetailsPage } from '@console/internal/components/factory';
-import { PodModel, TemplateModel } from '@console/internal/models';
-import { VMDisksFirehose } from '../vm-disks';
+import { PodModel } from '@console/internal/models';
+import { VMDisksAndFileSystemsPage } from '../vm-disks/vm-disks';
 import { VMNics } from '../vm-nics';
 import {
   VirtualMachineInstanceMigrationModel,
@@ -21,44 +22,43 @@ import { VMConsoleFirehose } from './vm-console';
 import { VMDetailsFirehose } from './vm-details';
 import { vmiMenuActionsCreator } from './menu-actions';
 import { VMDashboard } from './vm-dashboard';
-import { TEMPLATE_TYPE_LABEL, TEMPLATE_TYPE_VM } from '../../constants/vm';
+import VMIDetailsPageInfoMessage from '../info-messages/VMIDetailsPageInfoMessage';
 import { breadcrumbsForVMPage } from './vm-details-page';
 
-import './vmi-details-page.scss';
-
 export const VirtualMachinesInstanceDetailsPage: React.FC<VirtualMachinesInstanceDetailsPageProps> = (
   props,
 ) => {
+  const { t } = useTranslation();
   const { name, ns: namespace } = props.match.params;
 
   const overviewPage = {
     href: '', // default landing page
-    name: 'Overview',
+    name: t('kubevirt-plugin~Overview'),
     component: VMDashboard,
   };
 
   const detailsPage = {
     href: VM_DETAIL_DETAILS_HREF,
-    name: 'Details',
+    name: t('kubevirt-plugin~Details'),
     component: VMDetailsFirehose,
   };
 
   const consolePage = {
     href: VM_DETAIL_CONSOLES_HREF,
-    name: 'Consoles',
+    name: t('kubevirt-plugin~Console'),
     component: VMConsoleFirehose,
   };
 
   const nicsPage = {
     href: VM_DETAIL_NETWORKS_HREF,
-    name: 'Network Interfaces',
+    name: t('kubevirt-plugin~Network Interfaces'),
     component: VMNics,
   };
 
   const disksPage = {
     href: VM_DETAIL_DISKS_HREF,
-    name: 'Disks',
-    component: VMDisksFirehose,
+    name: t('kubevirt-plugin~Disks'),
+    component: VMDisksAndFileSystemsPage,
   };
 
   const pages = [
@@ -81,12 +81,6 @@ export const VirtualMachinesInstanceDetailsPage: React.FC<VirtualMachinesInstanc
     }),
     getResource(PodModel, { namespace, prop: 'pods' }),
     getResource(VirtualMachineInstanceMigrationModel, { namespace, prop: 'migrations' }),
-    getResource(TemplateModel, {
-      isList: true,
-      namespace,
-      prop: 'templates',
-      matchLabels: { [TEMPLATE_TYPE_LABEL]: TEMPLATE_TYPE_VM },
-    }),
   ];
 
   return (
@@ -99,23 +93,10 @@ export const VirtualMachinesInstanceDetailsPage: React.FC<VirtualMachinesInstanc
       menuActions={vmiMenuActionsCreator}
       pages={pages}
       resources={resources}
-      breadcrumbsFor={breadcrumbsForVMPage(props.match)}
+      breadcrumbsFor={breadcrumbsForVMPage(t, props.match)}
       customData={{ kindObj: VirtualMachineInstanceModel }}
     >
-      <HintBlock
-        className="kubevirt-details-page__hint-block"
-        title={`Virtual Machine Instance ${name}`}
-      >
-        <p>
-          This is a VirtualMachineInstance overview page. Please consider using a VirtualMachine
-          that will provide additional management capabilities to a VirtualMachineInstance inside
-          the cluster.
-        </p>
-        <ExternalLink
-          href="https://kubevirt.io/user-guide/#/architecture?id=virtualmachine"
-          text="Learn more"
-        />
-      </HintBlock>
+      <VMIDetailsPageInfoMessage name={name} namespace={namespace} />
     </DetailsPage>
   );
 };
