@@ -1,14 +1,14 @@
-import { K8sResourceKind } from '@console/internal/module/k8s';
+import * as _ from 'lodash';
+import { K8sResourceKind, PersistentVolumeClaimKind } from '@console/internal/module/k8s';
 import { createBasicLookup, getName, getNamespace } from '@console/shared';
-import { VMKind } from '../../types/vm';
-import { getBasicID, joinIDs } from '../../utils';
+import { V1DataVolumeTemplateSpec, VMKind } from '../../types/vm';
+import { generateDataVolumeName, getBasicID } from '../../utils';
 import {
   getPvcAccessModes,
   getPvcStorageClassName,
   getPvcStorageSize,
   getPvcVolumeMode,
 } from '../../selectors/pvc/selectors';
-import { DataVolumeTemplate } from '../objects/vm/datavolume-template';
 import {
   getOperatingSystem,
   getOperatingSystemName,
@@ -88,7 +88,7 @@ export class VMClone {
     return this;
   }
 
-  withClonedPVCs = (persistentVolumeClaimsToClone: K8sResourceKind[]) => {
+  withClonedPVCs = (persistentVolumeClaimsToClone: PersistentVolumeClaimKind[]) => {
     const pvcLookup = createBasicLookup(persistentVolumeClaimsToClone, getBasicID);
     const name = this.vm.getName();
 
@@ -102,15 +102,29 @@ export class VMClone {
         const pvc = pvcLookup[`${this.oldVMNamespace}-${pvcName}`];
 
         if (pvc) {
-          const clonedDVTemplate = new DataVolumeTemplate({
-            name: joinIDs(name, pvcName, 'clone'),
-            pvcSourceName: pvcName,
-            pvcSourceNamespace: this.oldVMNamespace,
-            accessModes: getPvcAccessModes(pvc),
-            volumeMode: getPvcVolumeMode(pvc),
-            size: getPvcStorageSize(pvc),
-            storageClassName: getPvcStorageClassName(pvc),
-          }).build();
+          const clonedDVTemplate: V1DataVolumeTemplateSpec = {
+            metadata: {
+              name: generateDataVolumeName(name, volume.name),
+            },
+            spec: {
+              pvc: {
+                accessModes: _.cloneDeep(getPvcAccessModes(pvc)),
+                volumeMode: getPvcVolumeMode(pvc),
+                resources: {
+                  requests: {
+                    storage: getPvcStorageSize(pvc),
+                  },
+                },
+                storageClassName: getPvcStorageClassName(pvc),
+              },
+              source: {
+                pvc: {
+                  name: pvcName,
+                  namespace: this.oldVMNamespace,
+                },
+              },
+            },
+          };
 
           this.vm.ensureDataVolumeTemplates().push(clonedDVTemplate);
 
@@ -134,15 +148,29 @@ export class VMClone {
         const dataVolume = dvLookup[`${this.oldVMNamespace}-${dvName}`];
 
         if (dataVolume) {
-          const clonedDVTemplate = new DataVolumeTemplate({
-            name: joinIDs(name, dvName, 'clone'),
-            pvcSourceName: dvName,
-            pvcSourceNamespace: this.oldVMNamespace,
-            accessModes: getDataVolumeAccessModes(dataVolume),
-            volumeMode: getDataVolumeVolumeMode(dataVolume),
-            size: getDataVolumeStorageSize(dataVolume),
-            storageClassName: getDataVolumeStorageClassName(dataVolume),
-          }).build();
+          const clonedDVTemplate: V1DataVolumeTemplateSpec = {
+            metadata: {
+              name: generateDataVolumeName(name, volume.name),
+            },
+            spec: {
+              pvc: {
+                accessModes: _.cloneDeep(getDataVolumeAccessModes(dataVolume)),
+                volumeMode: getDataVolumeVolumeMode(dataVolume),
+                resources: {
+                  requests: {
+                    storage: getDataVolumeStorageSize(dataVolume),
+                  },
+                },
+                storageClassName: getDataVolumeStorageClassName(dataVolume),
+              },
+              source: {
+                pvc: {
+                  name: dvName,
+                  namespace: this.oldVMNamespace,
+                },
+              },
+            },
+          };
 
           this.vm.ensureDataVolumeTemplates().push(clonedDVTemplate);
 
