@@ -85,16 +85,17 @@ const getNetworkMappings = (networks: VMWizardNetwork[]) => {
 const getDiskMappings = (storage: VMWizardStorage[]) =>
   storage
     .filter(({ type, importData }) => type === VMWizardStorageType.V2V_OVIRT_IMPORT && importData)
-    .map(
-      ({ persistentVolumeClaim, importData: { id } }) =>
-        ({
-          source: { id },
-          target: {
-            name:
-              new PersistentVolumeClaimWrapper(persistentVolumeClaim).getStorageClassName() || '',
-          },
-        } as DiskMapping),
-    );
+    .map(({ persistentVolumeClaim, importData: { id } }) => {
+      const persistentVolumeClaimWrapper = new PersistentVolumeClaimWrapper(persistentVolumeClaim);
+
+      return {
+        source: { id },
+        target: {
+          name: persistentVolumeClaimWrapper.getStorageClassName() || '',
+        },
+        volumeMode: persistentVolumeClaimWrapper.getVolumeMode() || null,
+      } as DiskMapping;
+    });
 
 const createVMImport = async (
   {
@@ -111,6 +112,7 @@ const createVMImport = async (
   const targetVMName = simpleSettings[VMSettingsField.NAME];
   const description = simpleSettings[VMSettingsField.DESCRIPTION];
   const vm = getOvirtAttribute(importProviders, OvirtProviderField.VM, 'vm');
+  const secretWrapper = new SecretWrappper(secret);
   const vmAnnotations = {};
 
   if (description) {
@@ -122,10 +124,7 @@ const createVMImport = async (
     .setType(VMImportType.OVIRT)
     .setTargetVMName(targetVMName)
     .setStartVM(simpleSettings[VMSettingsField.START_VM])
-    .setCredentialsSecret(
-      getOvirtField(importProviders, OvirtProviderField.CURRENT_RESOLVED_OVIRT_ENGINE_SECRET_NAME),
-      namespace,
-    );
+    .setCredentialsSecret(secretWrapper.getName(), secretWrapper.getNamespace());
 
   if (!_.isEmpty(vmAnnotations)) {
     vmImport.addAnotation(
@@ -144,8 +143,6 @@ const createVMImport = async (
   const vmImportResult = await enhancedK8sMethods.k8sWrapperCreate(vmImport);
   const vmImportOwnerReference = buildOwnerReference(vmImportResult);
 
-  const secretWrapper = new SecretWrappper(secret);
-
   await enhancedK8sMethods.k8sWrapperPatch(secretWrapper, [
     new PatchBuilder('/metadata/ownerReferences')
       .setListUpdate(
