@@ -1,7 +1,6 @@
 import { DefaultVMLikeEntityParams } from './types';
 import { TemplateKind } from '@console/internal/module/k8s';
 import { VMTemplateWrapper } from '../../../wrapper/vm/vm-template-wrapper';
-import { VM_TEMPLATE_NAME_PARAMETER } from '../../../../constants/vm-templates';
 import {
   DiskBus,
   DiskType,
@@ -20,6 +19,12 @@ import { getFlavor, getWorkloadProfile } from '../../../../selectors/vm';
 import { DiskWrapper } from '../../../wrapper/vm/disk-wrapper';
 import { VolumeWrapper } from '../../../wrapper/vm/volume-wrapper';
 import { NetworkInterfaceWrapper } from '../../../wrapper/vm/network-interface-wrapper';
+import { VM_TEMPLATE_NAME_PARAMETER } from '../../../../constants/vm-templates/constants';
+import {
+  CloudInitDataHelper,
+  CloudInitDataFormKeys,
+  generateCloudInitPassword,
+} from '../../../wrapper/vm/cloud-init-data-helper';
 
 export const resolveDefaultVMTemplate = (params: DefaultVMLikeEntityParams): TemplateKind => {
   const { commonTemplate, name, namespace, containerImage, baseOSName } = params;
@@ -39,6 +44,7 @@ export const resolveDefaultVMTemplate = (params: DefaultVMLikeEntityParams): Tem
       }),
     )
     .removeStorage('rootdisk')
+    .removeStorage(VM_TEMPLATE_NAME_PARAMETER)
     .prependStorage({
       disk: new DiskWrapper()
         .init({
@@ -55,6 +61,17 @@ export const resolveDefaultVMTemplate = (params: DefaultVMLikeEntityParams): Tem
         .asResource(),
     });
 
+  const cloudInitVolume = vm.getCloudInitVolume();
+  const cloudInitHelper = new CloudInitDataHelper(cloudInitVolume?.cloudInitNoCloud);
+  if (!cloudInitHelper.isEmpty() && cloudInitHelper.hasKey(CloudInitDataFormKeys.PASSWORD)) {
+    cloudInitHelper.set(CloudInitDataFormKeys.PASSWORD, generateCloudInitPassword());
+    vm.updateVolume(
+      new VolumeWrapper(cloudInitVolume)
+        .setTypeData(cloudInitHelper.asCloudInitNoCloudSource())
+        .asResource(),
+    );
+  }
+
   const finalTemplate = new VMTemplateWrapper().init({
     name,
     namespace,
@@ -78,18 +95,18 @@ export const resolveDefaultVMTemplate = (params: DefaultVMLikeEntityParams): Tem
     `${TEMPLATE_OS_NAME_ANNOTATION}/${osID}`,
   );
 
-  initializeCommonMetadata(
-    {
-      [VMSettingsField.DESCRIPTION]: 'VM template example',
-      [VMSettingsField.FLAVOR]: getFlavor(commonTemplate),
-      [VMSettingsField.WORKLOAD_PROFILE]: getWorkloadProfile(commonTemplate),
-      osID,
-      osName,
-    },
-    finalTemplate,
-    commonTemplate,
-  );
-  initializeCommonTemplateMetadata(finalTemplate, commonTemplate);
+  const settings = {
+    [VMSettingsField.DESCRIPTION]: 'VM template example',
+    [VMSettingsField.FLAVOR]: getFlavor(commonTemplate),
+    [VMSettingsField.WORKLOAD_PROFILE]: getWorkloadProfile(commonTemplate),
+    [VMSettingsField.TEMPLATE_PROVIDER]: null,
+    [VMSettingsField.TEMPLATE_SUPPORTED]: null,
+    osID,
+    osName,
+  };
+
+  initializeCommonMetadata(settings, finalTemplate, commonTemplate);
+  initializeCommonTemplateMetadata(settings, finalTemplate, commonTemplate);
 
   return finalTemplate.asResource();
 };
