@@ -1,10 +1,10 @@
 import * as React from 'react';
 import * as _ from 'lodash';
 import { AlertVariant } from '@patternfly/react-core';
+import { VirtualMachineIcon } from '@patternfly/react-icons';
 import {
   Plugin,
   ResourceNSNavItem,
-  OverviewCRD,
   ResourceListPage,
   ResourceDetailsPage,
   ModelFeatureFlag,
@@ -22,11 +22,14 @@ import {
   PVCAlert,
   PVCStatus,
   PVCDelete,
+  CatalogItemProvider,
+  CatalogItemType,
+  CatalogItemFilter,
 } from '@console/plugin-sdk';
 import { DashboardsStorageCapacityDropdownItem } from '@console/ceph-storage-plugin';
 import { TemplateModel, PodModel, PersistentVolumeClaimModel } from '@console/internal/models';
 import { getName } from '@console/shared/src/selectors/common';
-import { FirehoseResource } from '@console/internal/components/utils';
+import '@console/internal/i18n.js';
 import * as models from './models';
 import { VMTemplateYAMLTemplates, VirtualMachineYAMLTemplates } from './models/templates';
 import { getKubevirtHealthState } from './components/dashboards-page/overview-dashboard/health';
@@ -43,11 +46,12 @@ import {
 } from './components/cdi-upload-provider/cdi-upload-provider';
 import { killCDIBoundPVC } from './components/cdi-upload-provider/pvc-delete-extension';
 import { isPvcBoundToCDI, isPvcUploading } from './selectors/pvc/selectors';
+import { AddAction } from '../../dev-console/src/extensions/add-actions';
 import './style.scss';
+import { getExecutableCodeRef } from '@console/dynamic-plugin-sdk/src/coderefs/coderef-utils';
 
 type ConsumedExtensions =
   | ResourceNSNavItem
-  | OverviewCRD
   | ResourceListPage
   | ResourceDetailsPage
   | ModelFeatureFlag
@@ -66,64 +70,14 @@ type ConsumedExtensions =
   | PVCCreateProp
   | PVCAlert
   | PVCStatus
-  | PVCDelete;
+  | PVCDelete
+  | AddAction
+  | CatalogItemProvider
+  | CatalogItemType
+  | CatalogItemFilter;
 
 export const FLAG_KUBEVIRT = 'KUBEVIRT';
 
-const virtualMachineConfigurations = (namespace: string): FirehoseResource[] => {
-  const virtualMachineResource = [
-    {
-      isList: true,
-      kind: models.VirtualMachineModel.kind,
-      namespace,
-      prop: 'virtualmachines',
-      optional: true,
-    },
-    {
-      isList: true,
-      kind: models.VirtualMachineInstanceModel.kind,
-      namespace,
-      prop: 'virtualmachineinstances',
-      optional: true,
-    },
-    {
-      isList: true,
-      kind: TemplateModel.kind,
-      prop: 'virtualmachinetemplates',
-      selector: {
-        matchLabels: { 'template.kubevirt.io/type': 'base' },
-      },
-      optional: true,
-    },
-    {
-      isList: true,
-      kind: models.VirtualMachineInstanceMigrationModel.kind,
-      namespace,
-      prop: 'migrations',
-      optional: true,
-    },
-    {
-      isList: true,
-      optional: true,
-      kind: PersistentVolumeClaimModel.kind,
-      prop: 'pvcs',
-    },
-    {
-      isList: true,
-      optional: true,
-      kind: models.DataVolumeModel.kind,
-      prop: 'dataVolumes',
-    },
-    {
-      isList: true,
-      optional: true,
-      kind: models.VirtualMachineImportModel.kind,
-      prop: 'vmImports',
-    },
-  ];
-  return virtualMachineResource;
-};
-
 const plugin: Plugin<ConsumedExtensions> = [
   {
     type: 'ModelDefinition',
@@ -138,24 +92,17 @@ const plugin: Plugin<ConsumedExtensions> = [
       flag: FLAG_KUBEVIRT,
     },
   },
-  {
-    type: 'Overview/CRD',
-    properties: {
-      resources: virtualMachineConfigurations,
-    },
-    flags: {
-      required: [FLAG_KUBEVIRT],
-    },
-  },
   {
     type: 'NavItem/ResourceNS',
     properties: {
-      section: 'Workloads',
+      id: 'virtualization',
+      section: 'workloads',
       componentProps: {
-        name: 'Virtualization',
+        // t('kubevirt-plugin~Virtualization')
+        name: '%kubevirt-plugin~Virtualization%',
         resource: 'virtualization',
       },
-      mergeBefore: 'Deployments',
+      insertBefore: 'deployments',
     },
     flags: {
       required: [FLAG_KUBEVIRT],
@@ -218,6 +165,20 @@ const plugin: Plugin<ConsumedExtensions> = [
       required: [FLAG_KUBEVIRT],
     },
   },
+  {
+    type: 'Page/Route',
+    properties: {
+      exact: true,
+      path: ['/k8s/virtualization/~new-from-template'],
+      loader: () =>
+        import(
+          './components/create-vm/create-vm' /* webpackChunkName: "kubevirt-create-vm" */
+        ).then((m) => m.CreateVM),
+    },
+    flags: {
+      required: [FLAG_KUBEVIRT],
+    },
+  },
   {
     type: 'Page/Route',
     properties: {
@@ -312,6 +273,32 @@ const plugin: Plugin<ConsumedExtensions> = [
       required: [FLAG_KUBEVIRT],
     },
   },
+  {
+    type: 'Page/Route',
+    properties: {
+      path: '/k8s/ns/:ns/virtualmachinesnapshots/:name',
+      loader: () =>
+        import(
+          './components/vm-snapshots/vm-snapshot-details' /* webpackChunkName: "kubevirt" */
+        ).then((m) => m.SnapshotDetailsPage),
+    },
+    flags: {
+      required: [FLAG_KUBEVIRT],
+    },
+  },
+  {
+    type: 'Page/Route',
+    properties: {
+      path: '/catalog/create-vm',
+      loader: () =>
+        import(
+          './components/create-vm/dev-console/dev-console-create-vm-form' /* webpackChunkName: "kubevirt" */
+        ).then((m) => m.DevConsoleCreateVmForm),
+    },
+    flags: {
+      required: [FLAG_KUBEVIRT],
+    },
+  },
   {
     type: 'Dashboards/Overview/Health/URL',
     properties: {
@@ -548,6 +535,70 @@ const plugin: Plugin<ConsumedExtensions> = [
       required: [FLAG_KUBEVIRT],
     },
   },
+  {
+    type: 'AddAction',
+    properties: {
+      id: 'dev-catalog-virtualization',
+      url: '/catalog?catalogType=VmTemplate',
+      // t('kubevirt-plugin~Virtual Machines')
+      label: '%kubevirt-plugin~Virtual Machines%',
+      // t('kubevirt-plugin~Create a Virtual Machine from a template')
+      description: '%kubevirt-plugin~Create a Virtual Machine from a template%',
+      icon: <VirtualMachineIcon />,
+    },
+    flags: {
+      required: [FLAG_KUBEVIRT],
+    },
+  },
+  {
+    type: 'Catalog/ItemType',
+    properties: {
+      type: 'VmTemplate',
+      // t('kubevirt-plugin~Virtual Machines')
+      title: '%kubevirt-plugin~Virtual Machines%',
+      // t('kubevirt-plugin~Quickly create a virtual machine from a template.')
+      catalogDescription: '%kubevirt-plugin~Quickly create a virtual machine from a template.%',
+      // t('kubevirt-plugin~**Virtual Machines** are templates for quickly creating a virtual machine.')
+      typeDescription:
+        '%kubevirt-plugin~**Virtual Machines** are templates for quickly creating a virtual machine.%',
+      filters: [
+        {
+          // t('kubevirt-plugin~Template Providers')
+          label: '%kubevirt-plugin~Template Providers%',
+          attribute: 'templateProvider',
+        },
+      ],
+    },
+    flags: {
+      required: [FLAG_KUBEVIRT],
+    },
+  },
+  {
+    type: 'Catalog/ItemProvider',
+    properties: {
+      type: 'VmTemplate',
+      provider: getExecutableCodeRef(() =>
+        import(
+          './components/create-vm/dev-console/use-catalog-vm-templates' /* webpackChunkName: "kubevirt" */
+        ).then((m) => m.default),
+      ),
+    },
+    flags: {
+      required: [FLAG_KUBEVIRT],
+    },
+  },
+
+  {
+    type: 'Catalog/ItemFilter',
+    properties: {
+      type: 'Template',
+      filter: getExecutableCodeRef(() =>
+        import(
+          './components/create-vm/dev-console/dev-catalog-vm-templates-filter' /* webpackChunkName: "kubevirt" */
+        ).then((m) => m.default),
+      ),
+    },
+  },
 ];
 
 export default plugin;
