@@ -1,3 +1,5 @@
+import { TFunction } from 'i18next';
+
 export const COULD_NOT_LOAD_DATA = 'Could not load data';
 
 export const CREATED = 'created';
@@ -7,20 +9,27 @@ export const FAILED_TO_CREATE = 'failed to create';
 export const FAILED_TO_PATCH = 'failed to patch';
 export const DYNAMIC = 'Dynamic';
 
-export const EDIT = 'Edit';
-export const SAVE = 'Save';
-export const ADD = 'Add';
+export const READY = 'Ready';
 
-export const ADD_DISK = 'Add Disk';
-export const ADD_NETWORK_INTERFACE = 'Add Network Interface';
+export const EXAMPLE_CONTAINER = 'kubevirt/fedora-cloud-container-disk-demo';
+export const FEDORA_IMAGE_LINK = 'https://alt.fedoraproject.org/cloud/';
+export const RHEL_IMAGE_LINK =
+  'https://access.redhat.com/downloads/content/479/ver=/rhel---8/8.2/x86_64/product-software';
+export const CLOUD_INIT_MISSING_USERNAME =
+  'No username set, see operating system documentation for the default username.';
+export const CLOUD_INIT_DOC_LINK = 'https://cloudinit.readthedocs.io/en/latest/index.html';
+export const STORAGE_CLASS_SUPPORTED_MATRIX_DOC_LINK =
+  'https://docs.openshift.com/container-platform/4.6/virt/virtual_machines/virtual_disks/virt-features-for-storage.html';
 
-export const getDialogUIError = (hasAllRequiredFilled) =>
+export const getDialogUIError = (hasAllRequiredFilled, t: TFunction) =>
   hasAllRequiredFilled
-    ? 'Please correct the invalid fields.'
-    : 'Please fill in all required fields.';
+    ? t('kubevirt-plugin~Please correct the invalid fields.')
+    : t('kubevirt-plugin~Please fill in all required fields.');
 
-export const getSimpleDialogUIError = (hasAllRequiredFilled) =>
-  hasAllRequiredFilled ? 'Some fields are not correct' : 'Required fields not completed';
+export const getSimpleDialogUIError = (hasAllRequiredFilled, t: TFunction) =>
+  hasAllRequiredFilled
+    ? t('kubevirt-plugin~Some fields are not correct')
+    : t('kubevirt-plugin~Required fields not completed');
 
 export const getBooleanReadableValue = (value: boolean) => (value ? 'yes' : 'no');
 
