@@ -2,7 +2,7 @@ import { K8sResourceKind } from '@console/internal/module/k8s';
 import { getDeletetionTimestamp } from '@console/shared/src/selectors';
 import { getNodeMaintenancePhase } from '../selectors';
 import {
-  NODE_STATUS_TITLES,
+  NODE_STATUS_TITLE_KEYS,
   NODE_STATUS_UNDER_MAINTENANCE,
   NODE_STATUS_STOPPING_MAINTENANCE,
   NODE_STATUS_STARTING_MAINTENANCE,
@@ -15,17 +15,17 @@ export const getNodeMaintenanceStatus = (maintenance: K8sResourceKind): StatusPr
   if (getDeletetionTimestamp(maintenance)) {
     return {
       status: NODE_STATUS_STOPPING_MAINTENANCE,
-      title: NODE_STATUS_TITLES[NODE_STATUS_STOPPING_MAINTENANCE],
+      titleKey: NODE_STATUS_TITLE_KEYS[NODE_STATUS_STOPPING_MAINTENANCE],
     };
   }
   if (getNodeMaintenancePhase(maintenance) === 'Succeeded') {
     return {
       status: NODE_STATUS_UNDER_MAINTENANCE,
-      title: NODE_STATUS_TITLES[NODE_STATUS_UNDER_MAINTENANCE],
+      titleKey: NODE_STATUS_TITLE_KEYS[NODE_STATUS_UNDER_MAINTENANCE],
     };
   }
   return {
     status: NODE_STATUS_STARTING_MAINTENANCE,
-    title: NODE_STATUS_TITLES[NODE_STATUS_STARTING_MAINTENANCE],
+    titleKey: NODE_STATUS_TITLE_KEYS[NODE_STATUS_STARTING_MAINTENANCE],
   };
 };
