@@ -3,7 +3,13 @@ import * as _ from 'lodash';
 import { shallow, ShallowWrapper } from 'enzyme';
 import { Link } from 'react-router-dom';
 import { Button } from '@patternfly/react-core';
-import { Table, TableRow, MultiListPage, DetailsPage } from '@console/internal/components/factory';
+import {
+  Table,
+  MultiListPage,
+  DetailsPage,
+  RowFunctionArgs,
+  TableRow,
+} from '@console/internal/components/factory';
 import {
   ResourceKebab,
   ResourceLink,
@@ -18,17 +24,13 @@ import { testInstallPlan } from '../../mocks';
 import { InstallPlanModel, ClusterServiceVersionModel, OperatorGroupModel } from '../models';
 import { InstallPlanKind, InstallPlanApproval } from '../types';
 import {
-  InstallPlanTableHeader,
   InstallPlanTableRow,
-  InstallPlanTableRowProps,
   InstallPlansList,
   InstallPlansListProps,
   InstallPlansPage,
   InstallPlansPageProps,
   InstallPlanDetailsPage,
   InstallPlanPreview,
-  InstallPlanPreviewProps,
-  InstallPlanPreviewState,
   InstallPlanDetailsPageProps,
   InstallPlanDetails,
   InstallPlanDetailsProps,
@@ -40,64 +42,67 @@ import { referenceForStepResource } from '.';
 
 import Spy = jasmine.Spy;
 
-// Prevent failures if column order is changed
-const COLUMNS = InstallPlanTableHeader();
-const NAME_INDEX = _.findIndex(COLUMNS, (c) => c.title === 'Name');
-const NAMESPACE_INDEX = _.findIndex(COLUMNS, (c) => c.title === 'Namespace');
-const STATUS_INDEX = _.findIndex(COLUMNS, (c) => c.title === 'Status');
-const COMPONENTS_INDEX = _.findIndex(COLUMNS, (c) => c.title === 'Components');
-const SUBSCRIPTIONS_INDEX = _.findIndex(COLUMNS, (c) => c.title === 'Subscriptions');
-
-describe(InstallPlanTableHeader.displayName, () => {
-  it('returns column header definition for install plans', () => {
-    expect(Array.isArray(InstallPlanTableHeader()));
-  });
+jest.mock('react-i18next', () => {
+  const reactI18next = require.requireActual('react-i18next');
+  return {
+    ...reactI18next,
+    useTranslation: () => ({ t: (key) => key }),
+  };
 });
 
-describe(InstallPlanTableRow.displayName, () => {
-  let wrapper: ShallowWrapper<InstallPlanTableRowProps>;
+const i18nNS = 'details-page';
+
+describe('InstallPlanTableRow', () => {
+  let obj: InstallPlanKind;
+  let wrapper: ShallowWrapper;
+
+  const updateWrapper = () => {
+    const rowArgs: RowFunctionArgs<k8s.K8sResourceKind> = {
+      obj,
+      index: 0,
+      key: '0',
+      style: {},
+    } as any;
+
+    wrapper = shallow(<InstallPlanTableRow {...rowArgs} />);
+    return wrapper;
+  };
 
   beforeEach(() => {
-    wrapper = shallow(
-      <InstallPlanTableRow obj={_.cloneDeep(testInstallPlan)} index={0} style={{}} />,
-    );
+    obj = _.cloneDeep(testInstallPlan);
+    wrapper = updateWrapper();
   });
 
   it('renders resource kebab for performing common actions', () => {
-    expect(
-      wrapper
-        .find(TableRow)
-        .find(ResourceKebab)
-        .props().actions,
-    ).toEqual(Kebab.factory.common);
+    expect(wrapper.find(ResourceKebab).props().actions).toEqual(Kebab.factory.common);
   });
 
   it('renders column for install plan name', () => {
     expect(
       wrapper
         .find(TableRow)
-        .childAt(NAME_INDEX)
+        .childAt(0)
         .find(ResourceLink)
         .props().kind,
     ).toEqual(k8s.referenceForModel(InstallPlanModel));
     expect(
       wrapper
         .find(TableRow)
-        .childAt(NAME_INDEX)
+        .childAt(0)
         .find(ResourceLink)
         .props().namespace,
     ).toEqual(testInstallPlan.metadata.namespace);
     expect(
       wrapper
         .find(TableRow)
-        .childAt(NAME_INDEX)
+        .childAt(0)
         .find(ResourceLink)
         .props().name,
     ).toEqual(testInstallPlan.metadata.name);
     expect(
       wrapper
         .find(TableRow)
-        .childAt(NAME_INDEX)
+        .childAt(0)
         .find(ResourceLink)
         .props().title,
     ).toEqual(testInstallPlan.metadata.uid);
@@ -107,21 +112,21 @@ describe(InstallPlanTableRow.displayName, () => {
     expect(
       wrapper
         .find(TableRow)
-        .childAt(NAMESPACE_INDEX)
+        .childAt(1)
         .find(ResourceLink)
         .props().kind,
     ).toEqual('Namespace');
     expect(
       wrapper
         .find(TableRow)
-        .childAt(NAMESPACE_INDEX)
+        .childAt(1)
         .find(ResourceLink)
         .props().title,
     ).toEqual(testInstallPlan.metadata.namespace);
     expect(
       wrapper
         .find(TableRow)
-        .childAt(NAMESPACE_INDEX)
+        .childAt(1)
         .find(ResourceLink)
         .props().displayName,
     ).toEqual(testInstallPlan.metadata.namespace);
@@ -131,33 +136,34 @@ describe(InstallPlanTableRow.displayName, () => {
     expect(
       wrapper
         .find(TableRow)
-        .childAt(STATUS_INDEX)
+        .childAt(2)
         .render()
+        .find('[data-test="status-text"]')
         .text(),
     ).toEqual(testInstallPlan.status.phase);
   });
 
   it('renders column with fallback status if `status.phase` is undefined', () => {
-    const obj = { ..._.cloneDeep(testInstallPlan), status: null };
-    wrapper = wrapper.setProps({ obj });
+    obj = { ..._.cloneDeep(testInstallPlan), status: null };
+    wrapper = updateWrapper();
 
     expect(
       wrapper
         .find(TableRow)
-        .childAt(STATUS_INDEX)
+        .childAt(2)
         .render()
         .text(),
     ).toEqual('Unknown');
     expect(
       wrapper
         .find(TableRow)
-        .childAt(COMPONENTS_INDEX)
+        .childAt(3)
         .find(ResourceIcon).length,
     ).toEqual(1);
     expect(
       wrapper
         .find(TableRow)
-        .childAt(COMPONENTS_INDEX)
+        .childAt(3)
         .find(ResourceIcon)
         .at(0)
         .props().kind,
@@ -168,21 +174,21 @@ describe(InstallPlanTableRow.displayName, () => {
     expect(
       wrapper
         .find(TableRow)
-        .childAt(COMPONENTS_INDEX)
+        .childAt(3)
         .find(ResourceLink)
         .props().kind,
     ).toEqual(k8s.referenceForModel(ClusterServiceVersionModel));
     expect(
       wrapper
         .find(TableRow)
-        .childAt(COMPONENTS_INDEX)
+        .childAt(3)
         .find(ResourceLink)
         .props().name,
     ).toEqual(testInstallPlan.spec.clusterServiceVersionNames.toString());
     expect(
       wrapper
         .find(TableRow)
-        .childAt(COMPONENTS_INDEX)
+        .childAt(3)
         .find(ResourceLink)
         .props().namespace,
     ).toEqual(testInstallPlan.metadata.namespace);
@@ -192,13 +198,13 @@ describe(InstallPlanTableRow.displayName, () => {
     expect(
       wrapper
         .find(TableRow)
-        .childAt(SUBSCRIPTIONS_INDEX)
+        .childAt(4)
         .find(ResourceLink).length,
     ).toEqual(1);
   });
 });
 
-describe(InstallPlansList.displayName, () => {
+describe('InstallPlansList', () => {
   let wrapper: ShallowWrapper<InstallPlansListProps>;
 
   beforeEach(() => {
@@ -206,22 +212,32 @@ describe(InstallPlansList.displayName, () => {
   });
 
   it('renders a `Table` component with the correct props', () => {
-    expect(wrapper.find<any>(Table).props().Header).toEqual(InstallPlanTableHeader);
-    expect(wrapper.find<any>(Table).props().Row).toEqual(InstallPlanTableRow);
+    const headerTitles = wrapper
+      .find(Table)
+      .props()
+      .Header()
+      .map((header) => header.title);
+    expect(headerTitles).toEqual([
+      'olm~Name',
+      'olm~Namespace',
+      'olm~Status',
+      'olm~Components',
+      'olm~Subscriptions',
+      '',
+    ]);
   });
 
   it('passes custom empty message for table', () => {
-    const { EmptyMsg } = wrapper.find<any>(Table).props();
-    const msgWrapper = shallow(<EmptyMsg />);
-
-    expect(msgWrapper.find(MsgBox).props().title).toEqual('No Install Plans Found');
+    const MsgComponent = wrapper.find<any>(Table).props().EmptyMsg;
+    const msgWrapper = shallow(<MsgComponent />);
+    expect(msgWrapper.find(MsgBox).props().title).toEqual('olm~No InstallPlans found');
     expect(msgWrapper.find(MsgBox).props().detail).toEqual(
-      'Install Plans are created automatically by subscriptions or manually using the CLI.',
+      'olm~InstallPlans are created automatically by subscriptions or manually using the CLI.',
     );
   });
 });
 
-describe(InstallPlansPage.displayName, () => {
+describe('InstallPlansPage', () => {
   let wrapper: ShallowWrapper<InstallPlansPageProps>;
   const match: any = {
     params: {
@@ -234,7 +250,7 @@ describe(InstallPlansPage.displayName, () => {
   });
 
   it('renders a `MultiListPage` with the correct props', () => {
-    expect(wrapper.find(MultiListPage).props().title).toEqual('Install Plans');
+    expect(wrapper.find(MultiListPage).props().title).toEqual('olm~InstallPlans');
     expect(wrapper.find(MultiListPage).props().showTitle).toBe(false);
     expect(wrapper.find(MultiListPage).props().ListComponent).toEqual(InstallPlansList);
     expect(wrapper.find(MultiListPage).props().resources).toEqual([
@@ -254,9 +270,39 @@ describe(InstallPlansPage.displayName, () => {
   });
 });
 
-describe(InstallPlanPreview.name, () => {
-  let wrapper: ShallowWrapper<InstallPlanPreviewProps, InstallPlanPreviewState>;
-  let installPlan: InstallPlanKind;
+describe('InstallPlanPreview', () => {
+  // let wrapper: ShallowWrapper<InstallPlanPreviewProps, InstallPlanPreviewState>;
+  // let obj: InstallPlanKind;
+  const obj: InstallPlanKind = {
+    ...testInstallPlan,
+    status: {
+      ...testInstallPlan.status,
+      plan: [
+        {
+          resolving: 'testoperator.v1.0.0',
+          status: 'Created',
+          resource: {
+            group: ClusterServiceVersionModel.apiGroup,
+            version: ClusterServiceVersionModel.apiVersion,
+            kind: ClusterServiceVersionModel.kind,
+            name: 'testoperator.v1.0.0',
+            manifest: '',
+          },
+        },
+        {
+          resolving: 'testoperator.v1.0.0',
+          status: 'Unknown',
+          resource: {
+            group: CustomResourceDefinitionModel.apiGroup,
+            version: CustomResourceDefinitionModel.apiVersion,
+            kind: CustomResourceDefinitionModel.kind,
+            name: 'test-crds.test.com',
+            manifest: '',
+          },
+        },
+      ],
+    },
+  };
 
   const spyAndExpect = (spy: Spy) => (returnValue: any) =>
     new Promise((resolve) =>
@@ -266,46 +312,26 @@ describe(InstallPlanPreview.name, () => {
       }),
     );
 
-  beforeEach(() => {
-    installPlan = _.cloneDeep(testInstallPlan);
-    installPlan.status.plan = [
-      {
-        resolving: 'testoperator.v1.0.0',
-        status: 'Created',
-        resource: {
-          group: ClusterServiceVersionModel.apiGroup,
-          version: ClusterServiceVersionModel.apiVersion,
-          kind: ClusterServiceVersionModel.kind,
-          name: 'testoperator.v1.0.0',
-          manifest: '',
-        },
-      },
-      {
-        resolving: 'testoperator.v1.0.0',
-        status: 'Unknown',
-        resource: {
-          group: CustomResourceDefinitionModel.apiGroup,
-          version: CustomResourceDefinitionModel.apiVersion,
-          kind: CustomResourceDefinitionModel.kind,
-          name: 'test-crds.test.com',
-          manifest: '',
-        },
-      },
-    ];
-
-    wrapper = shallow(<InstallPlanPreview obj={installPlan} />);
-  });
-
   it('renders empty message if `status.plan` is not filled', () => {
-    installPlan.status.plan = [];
-    wrapper = wrapper.setProps({ obj: installPlan });
-
+    const wrapper = shallow(
+      <InstallPlanPreview obj={{ ...obj, status: { ...obj.status, plan: [] } }} />,
+    );
     expect(wrapper.find(MsgBox).exists()).toBe(true);
   });
 
   it('renders button to approve install plan if requires approval', () => {
-    wrapper = wrapper.setState({ needsApproval: true });
-
+    const wrapper = shallow(
+      <InstallPlanPreview
+        obj={{
+          ...obj,
+          spec: {
+            ...obj.spec,
+            approval: InstallPlanApproval.Manual,
+            approved: false,
+          },
+        }}
+      />,
+    );
     expect(
       wrapper
         .find(HintBlock)
@@ -314,19 +340,30 @@ describe(InstallPlanPreview.name, () => {
         .at(0)
         .render()
         .text(),
-    ).toEqual('Approve');
+    ).toEqual('olm~Approve');
   });
 
   it('calls `k8sUpdate` to set `approved: true` when button is clicked', (done) => {
     spyAndExpect(spyOn(k8s, 'k8sUpdate'))(Promise.resolve(testInstallPlan))
-      .then(([model, obj]) => {
+      .then(([model, installPlan]) => {
         expect(model).toEqual(InstallPlanModel);
-        expect(obj.spec.approved).toBe(true);
+        expect(installPlan.spec.approved).toBe(true);
         done();
       })
       .catch((err) => fail(err));
 
-    wrapper = wrapper.setState({ needsApproval: true });
+    const wrapper = shallow(
+      <InstallPlanPreview
+        obj={{
+          ...obj,
+          spec: {
+            ...obj.spec,
+            approval: InstallPlanApproval.Manual,
+            approved: false,
+          },
+        }}
+      />,
+    );
     wrapper
       .find(HintBlock)
       .shallow()
@@ -336,8 +373,18 @@ describe(InstallPlanPreview.name, () => {
   });
 
   it('renders button to deny install plan if requires approval', () => {
-    wrapper = wrapper.setState({ needsApproval: true });
-
+    const wrapper = shallow(
+      <InstallPlanPreview
+        obj={{
+          ...obj,
+          spec: {
+            ...obj.spec,
+            approval: InstallPlanApproval.Manual,
+            approved: false,
+          },
+        }}
+      />,
+    );
     expect(
       wrapper
         .find(HintBlock)
@@ -346,10 +393,11 @@ describe(InstallPlanPreview.name, () => {
         .at(1)
         .render()
         .text(),
-    ).toEqual('Deny');
+    ).toEqual('olm~Deny');
   });
 
   it('renders section for each resolving `ClusterServiceVersion`', () => {
+    const wrapper = shallow(<InstallPlanPreview obj={obj} />);
     expect(wrapper.find('.co-m-pane__body').length).toEqual(1);
     wrapper.find('.co-m-pane__body').forEach((section) => {
       expect(section.find('tbody').find('tr').length).toEqual(2);
@@ -357,6 +405,7 @@ describe(InstallPlanPreview.name, () => {
   });
 
   it('renders link to view install plan component if it exists', () => {
+    const wrapper = shallow(<InstallPlanPreview obj={obj} />);
     const row = wrapper
       .find('.co-m-pane__body')
       .find('tbody')
@@ -369,10 +418,11 @@ describe(InstallPlanPreview.name, () => {
         .at(0)
         .find(ResourceLink)
         .props().name,
-    ).toEqual(installPlan.status.plan[0].resource.name);
+    ).toEqual(obj.status.plan[0].resource.name);
   });
 
   it('renders link to open preview modal for install plan component if not created yet', () => {
+    const wrapper = shallow(<InstallPlanPreview obj={obj} />);
     const row = wrapper
       .find('.co-m-pane__body')
       .find('tbody')
@@ -386,7 +436,7 @@ describe(InstallPlanPreview.name, () => {
         .at(0)
         .find(ResourceIcon)
         .props().kind,
-    ).toEqual(referenceForStepResource(installPlan.status.plan[1].resource));
+    ).toEqual(referenceForStepResource(obj.status.plan[1].resource));
 
     row
       .find('td')
@@ -394,11 +444,11 @@ describe(InstallPlanPreview.name, () => {
       .find(Button)
       .simulate('click');
 
-    expect(modalSpy.calls.argsFor(0)[0].stepResource).toEqual(installPlan.status.plan[1].resource);
+    expect(modalSpy.calls.argsFor(0)[0].stepResource).toEqual(obj.status.plan[1].resource);
   });
 });
 
-describe(InstallPlanDetails.displayName, () => {
+describe('InstallPlanDetails', () => {
   let wrapper: ShallowWrapper<InstallPlanDetailsProps>;
 
   beforeEach(() => {
@@ -429,7 +479,7 @@ describe(InstallPlanDetails.displayName, () => {
   });
 });
 
-describe(InstallPlanDetailsPage.displayName, () => {
+describe('InstallPlanDetailsPage', () => {
   let wrapper: ShallowWrapper<InstallPlanDetailsPageProps>;
   let match: InstallPlanDetailsPageProps['match'];
 
@@ -448,7 +498,7 @@ describe(InstallPlanDetailsPage.displayName, () => {
       wrapper
         .find(DetailsPage)
         .props()
-        .pages.map((p) => p.name),
-    ).toEqual(['Details', 'YAML', 'Components']);
+        .pages.map((p) => p.name || p.nameKey),
+    ).toEqual([`${i18nNS}~Details`, `${i18nNS}~YAML`, 'olm~Components']);
   });
 });
