@@ -40,6 +40,7 @@ import {
 import { ClusterServiceVersionLogo } from '../index';
 import { ResourceRequirements } from '../descriptors/spec/resource-requirements';
 import { Descriptor, SpecCapability, StatusCapability } from '../descriptors/types';
+import { SyncMarkdownView } from '@console/internal/components/markdown-view';
 import {
   NodeAffinity,
   PodAffinity,
@@ -48,6 +49,8 @@ import {
 } from '../descriptors/spec/affinity';
 import { OperandFormProps } from './operand-form';
 import { ProvidedAPI } from '../../types';
+import { usePostFormSubmitAction } from '@console/shared';
+import { useTranslation } from 'react-i18next';
 
 /*
  * Matches a path that contains an array index. Use Sting.match against an OperandField 'path'
@@ -105,7 +108,7 @@ enum Validations {
   pattern = 'pattern',
 }
 
-const idFromPath = (path) => `root_${path.split('.').join('_')}`;
+const idFromPath = (path) => `DEPRECATED_root_${path.split('.').join('_')}`;
 
 /*
  * Determines if a field contains a descriptor in it's capabilities. If only prefix is
@@ -465,12 +468,16 @@ const FieldGroup: React.FC<FieldGroupProps> = ({ children, isExpanded = false, i
   };
 
   return (
-    <div id={`${id}_field-group`} className="co-dynamic-form__field-group">
+    <div id={`DEPRECATED_${id}_field-group`} className="co-dynamic-form__field-group">
       <AccordionItem>
-        <AccordionToggle id={`${id}_accordion-toggle`} onClick={onToggle} isExpanded={expanded}>
-          <label htmlFor={`${id}_accordion-content`}>{label}</label>
+        <AccordionToggle
+          id={`DEPRECATED_${id}_accordion-toggle`}
+          onClick={onToggle}
+          isExpanded={expanded}
+        >
+          <label htmlFor={`DEPRECATED_${id}_accordion-content`}>{label}</label>
         </AccordionToggle>
-        <AccordionContent id={`${id}_accordion-content`} isHidden={!expanded}>
+        <AccordionContent id={`DEPRECATED_${id}_accordion-content`} isHidden={!expanded}>
           {children}
         </AccordionContent>
       </AccordionItem>
@@ -483,13 +490,17 @@ const OperandFormInputGroup: React.FC<OperandFormInputGroupProps> = ({ error, fi
   const { description, displayName, path, required } = field;
   const id = idFromPath(path);
   return input ? (
-    <div className="form-group co-dynamic-form__form-group" data-test-selector={path}>
+    <div
+      id={`DEPRECATED_${id}_field`}
+      className="form-group co-dynamic-form__form-group"
+      data-test-selector={path}
+    >
       <label className={classNames('form-label', { 'co-required': required })} htmlFor={id}>
         {displayName}
       </label>
       {input}
       {description && (
-        <span id={`${id}__description`} className="help-block">
+        <span id={`DEPRECATED_${id}__description`} className="help-block">
           {description}
         </span>
       )}
@@ -509,6 +520,8 @@ export const DEPRECATED_CreateOperandForm: React.FC<OperandFormProps> = ({
   match,
   next,
 }) => {
+  const postFormCallback = usePostFormSubmitAction<K8sResourceKind>();
+  const { t } = useTranslation();
   const immutableFormData = Immutable.fromJS(formData);
   const handleFormDataUpdate = (path: string, value: any): void => {
     const { regexMatch, index, pathBeforeIndex, pathAfterIndex } = parseArrayPath(path);
@@ -707,7 +720,8 @@ export const DEPRECATED_CreateOperandForm: React.FC<OperandFormProps> = ({
           ? immutableFormData.setIn(['metadata', 'namespace'], match.params.ns).toJS()
           : immutableFormData.toJS(),
       )
-        .then(() => history.push(next))
+        .then((res) => postFormCallback(res))
+        .then(() => next && history.push(next))
         .catch((err: Error) => setError(err.message || 'Unknown error.'));
     }
   };
@@ -767,7 +781,7 @@ export const DEPRECATED_CreateOperandForm: React.FC<OperandFormProps> = ({
       const storageRequestsPath = 'requests.ephemeral-storage';
       return (
         <dl style={{ marginLeft: '15px' }}>
-          <dt>Limits</dt>
+          <dt>{t('olm~Limits')}</dt>
           <dd>
             <ResourceRequirements
               cpu={currentValue.getIn?.(_.toPath(cpuLimitsPath))}
@@ -781,7 +795,7 @@ export const DEPRECATED_CreateOperandForm: React.FC<OperandFormProps> = ({
               path={`${id}.limits`}
             />
           </dd>
-          <dt>Requests</dt>
+          <dt>{t('olm~Requests')}</dt>
           <dd>
             <ResourceRequirements
               cpu={currentValue.getIn?.(_.toPath(cpuRequestsPath))}
@@ -834,7 +848,7 @@ export const DEPRECATED_CreateOperandForm: React.FC<OperandFormProps> = ({
             },
           ]}
           desc={displayName}
-          placeholder={`Select ${kindForReference(groupVersionKind)}`}
+          placeholder={t('olm~Select {{item}}', { item: kindForReference(groupVersionKind) })}
           onChange={(value) => handleFormDataUpdate(path, value)}
           selectedKey={currentValue ? `${currentValue}-${k8sModel?.kind}` : null}
         />
@@ -859,8 +873,8 @@ export const DEPRECATED_CreateOperandForm: React.FC<OperandFormProps> = ({
           id={id}
           isChecked={(_.isNil(currentValue) ? false : currentValue) as boolean}
           onChange={(value) => handleFormDataUpdate(path, value)}
-          label="True"
-          labelOff="False"
+          label={t('public~True')}
+          labelOff={t('public~False')}
         />
       );
     }
@@ -955,7 +969,7 @@ export const DEPRECATED_CreateOperandForm: React.FC<OperandFormProps> = ({
         <div>
           <Dropdown
             id={id}
-            title={`Select ${displayName}`}
+            title={t('olm~Select {{item}}', { item: displayName })}
             selectedKey={currentValue}
             items={capabilities
               .filter((c) => c.startsWith(SpecCapability.select))
@@ -1054,7 +1068,7 @@ export const DEPRECATED_CreateOperandForm: React.FC<OperandFormProps> = ({
                     variant="link"
                   >
                     <MinusCircleIcon className="co-icon-space-r" />
-                    Remove {singularGroupDisplayName}
+                    {t('olm~Remove {{item}}', { item: singularGroupDisplayName })}
                   </Button>
                 </div>
               )}
@@ -1071,7 +1085,7 @@ export const DEPRECATED_CreateOperandForm: React.FC<OperandFormProps> = ({
           <div className="row">
             <Button type="button" onClick={() => addArrayFieldGroup(fieldLists)} variant="link">
               <PlusCircleIcon className="co-icon-space-r" />
-              Add {singularGroupDisplayName}
+              {t('olm~Add {{item}}', { item: singularGroupDisplayName })}
             </Button>
           </div>
         </FieldGroup>
@@ -1116,8 +1130,8 @@ export const DEPRECATED_CreateOperandForm: React.FC<OperandFormProps> = ({
     advancedFields.length > 0 && (
       <div>
         <ExpandCollapse
-          textExpanded="Advanced Configuration"
-          textCollapsed="Advanced Configuration"
+          textExpanded={t('olm~Advanced configuration')}
+          textCollapsed={t('olm~Advanced configuration')}
         >
           {_.map(advancedFields, (field) => (
             <OperandFormInputGroup
@@ -1135,33 +1149,53 @@ export const DEPRECATED_CreateOperandForm: React.FC<OperandFormProps> = ({
   return (
     <div className="co-m-pane__body">
       <div className="row">
-        <div className="col-md-8 col-lg-7">
+        <div className="col-md-4 col-md-push-8 col-lg-5 col-lg-push-7">
+          {csv && providedAPI && (
+            <div style={{ marginBottom: '30px' }}>
+              <ClusterServiceVersionLogo
+                displayName={providedAPI.displayName}
+                icon={_.get(csv, 'spec.icon[0]')}
+                provider={_.get(csv, 'spec.provider')}
+              />
+              <SyncMarkdownView content={providedAPI.description} />
+            </div>
+          )}
+        </div>
+        <div className="col-md-8 col-md-pull-4 col-lg-7 col-lg-pull-5">
           <Alert
             isInline
             className="co-alert co-break-word"
             variant="info"
-            title={
-              'Note: Some fields may not be represented in this form. Please select "YAML View" for full control of object creation.'
-            }
+            title={t(
+              'olm~Note: Some fields may not be represented in this form. Please select "YAML View" for full control of object creation.',
+            )}
           />
           <form className="co-dynamic-form" onSubmit={submit}>
             <Accordion asDefinitionList={false} className="co-dynamic-form__accordion">
-              <div key={'metadata.name'} className="form-group">
-                <label className="control-label co-required" htmlFor="name">
-                  Name
+              <div
+                id="DEPRECATED_root_metadata_name_field"
+                key="root_metadata_name_field"
+                className="form-group"
+              >
+                <label className="form-label co-required" htmlFor="DEPRECATED_root_metadata_name">
+                  {t('public~Name')}
                 </label>
                 <input
                   className="pf-c-form-control"
                   type="text"
                   onChange={({ target: { value } }) => handleFormDataUpdate('metadata.name', value)}
                   value={immutableFormData.getIn(['metadata', 'name']) || 'example'}
-                  id="root_metadata_name"
+                  id="DEPRECATED_root_metadata_name"
                   required
                 />
               </div>
-              <div key={'root_metadata_labels'} className="form-group">
-                <label className="control-label" htmlFor="tags-input">
-                  Labels
+              <div
+                id="DEPRECATED_root_metadata_labels_field"
+                key="root_metadata_labels_field"
+                className="form-group"
+              >
+                <label className="form-label" htmlFor="tags-input">
+                  {t('public~Labels')}
                 </label>
                 <SelectorInput
                   onChange={(value) =>
@@ -1185,33 +1219,21 @@ export const DEPRECATED_CreateOperandForm: React.FC<OperandFormProps> = ({
                 variant="danger"
                 title="Error"
               >
-                {error || 'Fix above errors'}
+                {error || t('olm~Fix above errors')}
               </Alert>
             )}
             <div style={{ paddingBottom: '30px' }}>
               <ActionGroup className="pf-c-form">
                 <Button onClick={submit} type="submit" variant="primary">
-                  Create
+                  {t('public~Create')}
                 </Button>
                 <Button onClick={history.goBack} variant="secondary">
-                  Cancel
+                  {t('public~Cancel')}
                 </Button>
               </ActionGroup>
             </div>
           </form>
         </div>
-        <div className="col-md-4 col-lg-5">
-          {csv && providedAPI && (
-            <div style={{ marginBottom: '30px' }}>
-              <ClusterServiceVersionLogo
-                displayName={providedAPI.displayName}
-                icon={_.get(csv, 'spec.icon[0]')}
-                provider={_.get(csv, 'spec.provider')}
-              />
-              {providedAPI.description}
-            </div>
-          )}
-        </div>
       </div>
     </div>
   );
