@@ -1,10 +1,10 @@
 import * as React from 'react';
 import { useTranslation } from 'react-i18next';
 import { RouteComponentProps } from 'react-router';
-import { getBadgeFromType } from '@console/shared';
 import CreateProjectListPage from '@console/dev-console/src/components/projects/CreateProjectListPage';
 import { PipelineRunModel } from '../../models';
 import PipelineRunsResourceList from './PipelineRunsResourceList';
+import { usePipelineTechPreviewBadge } from '../../utils/hooks';
 
 type PipelineRunsPageProps = RouteComponentProps<{ ns: string }>;
 
@@ -15,15 +15,13 @@ const PipelineRunsPage: React.FC<PipelineRunsPageProps> = (props) => {
       params: { ns: namespace },
     },
   } = props;
+  const badge = usePipelineTechPreviewBadge(namespace);
   return namespace ? (
     <div>
       <PipelineRunsResourceList {...props} namespace={namespace} />
     </div>
   ) : (
-    <CreateProjectListPage
-      title={PipelineRunModel.labelPlural}
-      badge={getBadgeFromType(PipelineRunModel.badge)}
-    >
+    <CreateProjectListPage title={PipelineRunModel.labelPlural} badge={badge}>
       {t('pipelines-plugin~Select a Project to view the list of {{pipelineRunLabel}}', {
         pipelineRunLabel: PipelineRunModel.labelPlural,
       })}
