@@ -1,8 +1,12 @@
 import * as React from 'react';
 import { connect } from 'react-redux';
-import { Button } from '@patternfly/react-core';
-import { ArrowCircleUpIcon, InProgressIcon } from '@patternfly/react-icons';
-import { FLAGS, getInfrastructureAPIURL, getInfrastructurePlatform } from '@console/shared';
+import { InProgressIcon } from '@patternfly/react-icons';
+import {
+  BlueArrowCircleUpIcon,
+  FLAGS,
+  getInfrastructureAPIURL,
+  getInfrastructurePlatform,
+} from '@console/shared';
 import DashboardCard from '@console/shared/src/components/dashboard/dashboard-card/DashboardCard';
 import DashboardCardBody from '@console/shared/src/components/dashboard/dashboard-card/DashboardCardBody';
 import DashboardCardHeader from '@console/shared/src/components/dashboard/dashboard-card/DashboardCardHeader';
@@ -10,6 +14,8 @@ import DashboardCardTitle from '@console/shared/src/components/dashboard/dashboa
 import DetailsBody from '@console/shared/src/components/dashboard/details-card/DetailsBody';
 import DetailItem from '@console/shared/src/components/dashboard/details-card/DetailItem';
 import DashboardCardLink from '@console/shared/src/components/dashboard/dashboard-card/DashboardCardLink';
+import { useTranslation } from 'react-i18next';
+
 import { DashboardItemProps, withDashboardResources } from '../../with-dashboard-resources';
 import { ClusterVersionModel } from '../../../../models';
 import {
@@ -28,7 +34,6 @@ import {
 import { flagPending, featureReducerName } from '../../../../reducers/features';
 import { ExternalLink, useAccessReview } from '../../../utils';
 import { RootState } from '../../../../redux';
-import { clusterUpdateModal } from '../../../modals';
 import { Link } from 'react-router-dom';
 import { useK8sWatchResource, WatchK8sResource } from '../../../utils/k8s-watch-hook';
 import { ClusterDashboardContext } from './context';
@@ -44,6 +49,7 @@ const ClusterVersion: React.FC<ClusterVersionProps> = ({ cv }) => {
       verb: 'patch',
       name: 'version',
     }) && window.SERVER_FLAGS.branding !== 'dedicated';
+  const { t } = useTranslation();
 
   switch (status) {
     case ClusterUpdateStatus.Updating:
@@ -53,7 +59,7 @@ const ClusterVersion: React.FC<ClusterVersionProps> = ({ cv }) => {
           <div>
             <Link to="/settings/cluster/">
               <InProgressIcon className="co-icon-and-text__icon" />
-              Updating
+              {t('dashboard~Updating')}
             </Link>
           </div>
         </>
@@ -64,15 +70,10 @@ const ClusterVersion: React.FC<ClusterVersionProps> = ({ cv }) => {
           <span className="co-select-to-copy">{desiredVersion}</span>
           {clusterVersionIsEditable && (
             <div>
-              <Button
-                variant="link"
-                className="btn-link--no-btn-default-values"
-                onClick={() => clusterUpdateModal({ cv })}
-                icon={<ArrowCircleUpIcon />}
-                isInline
-              >
-                Update
-              </Button>
+              <Link to="/settings/cluster?showVersions">
+                <BlueArrowCircleUpIcon className="co-icon-space-r" />
+                {t('dashboard~Update cluster')}
+              </Link>
             </div>
           )}
         </>
@@ -81,7 +82,7 @@ const ClusterVersion: React.FC<ClusterVersionProps> = ({ cv }) => {
       return lastVersion ? (
         <span className="co-select-to-copy">{lastVersion}</span>
       ) : (
-        <span className="text-secondary">Not available</span>
+        <span className="text-secondary">{t('dashboard~Not available')}</span>
       );
   }
 };
@@ -131,19 +132,22 @@ export const DetailsCard_ = connect(mapStateToProps)(
     const infrastuctureApiUrl = getInfrastructureAPIURL(infrastructure);
 
     const k8sGitVersion = getK8sGitVersion(k8sVersion);
+    const { t } = useTranslation();
 
     return (
       <DashboardCard data-test-id="details-card">
         <DashboardCardHeader>
-          <DashboardCardTitle>Details</DashboardCardTitle>
-          <DashboardCardLink to="/settings/cluster/">View settings</DashboardCardLink>
+          <DashboardCardTitle>{t('dashboard~Details')}</DashboardCardTitle>
+          <DashboardCardLink to="/settings/cluster/">
+            {t('dashboard~View settings')}
+          </DashboardCardLink>
         </DashboardCardHeader>
         <DashboardCardBody isLoading={flagPending(openshiftFlag)}>
           <DetailsBody>
             {openshiftFlag ? (
               <>
                 <DetailItem
-                  title="Cluster API address"
+                  title={t('dashboard~Cluster API address')}
                   isLoading={!infrastructureLoaded}
                   error={!!infrastructureError || (infrastructure && !infrastuctureApiUrl)}
                   valueClassName="co-select-to-copy"
@@ -151,18 +155,21 @@ export const DetailsCard_ = connect(mapStateToProps)(
                   {infrastuctureApiUrl}
                 </DetailItem>
                 <DetailItem
-                  title="Cluster ID"
+                  title={t('dashboard~Cluster ID')}
                   error={!!clusterVersionError || (clusterVersionLoaded && !clusterId)}
                   isLoading={!clusterVersionLoaded}
                 >
                   <div className="co-select-to-copy">{clusterId}</div>
                   {window.SERVER_FLAGS.branding !== 'okd' &&
                     window.SERVER_FLAGS.branding !== 'azure' && (
-                      <ExternalLink text="OpenShift Cluster Manager" href={getOCMLink(clusterId)} />
+                      <ExternalLink
+                        text={t('dashboard~OpenShift Cluster Manager')}
+                        href={getOCMLink(clusterId)}
+                      />
                     )}
                 </DetailItem>
                 <DetailItem
-                  title="Provider"
+                  title={t('dashboard~Provider')}
                   error={!!infrastructureError || (infrastructure && !infrastructurePlatform)}
                   isLoading={!infrastructureLoaded}
                   valueClassName="co-select-to-copy"
@@ -170,14 +177,14 @@ export const DetailsCard_ = connect(mapStateToProps)(
                   {infrastructurePlatform}
                 </DetailItem>
                 <DetailItem
-                  title="OpenShift version"
+                  title={t('dashboard~OpenShift version')}
                   error={!!clusterVersionError || (clusterVersionLoaded && !openShiftVersion)}
                   isLoading={!clusterVersionLoaded}
                 >
                   <ClusterVersion cv={clusterVersionData} />
                 </DetailItem>
                 <DetailItem
-                  title="Update channel"
+                  title={t('dashboard~Update channel')}
                   isLoading={!clusterVersionLoaded && !clusterVersionError}
                   error={!!clusterVersionError || (clusterVersionLoaded && !cvChannel)}
                   valueClassName="co-select-to-copy"
@@ -188,7 +195,7 @@ export const DetailsCard_ = connect(mapStateToProps)(
             ) : (
               <DetailItem
                 key="kubernetes"
-                title="Kubernetes version"
+                title={t('dashboard~Kubernetes version')}
                 error={!!k8sVersionError || (k8sVersion && !k8sGitVersion)}
                 isLoading={!k8sVersion}
                 valueClassName="co-select-to-copy"
