@@ -2,6 +2,8 @@ import * as React from 'react';
 import * as _ from 'lodash-es';
 import { connect } from 'react-redux';
 import { Map as ImmutableMap } from 'immutable';
+import { Link } from 'react-router-dom';
+import { useTranslation } from 'react-i18next';
 import {
   useExtensions,
   DashboardsOverviewHealthSubsystem,
@@ -13,9 +15,8 @@ import {
   isDashboardsOverviewHealthResourceSubsystem,
   isDashboardsOverviewHealthOperator,
 } from '@console/plugin-sdk';
-import { ArrowCircleUpIcon } from '@patternfly/react-icons';
-import { Gallery, GalleryItem, Button } from '@patternfly/react-core';
-import { FLAGS, getInfrastructurePlatform } from '@console/shared';
+import { Gallery, GalleryItem } from '@patternfly/react-core';
+import { BlueArrowCircleUpIcon, FLAGS, getInfrastructurePlatform } from '@console/shared';
 import DashboardCard from '@console/shared/src/components/dashboard/dashboard-card/DashboardCard';
 import DashboardCardBody from '@console/shared/src/components/dashboard/dashboard-card/DashboardCardBody';
 import DashboardCardHeader from '@console/shared/src/components/dashboard/dashboard-card/DashboardCardHeader';
@@ -27,7 +28,7 @@ import { withDashboardResources } from '../../with-dashboard-resources';
 import AlertItem, {
   StatusItem,
 } from '@console/shared/src/components/dashboard/status-card/AlertItem';
-import { alertURL } from '../../../monitoring';
+import { alertURL } from '../../../monitoring/utils';
 import {
   ClusterVersionKind,
   referenceForModel,
@@ -35,7 +36,6 @@ import {
   K8sKind,
 } from '../../../../module/k8s';
 import { ClusterVersionModel } from '../../../../models';
-import { clusterUpdateModal } from '../../../modals/cluster-update-modal';
 import { RootState } from '../../../../redux';
 import {
   OperatorHealthItem,
@@ -89,10 +89,7 @@ const ClusterAlerts = withDashboardResources(
     const { data: alerts, loaded: alertsLoaded, loadError: alertsResponseError } =
       notificationAlerts || {};
 
-    const UpdateIcon = React.useCallback(
-      () => <ArrowCircleUpIcon className="update-pending" />,
-      [],
-    );
+    const UpdateIcon = React.useCallback(() => <BlueArrowCircleUpIcon />, []);
 
     const items: React.ReactNode[] = [];
 
@@ -104,12 +101,16 @@ const ClusterAlerts = withDashboardResources(
         name: 'version',
       }) && window.SERVER_FLAGS.branding !== 'dedicated';
 
+    const { t } = useTranslation();
+
     if (hasCVResource && cvLoaded && hasAvailableUpdates(cv) && clusterVersionIsEditable) {
       items.push(
-        <StatusItem Icon={UpdateIcon} message="A cluster version update is available">
-          <Button variant="link" onClick={() => clusterUpdateModal({ cv })} isInline>
-            View details
-          </Button>
+        <StatusItem
+          key="clusterUpdate"
+          Icon={UpdateIcon}
+          message={t('dashboard~A cluster version update is available')}
+        >
+          <Link to="/settings/cluster?showVersions">{t('dashboard~Update cluster')}</Link>
         </StatusItem>,
       );
     }
@@ -143,7 +144,7 @@ export const StatusCard = connect<StatusCardProps>(mapStateToProps)(({ k8sModels
     [subsystems],
   );
   const { infrastructure, infrastructureLoaded } = React.useContext(ClusterDashboardContext);
-
+  const { t } = useTranslation();
   const healthItems: { title: string; Component: React.ReactNode }[] = [];
   subsystems.forEach((subsystem) => {
     if (isDashboardsOverviewHealthURLSubsystem(subsystem)) {
@@ -182,12 +183,12 @@ export const StatusCard = connect<StatusCardProps>(mapStateToProps)(({ k8sModels
   return (
     <DashboardCard gradient data-test-id="status-card">
       <DashboardCardHeader>
-        <DashboardCardTitle>Status</DashboardCardTitle>
-        <DashboardCardLink to="/monitoring/alerts">View alerts</DashboardCardLink>
+        <DashboardCardTitle>{t('dashboard~Status')}</DashboardCardTitle>
+        <DashboardCardLink to="/monitoring/alerts">{t('dashboard~View alerts')}</DashboardCardLink>
       </DashboardCardHeader>
       <DashboardCardBody>
         <HealthBody>
-          <Gallery className="co-overview-status__health" gutter="md">
+          <Gallery className="co-overview-status__health" hasGutter>
             {healthItems.map((item) => {
               return <GalleryItem key={item.title}>{item.Component}</GalleryItem>;
             })}
