@@ -2,8 +2,9 @@ import * as React from 'react';
 // eslint-disable-next-line @typescript-eslint/ban-ts-ignore
 // @ts-ignore: FIXME missing exports due to out-of-sync @types/react-redux version
 import { useSelector } from 'react-redux';
+import { useTranslation } from 'react-i18next';
 import { RootState } from '@console/internal/redux';
-import { Status, PodRingController, useCsvWatchResource } from '@console/shared';
+import { Status, useCsvWatchResource } from '@console/shared';
 import PodRingSet from '@console/shared/src/components/pod/PodRingSet';
 import { AddHealthChecks, EditHealthChecks } from '@console/app/src/actions/modify-health-checks';
 import {
@@ -27,12 +28,10 @@ import {
   KebabAction,
   ContainerTable,
   navFactory,
-  pluralize,
   ResourceSummary,
   SectionHeading,
   togglePaused,
   WorkloadPausedAlert,
-  LoadingInline,
 } from './utils';
 import { ReplicaSetsPage } from './replicaset';
 import { WorkloadTableRow, WorkloadTableHeader } from './workload-table';
@@ -41,7 +40,8 @@ const deploymentsReference: K8sResourceKindReference = 'Deployment';
 const { ModifyCount, AddStorage, common } = Kebab.factory;
 
 const UpdateStrategy: KebabAction = (kind: K8sKind, deployment: DeploymentKind) => ({
-  label: 'Edit Update Strategy',
+  // t('public~Edit update strategy')
+  labelKey: 'public~Edit update strategy',
   callback: () => configureUpdateStrategyModal({ deployment }),
   accessReview: {
     group: kind.apiGroup,
@@ -53,7 +53,9 @@ const UpdateStrategy: KebabAction = (kind: K8sKind, deployment: DeploymentKind)
 });
 
 const PauseAction: KebabAction = (kind: K8sKind, obj: DeploymentKind) => ({
-  label: obj.spec.paused ? 'Resume Rollouts' : 'Pause Rollouts',
+  // t('public~Resume rollouts')
+  // t('public~Pause rollouts')
+  labelKey: obj.spec.paused ? 'public~Resume rollouts' : 'public~Pause rollouts',
   callback: () => togglePaused(kind, obj).catch((err) => errorModal({ error: err.message })),
   accessReview: {
     group: kind.apiGroup,
@@ -79,42 +81,51 @@ export const menuActions = [
 ];
 
 export const DeploymentDetailsList: React.FC<DeploymentDetailsListProps> = ({ deployment }) => {
+  const { t } = useTranslation();
   return (
     <dl className="co-m-pane__details">
-      <DetailsItem label="Update Strategy" obj={deployment} path="spec.strategy.type" />
+      <DetailsItem label={t('public~Update strategy')} obj={deployment} path="spec.strategy.type" />
       {deployment.spec.strategy.type === 'RollingUpdate' && (
         <>
           <DetailsItem
-            label="Max Unavailable"
+            label={t('public~Max unavailable')}
             obj={deployment}
             path="spec.strategy.rollingUpdate.maxUnavailable"
           >
-            {deployment.spec.strategy.rollingUpdate.maxUnavailable || 1} of{' '}
-            {pluralize(deployment.spec.replicas, 'pod')}
+            {t('public~{{maxUnavailable}} of {{count}} pod', {
+              maxUnavailable: deployment.spec.strategy.rollingUpdate.maxUnavailable ?? 1,
+              count: deployment.spec.replicas,
+            })}
           </DetailsItem>
           <DetailsItem
-            label="Max Surge"
+            label={t('public~Max surge')}
             obj={deployment}
             path="spec.strategy.rollingUpdate.maxSurge"
           >
-            {deployment.spec.strategy.rollingUpdate.maxSurge || 1} greater than{' '}
-            {pluralize(deployment.spec.replicas, 'pod')}
+            {t('public~{{maxSurge}} greater than {{count}} pod', {
+              maxSurge: deployment.spec.strategy.rollingUpdate.maxSurge ?? 1,
+              count: deployment.spec.replicas,
+            })}
           </DetailsItem>
         </>
       )}
       <DetailsItem
-        label="Progress Deadline Seconds"
+        label={t('public~Progress deadline seconds')}
         obj={deployment}
         path="spec.progressDeadlineSeconds"
       >
         {deployment.spec.progressDeadlineSeconds
-          ? pluralize(deployment.spec.progressDeadlineSeconds, 'second')
-          : 'Not Configured'}
+          ? t('public~{{count}} second', { count: deployment.spec.progressDeadlineSeconds })
+          : t('public~Not configured')}
       </DetailsItem>
-      <DetailsItem label="Min Ready Seconds" obj={deployment} path="spec.minReadySeconds">
+      <DetailsItem
+        label={t('public~Min ready seconds')}
+        obj={deployment}
+        path="spec.minReadySeconds"
+      >
         {deployment.spec.minReadySeconds
-          ? pluralize(deployment.spec.minReadySeconds, 'second')
-          : 'Not Configured'}
+          ? t('public~{{count}} second', { count: deployment.spec.minReadySeconds })
+          : t('public~Not configured')}
       </DetailsItem>
     </dl>
   );
@@ -122,31 +133,13 @@ export const DeploymentDetailsList: React.FC<DeploymentDetailsListProps> = ({ de
 DeploymentDetailsList.displayName = 'DeploymentDetailsList';
 
 const DeploymentDetails: React.FC<DeploymentDetailsProps> = ({ obj: deployment }) => {
+  const { t } = useTranslation();
   return (
     <>
       <div className="co-m-pane__body">
-        <SectionHeading text="Deployment Details" />
+        <SectionHeading text={t('public~Deployment details')} />
         {deployment.spec.paused && <WorkloadPausedAlert obj={deployment} model={DeploymentModel} />}
-        <PodRingController
-          namespace={deployment.metadata.namespace}
-          kind={deployment.kind}
-          render={(d) => {
-            if (!d.loaded) {
-              return <LoadingInline />;
-            } else if (!d.data[deployment.metadata.uid]) {
-              return null;
-            }
-            return (
-              <PodRingSet
-                key={deployment.metadata.uid}
-                podData={d.data[deployment.metadata.uid]}
-                obj={deployment}
-                resourceKind={DeploymentModel}
-                path="/spec/replicas"
-              />
-            );
-          }}
-        />
+        <PodRingSet key={deployment.metadata.uid} obj={deployment} path="/spec/replicas" />
         <div className="co-m-pane__body-group">
           <div className="row">
             <div className="col-sm-6">
@@ -156,7 +149,7 @@ const DeploymentDetails: React.FC<DeploymentDetailsProps> = ({ obj: deployment }
                 showNodeSelector
                 showTolerations
               >
-                <dt>Status</dt>
+                <dt>{t('public~Status')}</dt>
                 <dd>
                   {deployment.status.availableReplicas === deployment.status.updatedReplicas &&
                   deployment.spec.replicas === deployment.status.availableReplicas ? (
@@ -174,14 +167,14 @@ const DeploymentDetails: React.FC<DeploymentDetailsProps> = ({ obj: deployment }
         </div>
       </div>
       <div className="co-m-pane__body">
-        <SectionHeading text="Containers" />
+        <SectionHeading text={t('public~Containers')} />
         <ContainerTable containers={deployment.spec.template.spec.containers} />
       </div>
       <div className="co-m-pane__body">
-        <VolumesTable resource={deployment} heading="Volumes" />
+        <VolumesTable resource={deployment} heading={t('public~Volumes')} />
       </div>
       <div className="co-m-pane__body">
-        <SectionHeading text="Conditions" />
+        <SectionHeading text={t('public~Conditions')} />
         <Conditions conditions={deployment.status.conditions} />
       </div>
     </>
@@ -228,6 +221,7 @@ export const DeploymentsDetailsPage: React.FC<DeploymentsDetailsPageProps> = (pr
   const ns = useSelector((state: RootState) => getActiveNamespace(state));
 
   const { csvData } = useCsvWatchResource(ns);
+  // t('details-page~ReplicaSets')
   return (
     <DetailsPage
       {...props}
@@ -238,7 +232,7 @@ export const DeploymentsDetailsPage: React.FC<DeploymentsDetailsPageProps> = (pr
         editYaml(),
         {
           href: 'replicasets',
-          name: 'Replica Sets',
+          nameKey: 'details-page~ReplicaSets',
           component: ReplicaSetsTab,
         },
         pods(),
@@ -280,15 +274,18 @@ const DeploymentTableHeader = () => {
 };
 DeploymentTableHeader.displayName = 'DeploymentTableHeader';
 
-export const DeploymentsList: React.FC = (props) => (
-  <Table
-    {...props}
-    aria-label="Deployments"
-    Header={DeploymentTableHeader}
-    Row={DeploymentTableRow}
-    virtualize
-  />
-);
+export const DeploymentsList: React.FC = (props) => {
+  const { t } = useTranslation();
+  return (
+    <Table
+      {...props}
+      aria-label={t('public~Deployments')}
+      Header={DeploymentTableHeader}
+      Row={DeploymentTableRow}
+      virtualize
+    />
+  );
+};
 DeploymentsList.displayName = 'DeploymentsList';
 
 export const DeploymentsPage: React.FC<DeploymentsPageProps> = (props) => {
