@@ -1,9 +1,10 @@
 import * as _ from 'lodash-es';
 import * as React from 'react';
+import { useTranslation } from 'react-i18next';
 
 import { k8sPatch, K8sResourceKind, K8sKind } from '../../module/k8s';
 import { createModalLauncher, ModalTitle, ModalBody, ModalSubmitFooter } from '../factory/modal';
-import { NameValueEditorPair, withHandlePromise } from '../utils';
+import { NameValueEditorPair, withHandlePromise, HandlePromiseProps } from '../utils';
 import { AsyncComponent } from '../utils/async';
 
 /**
@@ -25,27 +26,29 @@ export const TagsModal = withHandlePromise((props: TagsModalProps) => {
   );
   const [errorMessage, setErrorMessage] = React.useState(props.errorMessage);
 
+  const { t } = useTranslation();
+
   const submit = (e) => {
     e.preventDefault();
 
     // We just throw away any rows where the key is blank
-    const usedTags = _.reject(tags, (t) => _.isEmpty(t[NameValueEditorPair.Name]));
+    const usedTags = _.reject(tags, (tag) => _.isEmpty(tag[NameValueEditorPair.Name]));
 
-    const keys = usedTags.map((t) => t[NameValueEditorPair.Name]);
+    const keys = usedTags.map((tag) => tag[NameValueEditorPair.Name]);
     if (_.uniq(keys).length !== keys.length) {
-      setErrorMessage('Duplicate keys found.');
+      setErrorMessage(t('modal~Duplicate keys found.'));
       return;
     }
     // Make sure to 'add' if the path does not already exist, otherwise the patch request will fail
     const op = props.tags ? 'replace' : 'add';
     const patch = [{ path: props.path, op, value: _.fromPairs(usedTags) }];
     const promise = k8sPatch(props.kind, props.resource, patch);
-    props.handlePromise(promise).then(props.close);
+    props.handlePromise(promise, props.close);
   };
 
   return (
     <form onSubmit={submit} className="modal-content">
-      <ModalTitle>{props.title}</ModalTitle>
+      <ModalTitle>{t(props.titleKey)}</ModalTitle>
       <ModalBody>
         <NameValueEditorComponent
           nameValuePairs={tags}
@@ -54,7 +57,7 @@ export const TagsModal = withHandlePromise((props: TagsModalProps) => {
         />
       </ModalBody>
       <ModalSubmitFooter
-        submitText="Save"
+        submitText={t('modal~Save')}
         cancel={props.cancel}
         errorMessage={props.errorMessage || errorMessage}
         inProgress={props.inProgress}
@@ -67,7 +70,8 @@ export const annotationsModal = createModalLauncher((props: AnnotationsModalProp
   <TagsModal
     path="/metadata/annotations"
     tags={props.resource.metadata.annotations}
-    title="Edit Annotations"
+    // t('modal~Edit annotations')
+    titleKey="modal~Edit annotations"
     {...props}
   />
 ));
@@ -75,16 +79,15 @@ export const annotationsModal = createModalLauncher((props: AnnotationsModalProp
 type TagsModalProps = {
   tags?: { [key: string]: string };
   path: string;
-  title: string;
+  titleKey: string;
   kind: K8sKind;
   resource: K8sResourceKind;
-  handlePromise: <T>(promise: Promise<T>) => Promise<T>;
   inProgress: boolean;
   errorMessage: string;
   cancel?: () => void;
   close?: () => void;
-};
+} & HandlePromiseProps;
 
-type AnnotationsModalProps = Omit<TagsModalProps, 'path' | 'tags' | 'title'>;
+type AnnotationsModalProps = Omit<TagsModalProps, 'path' | 'tags'>;
 
 TagsModal.displayName = 'TagsModal';
