@@ -3,8 +3,6 @@ import * as _ from 'lodash-es';
 import { List as ImmutableList } from 'immutable';
 import {
   ActionGroup,
-  Alert,
-  AlertActionCloseButton,
   Button,
   EmptyState,
   EmptyStateBody,
@@ -34,14 +32,11 @@ import {
 } from '@patternfly/react-table';
 import * as React from 'react';
 import { Helmet } from 'react-helmet';
+import { useTranslation } from 'react-i18next';
 import { connect } from 'react-redux';
 
 import { withFallback } from '@console/shared/src/components/error/error-boundary';
-import {
-  RedExclamationCircleIcon,
-  TechPreviewBadge,
-  YellowExclamationTriangleIcon,
-} from '@console/shared';
+import { RedExclamationCircleIcon, YellowExclamationTriangleIcon } from '@console/shared';
 import * as UIActions from '../../actions/ui';
 import { RootState } from '../../redux';
 import { fuzzyCaseInsensitive } from '../factory/table-filters';
@@ -59,7 +54,22 @@ import {
   useSafeFetch,
 } from '../utils';
 import { setAllQueryArguments } from '../utils/router';
+import IntervalDropdown from './poll-interval-dropdown';
 import { colors, Error, QueryObj, QueryBrowser } from './query-browser';
+import { PrometheusAPIError } from './types';
+
+const operators = [
+  'and',
+  'by()',
+  'group_left()',
+  'group_right()',
+  'ignoring()',
+  'offset',
+  'on()',
+  'or',
+  'unless',
+  'without()',
+];
 
 const aggregationOperators = [
   'avg()',
@@ -139,18 +149,22 @@ const MetricsActionsMenu_: React.FC<MetricsActionsMenuProps> = ({
   isAllExpanded,
   setAllExpanded,
 }) => {
+  const { t } = useTranslation();
+
   const doDelete = () => {
     deleteAll();
     focusedQuery = undefined;
   };
 
   const actionsMenuActions = [
-    { label: 'Add query', callback: addQuery },
+    { label: t('public~Add query'), callback: addQuery },
     {
-      label: `${isAllExpanded ? 'Collapse' : 'Expand'} all query tables`,
+      label: isAllExpanded
+        ? t('public~Collapse all query tables')
+        : t('public~Expand all query tables'),
       callback: () => setAllExpanded(!isAllExpanded),
     },
-    { label: 'Delete all queries', callback: doDelete },
+    { label: t('public~Delete all queries'), callback: doDelete },
   ];
 
   return (
@@ -184,19 +198,23 @@ const headerPrometheusLinkStateToProps = ({ UI }: RootState) => {
 };
 
 const HeaderPrometheusLink_ = ({ url }) => {
+  const { t } = useTranslation();
+
   return url ? (
     <span className="monitoring-header-link">
-      <ExternalLink href={url} text="Prometheus UI" />
+      <ExternalLink href={url} text={t('public~Platform Prometheus UI')} />
     </span>
   ) : null;
 };
 const HeaderPrometheusLink = connect(headerPrometheusLinkStateToProps)(HeaderPrometheusLink_);
 
-export const graphStateToProps = ({ UI }: RootState) => ({
+const graphStateToProps = ({ UI }: RootState) => ({
   hideGraphs: !!UI.getIn(['monitoring', 'hideGraphs']),
 });
 
 const ToggleGraph_ = ({ hideGraphs, toggle }) => {
+  const { t } = useTranslation();
+
   const icon = hideGraphs ? <ChartLineIcon /> : <CompressIcon />;
 
   return (
@@ -206,7 +224,7 @@ const ToggleGraph_ = ({ hideGraphs, toggle }) => {
       onClick={toggle}
       variant="link"
     >
-      {icon} {hideGraphs ? 'Show' : 'Hide'} Graph
+      {icon} {hideGraphs ? t('public~Show graph') : t('public~Hide graph')}
     </Button>
   );
 };
@@ -214,34 +232,27 @@ export const ToggleGraph = connect(graphStateToProps, { toggle: UIActions.monito
   ToggleGraph_,
 );
 
-const MetricsDropdown_: React.FC<MetricsDropdownProps> = ({
-  insertText,
-  namespace,
-  setMetrics,
-}) => {
+const MetricsDropdown_: React.FC<MetricsDropdownProps> = ({ insertText, setMetrics }) => {
+  const { t } = useTranslation();
+
   const [items, setItems] = React.useState<MetricsDropdownItems>();
-  const [isError, setIsError] = React.useState(false);
+  const [error, setError] = React.useState<PrometheusAPIError>();
 
   const safeFetch = React.useCallback(useSafeFetch(), []);
 
   React.useEffect(() => {
-    const url = namespace
-      ? getPrometheusURL({
-          endpoint: PrometheusEndpoint.QUERY,
-          namespace,
-          query: `count({namespace="${namespace}"}) by (__name__)`,
-        })
-      : `${PROMETHEUS_BASE_PATH}/${PrometheusEndpoint.LABEL}/__name__/values`;
-    safeFetch(url)
+    safeFetch(`${PROMETHEUS_BASE_PATH}/${PrometheusEndpoint.LABEL}/__name__/values`)
       .then((response) => {
-        const metrics = namespace
-          ? _.map(_.get(response, 'data.result'), 'metric.__name__').sort()
-          : _.get(response, 'data');
+        const metrics = response?.data;
         setItems(_.zipObject(metrics, metrics));
         setMetrics(metrics);
       })
-      .catch(() => setIsError(true));
-  }, [namespace, safeFetch, setMetrics]);
+      .catch((err) => {
+        if (err.name !== 'AbortError') {
+          setError(err);
+        }
+      });
+  }, [safeFetch, setMetrics]);
 
   const onChange = (metric: string) => {
     // Replace the currently selected text with the metric
@@ -256,11 +267,13 @@ const MetricsDropdown_: React.FC<MetricsDropdownProps> = ({
     }
   };
 
-  let title: React.ReactNode = 'Insert Metric at Cursor';
-  if (isError) {
+  let title: React.ReactNode = t('public~Insert metric at cursor');
+  if (error !== undefined) {
+    const message =
+      error?.response?.status === 403 ? 'Access restricted.' : 'Failed to load metrics list.';
     title = (
       <span>
-        <RedExclamationCircleIcon /> Failed to load metrics list.
+        <RedExclamationCircleIcon /> {message}
       </span>
     );
   } else if (items === undefined) {
@@ -276,7 +289,7 @@ const MetricsDropdown_: React.FC<MetricsDropdownProps> = ({
   return (
     <Dropdown
       autocompleteFilter={fuzzyCaseInsensitive}
-      disabled={isError}
+      disabled={error !== undefined}
       id="metrics-dropdown"
       items={items || {}}
       menuClassName="query-browser__metrics-dropdown-menu query-browser__metrics-dropdown-menu--insert"
@@ -285,7 +298,7 @@ const MetricsDropdown_: React.FC<MetricsDropdownProps> = ({
     />
   );
 };
-const MetricsDropdown: React.ComponentType<{ namespace?: string }> = connect(null, {
+const MetricsDropdown = connect(null, {
   insertText: UIActions.queryBrowserInsertText,
   setMetrics: UIActions.queryBrowserSetMetrics,
 })(MetricsDropdown_);
@@ -335,7 +348,7 @@ const SeriesButton_: React.FC<SeriesButtonProps> = ({
   toggleSeries,
 }) => {
   if (isSeriesEmpty) {
-    return null;
+    return <div className="query-browser__series-btn-wrap"></div>;
   }
   const title = `${isDisabled ? 'Show' : 'Hide'} series`;
 
@@ -364,6 +377,27 @@ const queryInputStateToProps = ({ UI }: RootState, { index }) => ({
   text: UI.getIn(['queryBrowser', 'queries', index, 'text']),
 });
 
+// Highlight characters in `text` based on the search string `token`
+const HighlightMatches: React.FC<{ text: string; token: string }> = ({ text, token }) => {
+  // Autocompletion uses fuzzy matching, so the entire `token` string may not be a substring of
+  // `text`. Instead, we find the longest starting substring of `token` that exists in `text` and
+  // highlight it. Then we repeat with the remainder of `token` and `text` and continue until all
+  // the characters of `token` have been found somewhere in `text`.
+  for (let sub = token; sub.length > 0; sub = sub.slice(0, -1)) {
+    const i = text.toLowerCase().indexOf(sub);
+    if (i !== -1) {
+      return (
+        <>
+          {text.slice(0, i)}
+          <span className="query-browser__autocomplete-match">{text.slice(i, i + sub.length)}</span>
+          <HighlightMatches text={text.slice(i + sub.length)} token={token.slice(sub.length)} />
+        </>
+      );
+    }
+  }
+  return <>{text}</>;
+};
+
 const QueryInput_: React.FC<QueryInputProps> = ({
   index,
   metrics,
@@ -371,6 +405,8 @@ const QueryInput_: React.FC<QueryInputProps> = ({
   runQueries,
   text = '',
 }) => {
+  const { t } = useTranslation();
+
   const [token, setToken] = React.useState('');
 
   const inputRef = React.useRef(null);
@@ -378,14 +414,17 @@ const QueryInput_: React.FC<QueryInputProps> = ({
   const getTextBeforeCursor = () =>
     inputRef.current.value.substring(0, inputRef.current.selectionEnd);
 
-  const onChange = (e: React.ChangeEvent<HTMLTextAreaElement>) => {
-    patchQuery({ text: e.target.value });
-
+  const updateToken = _.debounce(() => {
     // Metric and function names can only contain the characters a-z, A-Z, 0-9, '_' and ':'
     const allTokens = getTextBeforeCursor().split(/[^a-zA-Z0-9_:]+/);
 
     // We always do case insensitive autocompletion, so convert to lower case immediately
     setToken(_.toLower(_.last(allTokens)));
+  }, 200);
+
+  const onChange = (e: React.ChangeEvent<HTMLTextAreaElement>) => {
+    patchQuery({ text: e.target.value });
+    updateToken();
   };
 
   const onKeyDown = (e: React.KeyboardEvent) => {
@@ -448,6 +487,7 @@ const QueryInput_: React.FC<QueryInputProps> = ({
       ? {}
       : _.omitBy(
           {
+            ['Operators']: filterSuggestions(operators),
             ['Aggregation Operators']: filterSuggestions(aggregationOperators),
             ['Functions']: filterSuggestions(prometheusFunctions),
             ['Metrics']: filterSuggestions(metrics),
@@ -458,16 +498,18 @@ const QueryInput_: React.FC<QueryInputProps> = ({
   // Set the default textarea height to the number of lines in the query text
   const rows = _.clamp((text.match(/\n/g) || []).length + 1, 2, 10);
 
+  const placeholder = t('public~Expression (press Shift+Enter for newlines)');
+
   return (
     <div className="query-browser__query pf-c-dropdown">
       <textarea
-        aria-label="Expression (press Shift+Enter for newlines)"
+        aria-label={placeholder}
         autoFocus
         className="pf-c-form-control query-browser__query-input"
         onBlur={onBlur}
         onChange={onChange}
         onKeyDown={onKeyDown}
-        placeholder="Expression (press Shift+Enter for newlines)"
+        placeholder={placeholder}
         ref={inputRef}
         rows={rows}
         spellCheck={false}
@@ -475,7 +517,7 @@ const QueryInput_: React.FC<QueryInputProps> = ({
       />
       <Button
         className="query-browser__clear-icon"
-        aria-label="Clear Query"
+        aria-label={t('public~Clear query')}
         onClick={onClear}
         type="button"
         variant="plain"
@@ -495,7 +537,7 @@ const QueryInput_: React.FC<QueryInputProps> = ({
                     onMouseDown={onMouseDown}
                     type="button"
                   >
-                    {s}
+                    <HighlightMatches text={s} token={token} />
                   </button>
                 </li>
               ))}
@@ -523,6 +565,8 @@ const QueryKebab_: React.FC<QueryKebabProps> = ({
   series,
   toggleIsEnabled,
 }) => {
+  const { t } = useTranslation();
+
   const toggleAllSeries = () => patchQuery({ disabledSeries: isDisabledSeriesEmpty ? series : [] });
 
   const doDelete = () => {
@@ -533,12 +577,15 @@ const QueryKebab_: React.FC<QueryKebabProps> = ({
   return (
     <Kebab
       options={[
-        { label: `${isEnabled ? 'Disable' : 'Enable'} query`, callback: toggleIsEnabled },
         {
-          label: `${isDisabledSeriesEmpty ? 'Hide' : 'Show'} all series`,
+          label: isEnabled ? t('public~Disable query') : t('public~Enable query'),
+          callback: toggleIsEnabled,
+        },
+        {
+          label: isDisabledSeriesEmpty ? t('public~Hide all series') : t('public~Show all series'),
           callback: toggleAllSeries,
         },
-        { label: 'Delete query', callback: doDelete },
+        { label: t('public~Delete query'), callback: doDelete },
       ]}
     />
   );
@@ -557,6 +604,7 @@ const QueryKebab = connect(
 const queryTableStateToProps = ({ UI }: RootState, { index }) => ({
   isEnabled: UI.getIn(['queryBrowser', 'queries', index, 'isEnabled']),
   isExpanded: UI.getIn(['queryBrowser', 'queries', index, 'isExpanded']),
+  pollInterval: UI.getIn(['queryBrowser', 'pollInterval']),
   query: UI.getIn(['queryBrowser', 'queries', index, 'query']),
   series: UI.getIn(['queryBrowser', 'queries', index, 'series']),
 });
@@ -583,7 +631,6 @@ export const TablePagination = ({
 
   return (
     <Pagination
-      className="query-browser__pagination"
       itemCount={itemCount}
       onPerPageSelect={onPerPageSelect}
       onSetPage={(e, v) => setPage(v)}
@@ -600,11 +647,14 @@ const QueryTable_: React.FC<QueryTableProps> = ({
   isEnabled,
   isExpanded,
   namespace,
+  pollInterval = 15 * 1000,
   query,
   series,
 }) => {
+  const { t } = useTranslation();
+
   const [data, setData] = React.useState<PrometheusData>();
-  const [error, setError] = React.useState();
+  const [error, setError] = React.useState<PrometheusAPIError>();
   const [page, setPage] = React.useState(1);
   const [perPage, setPerPage] = React.useState(50);
   const [sortBy, setSortBy] = React.useState<ISortBy>();
@@ -612,7 +662,7 @@ const QueryTable_: React.FC<QueryTableProps> = ({
   const safeFetch = React.useCallback(useSafeFetch(), []);
 
   const tick = () => {
-    if (query) {
+    if (isEnabled && isExpanded && query) {
       safeFetch(getPrometheusURL({ endpoint: PrometheusEndpoint.QUERY, namespace, query }))
         .then((response) => {
           setData(_.get(response, 'data'));
@@ -627,7 +677,7 @@ const QueryTable_: React.FC<QueryTableProps> = ({
     }
   };
 
-  usePoll(tick, 15 * 1000, namespace, query);
+  usePoll(tick, pollInterval, namespace, query);
 
   React.useEffect(() => {
     setData(undefined);
@@ -656,21 +706,18 @@ const QueryTable_: React.FC<QueryTableProps> = ({
     );
   }
 
-  const { result, resultType } = data;
-
-  // Add any data series from `series` (those displayed in the graph) that are not already in `result`. This happens
-  // for filtering PromQL queries that exclude a series currently, but did not exclude that same series at some point
-  // during that graph's range.
-  _.each(series, (labels) => {
-    if (_.every(result, (r) => !_.isEqual(labels, r.metric))) {
-      result.push({ metric: labels });
-    }
-  });
+  // Add any data series from `series` (those displayed in the graph) that are not in `data.result`.
+  // This happens for queries that exclude a series currently, but included that same series at some
+  // point during the graph's range.
+  const expiredSeries = _.differenceWith(series, data.result, (s, r) => _.isEqual(s, r.metric));
+  const result = expiredSeries.length
+    ? [...data.result, ...expiredSeries.map((metric) => ({ metric }))]
+    : data.result;
 
   if (!result || result.length === 0) {
     return (
       <div className="query-browser__table-message">
-        <YellowExclamationTriangleIcon /> No datapoints found.
+        <YellowExclamationTriangleIcon /> {t('public~No datapoints found.')}
       </div>
     );
   }
@@ -680,14 +727,10 @@ const QueryTable_: React.FC<QueryTableProps> = ({
     transforms: [sortable, wrappable],
   };
 
-  // TableBody's shouldComponentUpdate seems to struggle with SeriesButton, so add a unique key to help TableBody
-  // determine when it should update
-  const buttonCell = (labels) => ({
-    title: <SeriesButton index={index} key={_.uniqueId()} labels={labels} />,
-  });
+  const buttonCell = (labels) => ({ title: <SeriesButton index={index} labels={labels} /> });
 
   let columns, rows;
-  if (resultType === 'scalar') {
+  if (data.resultType === 'scalar') {
     columns = ['', { title: 'Value', ...cellProps }];
     rows = [[buttonCell({}), _.get(result, '[1]')]];
   } else {
@@ -695,12 +738,15 @@ const QueryTable_: React.FC<QueryTableProps> = ({
 
     columns = [
       '',
-      ...allLabelKeys.map((k) => ({ title: k === '__name__' ? 'Name' : k, ...cellProps })),
+      ...allLabelKeys.map((k) => ({
+        title: <span>{k === '__name__' ? 'Name' : k}</span>,
+        ...cellProps,
+      })),
       { title: 'Value', ...cellProps },
     ];
 
     let rowMapper;
-    if (resultType === 'matrix') {
+    if (data.resultType === 'matrix') {
       rowMapper = ({ metric, values }) => [
         '',
         ..._.map(allLabelKeys, (k) => metric[k]),
@@ -739,38 +785,26 @@ const QueryTable_: React.FC<QueryTableProps> = ({
     }
   }
 
-  // Set the result table's break point based on the number of columns
-  let breakPoint: keyof typeof TableGridBreakpoint = 'grid';
-  if (columns.length <= 2) {
-    breakPoint = 'none';
-  } else if (columns.length <= 5) {
-    breakPoint = 'gridMd';
-  } else if (columns.length <= 8) {
-    breakPoint = 'gridLg';
-  } else if (columns.length <= 11) {
-    breakPoint = 'gridXl';
-  } else if (columns.length <= 14) {
-    breakPoint = 'grid2xl';
-  }
-
   const onSort = (e, i, direction) => setSortBy({ index: i, direction });
 
   const tableRows = rows.slice((page - 1) * perPage, page * perPage).map((cells) => ({ cells }));
 
   return (
     <>
-      <Table
-        aria-label="query results table"
-        cells={columns}
-        gridBreakPoint={TableGridBreakpoint[breakPoint]}
-        onSort={onSort}
-        rows={tableRows}
-        sortBy={sortBy}
-        variant={TableVariant.compact}
-      >
-        <TableHeader />
-        <TableBody />
-      </Table>
+      <div className="query-browser__table-wrapper">
+        <Table
+          aria-label="query results table"
+          cells={columns}
+          gridBreakPoint={TableGridBreakpoint.none}
+          onSort={onSort}
+          rows={tableRows}
+          sortBy={sortBy}
+          variant={TableVariant.compact}
+        >
+          <TableHeader />
+          <TableBody />
+        </Table>
+      </div>
       <TablePagination
         itemCount={rows.length}
         page={page}
@@ -783,35 +817,18 @@ const QueryTable_: React.FC<QueryTableProps> = ({
 };
 export const QueryTable = connect(queryTableStateToProps, queryDispatchToProps)(QueryTable_);
 
-const NamespaceAlert_: React.FC<{ dismiss: () => undefined; isDismissed: boolean }> = ({
-  dismiss,
-  isDismissed,
-}) =>
-  isDismissed ? null : (
-    <Alert
-      action={<AlertActionCloseButton onClose={dismiss} />}
-      isInline
-      className="co-alert"
-      title="Queries entered here are limited to the data available in the currently selected project."
-      variant="info"
-    />
-  );
-const NamespaceAlert: React.ComponentType<{}> = connect(
-  ({ UI }: RootState) => ({ isDismissed: !!UI.getIn(['queryBrowser', 'dismissNamespaceAlert']) }),
-  { dismiss: UIActions.queryBrowserDismissNamespaceAlert },
-)(NamespaceAlert_);
-
 const Query_: React.FC<QueryProps> = ({
   id,
   index,
   isExpanded,
   isEnabled,
-  namespace,
   patchQuery,
   toggleIsEnabled,
 }) => {
+  const { t } = useTranslation();
+
   const switchKey = `${id}-${isEnabled}`;
-  const switchLabel = `${isEnabled ? 'Disable' : 'Enable'} query`;
+  const switchLabel = isEnabled ? t('public~Disable query') : t('public~Enable query');
 
   const toggleIsExpanded = () => patchQuery({ isExpanded: !isExpanded });
 
@@ -823,7 +840,7 @@ const Query_: React.FC<QueryProps> = ({
     >
       <div className="query-browser__query-controls">
         <ExpandButton isExpanded={isExpanded} onClick={toggleIsExpanded} />
-        <QueryInput index={index} namespace={namespace} />
+        <QueryInput index={index} />
         <div title={switchLabel}>
           <Switch
             aria-label={switchLabel}
@@ -837,7 +854,7 @@ const Query_: React.FC<QueryProps> = ({
           <QueryKebab index={index} />
         </div>
       </div>
-      <QueryTable index={index} namespace={namespace} />
+      <QueryTable index={index} />
     </div>
   );
 };
@@ -851,10 +868,12 @@ const Query = connect(
 )(Query_);
 
 const QueryBrowserWrapper_: React.FC<QueryBrowserWrapperProps> = ({
-  namespace,
+  hideGraphs,
   patchQuery,
   queriesList,
 }) => {
+  const { t } = useTranslation();
+
   const queries = queriesList.toJS();
 
   // Initialize queries from URL parameters
@@ -886,70 +905,86 @@ const QueryBrowserWrapper_: React.FC<QueryBrowserWrapperProps> = ({
     setAllQueryArguments(newParams);
   }, [queryStrings]);
 
+  if (hideGraphs) {
+    return null;
+  }
+
   const insertExampleQuery = () => {
     const focusedIndex = focusedQuery?.index ?? 0;
     const index = queries[focusedIndex] ? focusedIndex : 0;
-
-    // Pick a suitable example query based on whether we are limiting results to a single namespace
-    const text = namespace
-      ? 'sum(rate(container_cpu_usage_seconds_total{image!="", container!="POD"}[5m])) by (pod)'
-      : 'sum(sort_desc(sum_over_time(ALERTS{alertstate="firing"}[24h]))) by (alertname)';
-
+    const text = 'sort_desc(sum(sum_over_time(ALERTS{alertstate="firing"}[24h])) by (alertname))';
     patchQuery(index, { isEnabled: true, query: text, text });
   };
 
-  return queryStrings.join('') === '' ? (
-    <div className="query-browser__wrapper graph-empty-state">
-      <EmptyState variant={EmptyStateVariant.full}>
-        <EmptyStateIcon size="sm" icon={ChartLineIcon} />
-        <Title size="sm">No Query Entered</Title>
-        <EmptyStateBody>
-          Enter a query in the box below to explore metrics for this cluster.
-        </EmptyStateBody>
-        <Button onClick={insertExampleQuery} variant="primary">
-          Insert Example Query
-        </Button>
-      </EmptyState>
-    </div>
-  ) : (
+  if (queryStrings.join('') === '') {
+    return (
+      <div className="query-browser__wrapper graph-empty-state">
+        <EmptyState variant={EmptyStateVariant.full}>
+          <EmptyStateIcon icon={ChartLineIcon} />
+          <Title headingLevel="h2" size="md">
+            {t('public~No query entered')}
+          </Title>
+          <EmptyStateBody>
+            {t('public~Enter a query in the box below to explore metrics for this cluster.')}
+          </EmptyStateBody>
+          <Button onClick={insertExampleQuery} variant="primary">
+            {t('public~Insert example query')}
+          </Button>
+        </EmptyState>
+      </div>
+    );
+  }
+
+  return (
     <QueryBrowser
       defaultTimespan={30 * 60 * 1000}
       disabledSeries={disabledSeries}
-      namespace={namespace}
       queries={queryStrings}
+      showStackedControl
     />
   );
 };
 const QueryBrowserWrapper = connect(
-  ({ UI }: RootState) => ({ queriesList: UI.getIn(['queryBrowser', 'queries']) }),
+  ({ UI }: RootState) => ({
+    hideGraphs: !!UI.getIn(['monitoring', 'hideGraphs']),
+    queriesList: UI.getIn(['queryBrowser', 'queries']),
+  }),
   { patchQuery: UIActions.queryBrowserPatchQuery },
 )(QueryBrowserWrapper_);
 
-const AddQueryButton_ = ({ addQuery }) => (
-  <Button
-    className="query-browser__inline-control"
-    onClick={addQuery}
-    type="button"
-    variant="secondary"
-  >
-    Add Query
-  </Button>
-);
+const AddQueryButton_ = ({ addQuery }) => {
+  const { t } = useTranslation();
+
+  return (
+    <Button
+      className="query-browser__inline-control"
+      onClick={addQuery}
+      type="button"
+      variant="secondary"
+    >
+      {t('public~Add query')}
+    </Button>
+  );
+};
 const AddQueryButton = connect(null, { addQuery: UIActions.queryBrowserAddQuery })(AddQueryButton_);
 
-const RunQueriesButton_ = ({ runQueries }) => (
-  <Button onClick={runQueries} type="submit" variant="primary">
-    Run Queries
-  </Button>
-);
+const RunQueriesButton_ = ({ runQueries }) => {
+  const { t } = useTranslation();
+
+  return (
+    <Button onClick={runQueries} type="submit" variant="primary">
+      {t('public~Run queries')}
+    </Button>
+  );
+};
 const RunQueriesButton = connect(null, { runQueries: UIActions.queryBrowserRunQueries })(
   RunQueriesButton_,
 );
 
-const QueriesList_ = ({ count, namespace }) => (
+const QueriesList_ = ({ count }) => (
   <>
     {_.range(count).map((i) => (
-      <Query index={i} key={i} namespace={namespace} />
+      <Query index={i} key={i} />
     ))}
   </>
 );
@@ -957,34 +992,39 @@ const QueriesList = connect(({ UI }: RootState) => ({
   count: UI.getIn(['queryBrowser', 'queries']).size,
 }))(QueriesList_);
 
-const TechPreview = () => (
-  <span className="query-browser__tech-preview">
-    <TechPreviewBadge />
-  </span>
-);
+const PollIntervalDropdown = connect(
+  ({ UI }: RootState) => ({
+    interval: UI.getIn(['queryBrowser', 'pollInterval']),
+  }),
+  {
+    setInterval: UIActions.queryBrowserSetPollInterval,
+  },
+)(IntervalDropdown);
+
+const QueryBrowserPage_: React.FC<QueryBrowserPageProps> = ({ deleteAll }) => {
+  const { t } = useTranslation();
 
-const QueryBrowserPage_: React.FC<QueryBrowserPageProps> = ({ deleteAll, namespace }) => {
   // Clear queries on unmount
   React.useEffect(() => deleteAll, [deleteAll]);
 
   return (
     <>
       <Helmet>
-        <title>Metrics</title>
+        <title>{t('public~Metrics')}</title>
       </Helmet>
       <div className="co-m-nav-title">
         <h1 className="co-m-pane__heading">
           <span>
-            Metrics
-            {namespace ? <TechPreview /> : <HeaderPrometheusLink />}
+            {t('public~Metrics')}
+            <HeaderPrometheusLink />
           </span>
           <div className="co-actions">
+            <PollIntervalDropdown />
             <MetricsActionsMenu />
           </div>
         </h1>
       </div>
       <div className="co-m-pane__body">
-        {namespace && <NamespaceAlert />}
         <div className="row">
           <div className="col-xs-12">
             <ToggleGraph />
@@ -992,10 +1032,10 @@ const QueryBrowserPage_: React.FC<QueryBrowserPageProps> = ({ deleteAll, namespa
         </div>
         <div className="row">
           <div className="col-xs-12">
-            <QueryBrowserWrapper namespace={namespace} />
+            <QueryBrowserWrapper />
             <div className="query-browser__controls">
               <div className="query-browser__controls--left">
-                <MetricsDropdown namespace={namespace} />
+                <MetricsDropdown />
               </div>
               <div className="query-browser__controls--right">
                 <ActionGroup className="pf-c-form pf-c-form__group--no-top-margin">
@@ -1004,14 +1044,14 @@ const QueryBrowserPage_: React.FC<QueryBrowserPageProps> = ({ deleteAll, namespa
                 </ActionGroup>
               </div>
             </div>
-            <QueriesList namespace={namespace} />
+            <QueriesList />
           </div>
         </div>
       </div>
     </>
   );
 };
-export const QueryBrowserPage: React.ComponentType<{ namespace?: string }> = withFallback(
+export const QueryBrowserPage = withFallback(
   connect(null, { deleteAll: UIActions.queryBrowserDeleteAllQueries })(QueryBrowserPage_),
 );
 
@@ -1028,17 +1068,15 @@ type MetricsDropdownItems = {
 
 type MetricsDropdownProps = {
   insertText: (index: number, newText: string, replaceFrom: number, replaceTo: number) => never;
-  namespace?: string;
   setMetrics: (metrics: string[]) => never;
 };
 
 type QueryBrowserPageProps = {
   deleteAll: () => never;
-  namespace?: string;
 };
 
 type QueryBrowserWrapperProps = {
-  namespace?: string;
+  hideGraphs: boolean;
   patchQuery: (index: number, patch: QueryObj) => any;
   queriesList: ImmutableList<QueryObj>;
 };
@@ -1065,7 +1103,6 @@ type QueryProps = {
   index: number;
   isEnabled: boolean;
   isExpanded: boolean;
-  namespace?: string;
   patchQuery: (patch: QueryObj) => void;
   toggleIsEnabled: () => never;
 };
@@ -1075,6 +1112,7 @@ type QueryTableProps = {
   isEnabled: boolean;
   isExpanded: boolean;
   namespace?: string;
+  pollInterval: number;
   query: string;
   series: PrometheusLabels[];
 };
