@@ -4,13 +4,21 @@ import { Link, LinkProps } from 'react-router-dom';
 import * as _ from 'lodash-es';
 import { NavItem } from '@patternfly/react-core';
 import { connect } from 'react-redux';
+import {
+  NavItem as PluginNavItem,
+  isNavItem,
+  isHrefNavItem,
+  isResourceNSNavItem,
+  isResourceClusterNavItem,
+} from '@console/plugin-sdk';
 import { formatNamespacedRouteForResource } from '@console/shared/src/utils';
 import { referenceForModel, K8sKind } from '../../module/k8s';
 import { stripBasePath } from '../utils';
-import * as plugins from '../../plugins';
 import { featureReducerName } from '../../reducers/features';
 import { RootState } from '../../redux';
 import { getActiveNamespace } from '../../reducers/ui';
+import { LAST_NAMESPACE_NAME_LOCAL_STORAGE_KEY } from '@console/shared/src/constants';
+import { ALL_NAMESPACES_KEY } from '@console/shared/src/constants/common';
 
 export const matchesPath = (resourcePath, prefix) =>
   resourcePath === prefix || _.startsWith(resourcePath, `${prefix}/`);
@@ -27,7 +35,13 @@ export const stripNS = (href) => {
 
 export const ExternalLink = ({ href, name }) => (
   <NavItem isActive={false}>
-    <a className="pf-c-nav__link" href={href} target="_blank" rel="noopener noreferrer">
+    <a
+      className="pf-c-nav__link"
+      href={href}
+      target="_blank"
+      rel="noopener noreferrer"
+      data-test="nav"
+    >
       {name}
       <span className="co-external-link" />
     </a>
@@ -54,7 +68,17 @@ class NavLink<P extends NavLinkProps> extends React.PureComponent<P> {
   }
 
   render() {
-    const { isActive, id, name, tipText, onClick, testID, children, className } = this.props;
+    const {
+      isActive,
+      name,
+      tipText,
+      onClick,
+      testID,
+      children,
+      className,
+      'data-tour-id': dataTourId,
+      'data-quickstart-id': dataQuickStartId,
+    } = this.props;
 
     // onClick is now handled globally by the Nav's onSelect,
     // however onClick can still be passed if desired in certain cases
@@ -65,11 +89,13 @@ class NavLink<P extends NavLinkProps> extends React.PureComponent<P> {
       <NavItem className={itemClasses} isActive={isActive}>
         <Link
           className={linkClasses}
-          id={id}
           data-test-id={testID}
           to={this.to}
           onClick={onClick}
           title={tipText}
+          data-tour-id={dataTourId}
+          data-quickstart-id={dataQuickStartId}
+          data-test="nav"
         >
           {name}
           {children}
@@ -87,7 +113,11 @@ export class ResourceNSLink extends NavLink<ResourceNSLinkProps> {
 
   get to() {
     const { resource, activeNamespace } = this.props;
-    return formatNamespacedRouteForResource(resource, activeNamespace);
+    const lastNamespace = sessionStorage.getItem(LAST_NAMESPACE_NAME_LOCAL_STORAGE_KEY);
+    return formatNamespacedRouteForResource(
+      resource,
+      lastNamespace === ALL_NAMESPACES_KEY ? lastNamespace : activeNamespace,
+    );
   }
 }
 
@@ -128,6 +158,8 @@ export type NavLinkProps = {
   activePath?: string;
   tipText?: string;
   testID?: string;
+  'data-tour-id'?: string;
+  'data-quickstart-id'?: string;
 };
 
 export type ResourceNSLinkProps = NavLinkProps & {
@@ -149,25 +181,26 @@ export type NavLinkComponent<T extends NavLinkProps = NavLinkProps> = React.Comp
   isActive: (props: T, resourcePath: string, activeNamespace: string) => boolean;
 };
 
-export const createLink = (item: plugins.NavItem, rootNavLink = false): React.ReactElement => {
-  if (plugins.isNavItem(item)) {
+export const createLink = (item: PluginNavItem, rootNavLink = false): React.ReactElement => {
+  if (isNavItem(item)) {
     let Component: NavLinkComponent = null;
-    if (plugins.isHrefNavItem(item)) {
+    if (isHrefNavItem(item)) {
       Component = HrefLink;
     }
-    if (plugins.isResourceNSNavItem(item)) {
+    if (isResourceNSNavItem(item)) {
       Component = ResourceNSLink;
     }
-    if (plugins.isResourceClusterNavItem(item)) {
+    if (isResourceClusterNavItem(item)) {
       Component = ResourceClusterLink;
     }
     if (Component) {
+      const { id } = item.properties;
       const key = item.properties.componentProps.name;
       const props = item.properties.componentProps;
       if (rootNavLink) {
-        return <RootNavLink {...props} key={key} component={Component} />;
+        return <RootNavLink id={id} {...props} key={key} component={Component} />;
       }
-      return <Component {...props} key={key} />;
+      return <Component id={id} {...props} key={key} />;
     }
   }
   return undefined;
