@@ -2,14 +2,24 @@ import * as React from 'react';
 // FIXME upgrading redux types is causing many errors at this time
 // eslint-disable-next-line @typescript-eslint/ban-ts-ignore
 // @ts-ignore
-import { connect, useSelector } from 'react-redux';
+import { connect } from 'react-redux';
 import { Link } from 'react-router-dom';
 import { sortable } from '@patternfly/react-table';
+import { useTranslation } from 'react-i18next';
+import i18next from 'i18next';
 import * as classNames from 'classnames';
 import * as _ from 'lodash-es';
-import { Status } from '@console/shared';
+import { Button, Popover } from '@patternfly/react-core';
+import { Status, TableColumnsType, useUserSettingsCompatibility } from '@console/shared';
 import { ByteDataTypes } from '@console/shared/src/graph-helper/data-utils';
-
+import {
+  withUserSettingsCompatibility,
+  WithUserSettingsCompatibilityProps,
+} from '@console/shared/src/hoc/withUserSettingsCompatibility';
+import {
+  COLUMN_MANAGEMENT_CONFIGMAP_KEY,
+  COLUMN_MANAGEMENT_LOCAL_STORAGE_KEY,
+} from '@console/shared/src/constants/common';
 import * as UIActions from '../actions/ui';
 import { coFetchJSON } from '../co-fetch';
 import { ContainerSpec, K8sResourceKindReference, PodKind, referenceForModel } from '../module/k8s';
@@ -42,7 +52,6 @@ import {
   humanizeDecimalBytesPerSec,
   humanizeCpuCores,
   navFactory,
-  pluralize,
   units,
   LabelList,
 } from './utils';
@@ -58,7 +67,6 @@ import {
 import { VolumesTable } from './volumes-table';
 import { PodModel } from '../models';
 import { Conditions } from './conditions';
-import { RootState } from '../redux';
 
 // Only request metrics if the device's screen width is larger than the
 // breakpoint where metrics are visible.
@@ -101,66 +109,79 @@ export const menuActions = [
   ...Kebab.factory.common,
 ];
 
+// t('public~Name')
+// t('public~Namespace')
+// t('public~Status')
+// t('public~Ready')
+// t('public~Restarts')
+// t('public~Owner')
+// t('public~Node')
+// t('public~Memory')
+// t('public~CPU')
+// t('public~Created')
+// t('public~Labels')
+// t('public~IP address')
+
 const podColumnInfo = Object.freeze({
   name: {
     classes: '',
     id: 'name',
-    title: 'Name',
+    title: 'public~Name',
   },
   namespace: {
     classes: '',
     id: 'namespace',
-    title: 'Namespace',
+    title: 'public~Namespace',
   },
   status: {
     classes: '',
     id: 'status',
-    title: 'Status',
+    title: 'public~Status',
   },
   ready: {
     classes: classNames('pf-m-nowrap', 'pf-u-w-10-on-lg', 'pf-u-w-8-on-xl'),
     id: 'ready',
-    title: 'Ready',
+    title: 'public~Ready',
   },
   restarts: {
     classes: classNames('pf-m-nowrap', 'pf-u-w-8-on-2xl'),
     id: 'restarts',
-    title: 'Restarts',
+    title: 'public~Restarts',
   },
   owner: {
     classes: '',
     id: 'owner',
-    title: 'Owner',
+    title: 'public~Owner',
   },
   node: {
     classes: '',
     id: 'node',
-    title: 'Node',
+    title: 'public~Node',
   },
   memory: {
     classes: classNames({ 'pf-u-w-10-on-2xl': showMetrics }),
     id: 'memory',
-    title: 'Memory',
+    title: 'public~Memory',
   },
   cpu: {
     classes: classNames({ 'pf-u-w-10-on-2xl': showMetrics }),
     id: 'cpu',
-    title: 'CPU',
+    title: 'public~CPU',
   },
   created: {
     classes: classNames('pf-u-w-10-on-2xl'),
     id: 'created',
-    title: 'Created',
+    title: 'public~Created',
   },
   labels: {
     classes: '',
     id: 'labels',
-    title: 'Labels',
+    title: 'public~Labels',
   },
   ipaddress: {
     classes: '',
     id: 'ipaddress',
-    title: 'IP Address',
+    title: 'public~IP address',
   },
 });
 
@@ -169,77 +190,78 @@ const columnManagementID = referenceForModel(PodModel);
 
 const podRowStateToProps = ({ UI }) => ({
   metrics: UI.getIn(['metrics', 'pod']),
-  selectedColumns: UI.getIn(['columnManagement']),
 });
 
 const getHeader = (showNodes) => {
   return () => {
     return [
       {
-        title: podColumnInfo.name.title,
+        title: i18next.t(podColumnInfo.name.title),
         id: podColumnInfo.name.id,
         sortField: 'metadata.name',
         transforms: [sortable],
         props: { className: podColumnInfo.name.classes },
       },
       {
-        title: podColumnInfo.namespace.title,
+        title: i18next.t(podColumnInfo.namespace.title),
         id: podColumnInfo.namespace.id,
         sortField: 'metadata.namespace',
         transforms: [sortable],
         props: { className: podColumnInfo.namespace.classes },
       },
       {
-        title: podColumnInfo.status.title,
+        title: i18next.t(podColumnInfo.status.title),
         id: podColumnInfo.status.id,
         sortFunc: 'podPhase',
         transforms: [sortable],
         props: { className: podColumnInfo.status.classes },
       },
       {
-        title: podColumnInfo.ready.title,
+        title: i18next.t(podColumnInfo.ready.title),
         id: podColumnInfo.ready.id,
         sortFunc: 'podReadiness',
         transforms: [sortable],
         props: { className: podColumnInfo.ready.classes },
       },
       {
-        title: podColumnInfo.restarts.title,
+        title: i18next.t(podColumnInfo.restarts.title),
         id: podColumnInfo.restarts.id,
         sortFunc: 'podRestarts',
         transforms: [sortable],
         props: { className: podColumnInfo.restarts.classes },
       },
       {
-        title: showNodes ? podColumnInfo.node.title : podColumnInfo.owner.title,
+        title: showNodes
+          ? i18next.t(podColumnInfo.node.title)
+          : i18next.t(podColumnInfo.owner.title),
         id: podColumnInfo.owner.id,
         sortField: showNodes ? 'spec.nodeName' : 'metadata.ownerReferences[0].name',
         transforms: [sortable],
         props: { className: podColumnInfo.owner.classes },
       },
       {
-        title: podColumnInfo.memory.title,
+        title: i18next.t(podColumnInfo.memory.title),
         id: podColumnInfo.memory.id,
         sortFunc: 'podMemory',
         transforms: [sortable],
         props: { className: podColumnInfo.memory.classes },
       },
       {
-        title: podColumnInfo.cpu.title,
+        title: i18next.t(podColumnInfo.cpu.title),
         id: podColumnInfo.cpu.id,
         sortFunc: 'podCPU',
         transforms: [sortable],
         props: { className: podColumnInfo.cpu.classes },
       },
       {
-        title: podColumnInfo.created.title,
+        title: i18next.t(podColumnInfo.created.title),
         id: podColumnInfo.created.id,
         sortField: 'metadata.creationTimestamp',
         transforms: [sortable],
         props: { className: podColumnInfo.created.classes },
       },
       {
-        title: podColumnInfo.node.title,
+        title: i18next.t(podColumnInfo.node.title),
         id: podColumnInfo.node.id,
         sortField: 'spec.nodeName',
         transforms: [sortable],
@@ -247,7 +269,7 @@ const getHeader = (showNodes) => {
         additional: true,
       },
       {
-        title: podColumnInfo.labels.title,
+        title: i18next.t(podColumnInfo.labels.title),
         id: podColumnInfo.labels.id,
         sortField: 'metadata.labels',
         transforms: [sortable],
@@ -255,7 +277,7 @@ const getHeader = (showNodes) => {
         additional: true,
       },
       {
-        title: podColumnInfo.ipaddress.title,
+        title: i18next.t(podColumnInfo.ipaddress.title),
         id: podColumnInfo.ipaddress.id,
         sortField: 'status.hostIP',
         transforms: [sortable],
@@ -289,17 +311,23 @@ const PodTableRow = connect<PodTableRowPropsFromState, null, PodTableRowProps>(p
     style,
     metrics,
     showNodes,
-    selectedColumns,
   }: PodTableRowProps & PodTableRowPropsFromState) => {
+    const [tableColumns, , loaded] = useUserSettingsCompatibility(
+      COLUMN_MANAGEMENT_CONFIGMAP_KEY,
+      COLUMN_MANAGEMENT_LOCAL_STORAGE_KEY,
+      undefined,
+      true,
+    );
     const { name, namespace, creationTimestamp, labels } = pod.metadata;
     const { readyCount, totalContainers } = podReadiness(pod);
     const phase = podPhase(pod);
     const restarts = podRestarts(pod);
     const bytes: number = _.get(metrics, ['memory', namespace, name]);
     const cores: number = _.get(metrics, ['cpu', namespace, name]);
-    const columns = new Set(
-      selectedColumns?.get(columnManagementID) || getSelectedColumns(showNodes),
-    );
+    const columns: Set<string> =
+      loaded && tableColumns?.[columnManagementID]?.length > 0
+        ? new Set(tableColumns[columnManagementID])
+        : getSelectedColumns(showNodes);
     return (
       <TableRow id={pod.metadata.uid} index={index} trKey={rowKey} style={style}>
         <TableData className={podColumnInfo.name.classes}>
@@ -317,7 +345,7 @@ const PodTableRow = connect<PodTableRowPropsFromState, null, PodTableRowProps>(p
           columns={columns}
           columnID={podColumnInfo.status.id}
         >
-          <Status status={phase} />
+          <PodStatus pod={pod} />
         </TableData>
         <TableData
           className={podColumnInfo.ready.classes}
@@ -445,109 +473,188 @@ export const PodContainerTable: React.FC<PodContainerTableProps> = ({
   heading,
   containers,
   pod,
-}) => (
-  <>
-    <SectionHeading text={heading} />
-    <div className="co-m-table-grid co-m-table-grid--bordered">
-      <div className="row co-m-table-grid__head">
-        <div className="col-lg-2 col-md-3 col-sm-4 col-xs-5">Name</div>
-        <div className="col-lg-2 col-md-3 col-sm-5 col-xs-7">Image</div>
-        <div className="col-lg-2 col-md-2 col-sm-3 hidden-xs">State</div>
-        <div className="col-lg-1 col-md-2 hidden-sm hidden-xs">Restarts</div>
-        <div className="col-lg-2 col-md-2 hidden-sm hidden-xs">Started</div>
-        <div className="col-lg-2 hidden-md hidden-sm hidden-xs">Finished</div>
-        <div className="col-lg-1 hidden-md hidden-sm hidden-xs">Exit Code</div>
+}) => {
+  const { t } = useTranslation();
+  return (
+    <>
+      <SectionHeading text={heading} />
+      <div className="co-m-table-grid co-m-table-grid--bordered">
+        <div className="row co-m-table-grid__head">
+          <div className="col-lg-2 col-md-3 col-sm-4 col-xs-5">{t('public~Name')}</div>
+          <div className="col-lg-2 col-md-3 col-sm-5 col-xs-7">{t('public~Image')}</div>
+          <div className="col-lg-2 col-md-2 col-sm-3 hidden-xs">{t('public~State')}</div>
+          <div className="col-lg-1 col-md-2 hidden-sm hidden-xs">{t('public~Restarts')}</div>
+          <div className="col-lg-2 col-md-2 hidden-sm hidden-xs">{t('public~Started')}</div>
+          <div className="col-lg-2 hidden-md hidden-sm hidden-xs">{t('public~Finished')}</div>
+          <div className="col-lg-1 hidden-md hidden-sm hidden-xs">{t('public~Exit code')}</div>
+        </div>
+        <div className="co-m-table-grid__body">
+          {containers.map((c: any, i: number) => (
+            <ContainerRow key={i} pod={pod} container={c} />
+          ))}
+        </div>
       </div>
-      <div className="co-m-table-grid__body">
-        {containers.map((c: any, i: number) => (
-          <ContainerRow key={i} pod={pod} container={c} />
-        ))}
-      </div>
-    </div>
-  </>
-);
+    </>
+  );
+};
 
 const getNetworkName = (result: PrometheusResult) =>
   // eslint-disable-next-line camelcase
   result?.metric?.network_name || 'unnamed interface';
 
-const PodGraphs = requirePrometheus(({ pod }) => (
-  <>
-    <div className="row">
-      <div className="col-md-12 col-lg-4">
-        <Area
-          title="Memory Usage"
-          humanize={humanizeBinaryBytes}
-          byteDataType={ByteDataTypes.BinaryBytes}
-          namespace={pod.metadata.namespace}
-          query={`sum(container_memory_working_set_bytes{pod='${pod.metadata.name}',namespace='${pod.metadata.namespace}',container='',}) BY (pod, namespace)`}
-          limitQuery={`sum(kube_pod_container_resource_limits_memory_bytes{pod='${pod.metadata.name}',namespace='${pod.metadata.namespace}'}) BY (pod, namespace)`}
-          requestedQuery={`sum(kube_pod_container_resource_requests_memory_bytes{pod='${pod.metadata.name}',namespace='${pod.metadata.namespace}'}) BY (pod, namespace)`}
-        />
+const PodGraphs = requirePrometheus(({ pod }) => {
+  const { t } = useTranslation();
+  const chartTitles = {
+    memory: t('public~Memory usage'),
+    cpu: t('public~CPU usage'),
+    fs: t('public~Filesystem'),
+    networkIn: t('public~Network in'),
+    networkOut: t('public~Network out'),
+  };
+  return (
+    <>
+      <div className="row">
+        <div className="col-md-12 col-lg-4">
+          <Area
+            title={chartTitles.memory}
+            ariaChartLinkLabel={t('public~View {{title}} metrics in query browser', {
+              title: chartTitles.memory,
+            })}
+            humanize={humanizeBinaryBytes}
+            byteDataType={ByteDataTypes.BinaryBytes}
+            namespace={pod.metadata.namespace}
+            query={`sum(container_memory_working_set_bytes{pod='${pod.metadata.name}',namespace='${pod.metadata.namespace}',container='',}) BY (pod, namespace)`}
+            limitQuery={`sum(label_replace(label_replace(kube_pod_resource_limit{resource='cpu',exported_pod='${pod.metadata.name}',exported_namespace='${pod.metadata.namespace}'},'pod','$1','exported_pod','(.+)'),'namespace','$1','exported_namespace','(.+)'))`}
+            requestedQuery={`sum(label_replace(label_replace(kube_pod_resource_request{resource='memory',exported_pod='${pod.metadata.name}',exported_namespace='${pod.metadata.namespace}'},'pod','$1','exported_pod','(.+)'),'namespace','$1','exported_namespace','(.+)')) BY (pod, namespace)`}
+          />
+        </div>
+        <div className="col-md-12 col-lg-4">
+          <Area
+            title={chartTitles.cpu}
+            ariaChartLinkLabel={t('public~View {{title}} metrics in query browser', {
+              title: chartTitles.cpu,
+            })}
+            humanize={humanizeCpuCores}
+            namespace={pod.metadata.namespace}
+            query={`pod:container_cpu_usage:sum{pod='${pod.metadata.name}',namespace='${pod.metadata.namespace}'}`}
+            limitQuery={`sum(label_replace(label_replace(kube_pod_resource_limit{resource='cpu',exported_pod='${pod.metadata.name}',exported_namespace='${pod.metadata.namespace}'},'pod','$1','exported_pod','(.+)'),'namespace','$1','exported_namespace','(.+)'))`}
+            requestedQuery={`sum(label_replace(label_replace(kube_pod_resource_request{resource='cpu',exported_pod='${pod.metadata.name}',exported_namespace='${pod.metadata.namespace}'},'pod','$1','exported_pod','(.+)'),'namespace','$1','exported_namespace','(.+)')) BY (pod, namespace)`}
+          />
+        </div>
+        <div className="col-md-12 col-lg-4">
+          <Area
+            title={chartTitles.fs}
+            ariaChartLinkLabel={t('public~View {{title}} metrics in query browser', {
+              title: chartTitles.fs,
+            })}
+            humanize={humanizeBinaryBytes}
+            byteDataType={ByteDataTypes.BinaryBytes}
+            namespace={pod.metadata.namespace}
+            query={`pod:container_fs_usage_bytes:sum{pod='${pod.metadata.name}',namespace='${pod.metadata.namespace}'}`}
+          />
+        </div>
       </div>
-      <div className="col-md-12 col-lg-4">
-        <Area
-          title="CPU Usage"
-          humanize={humanizeCpuCores}
-          namespace={pod.metadata.namespace}
-          query={`pod:container_cpu_usage:sum{pod='${pod.metadata.name}',namespace='${pod.metadata.namespace}'}`}
-          limitQuery={`sum(kube_pod_container_resource_limits_cpu_cores{pod='${pod.metadata.name}',namespace='${pod.metadata.namespace}'}) BY (pod, namespace)`}
-          requestedQuery={`sum(kube_pod_container_resource_requests_cpu_cores{pod='${pod.metadata.name}',namespace='${pod.metadata.namespace}'}) BY (pod, namespace)`}
-        />
+      <div className="row">
+        <div className="col-md-12 col-lg-4">
+          <Stack
+            title={chartTitles.networkIn}
+            ariaChartLinkLabel={t('public~View {{title}} metrics in query browser', {
+              title: chartTitles.networkIn,
+            })}
+            humanize={humanizeDecimalBytesPerSec}
+            namespace={pod.metadata.namespace}
+            query={`(sum(irate(container_network_receive_bytes_total{pod='${pod.metadata.name}', namespace='${pod.metadata.namespace}'}[5m])) by (pod, namespace, interface)) + on(namespace,pod,interface) group_left(network_name) ( pod_network_name_info )`}
+            description={getNetworkName}
+          />
+        </div>
+        <div className="col-md-12 col-lg-4">
+          <Stack
+            title={chartTitles.networkOut}
+            ariaChartLinkLabel={t('public~View {{title}} metrics in query browser', {
+              title: chartTitles.networkOut,
+            })}
+            humanize={humanizeDecimalBytesPerSec}
+            namespace={pod.metadata.namespace}
+            query={`(sum(irate(container_network_transmit_bytes_total{pod='${pod.metadata.name}', namespace='${pod.metadata.namespace}'}[5m])) by (pod, namespace, interface)) + on(namespace,pod,interface) group_left(network_name) ( pod_network_name_info )`}
+            description={getNetworkName}
+          />
+        </div>
       </div>
-      <div className="col-md-12 col-lg-4">
-        <Area
-          title="Filesystem"
-          humanize={humanizeBinaryBytes}
-          byteDataType={ByteDataTypes.BinaryBytes}
-          namespace={pod.metadata.namespace}
-          query={`pod:container_fs_usage_bytes:sum{pod='${pod.metadata.name}',namespace='${pod.metadata.namespace}'}`}
-        />
-      </div>
-    </div>
-    <div className="row">
-      <div className="col-md-12 col-lg-4">
-        <Stack
-          title="Network In"
-          humanize={humanizeDecimalBytesPerSec}
-          namespace={pod.metadata.namespace}
-          query={`(sum(irate(container_network_receive_bytes_total{pod='${pod.metadata.name}', namespace='${pod.metadata.namespace}'}[5m])) by (pod, namespace, interface)) + on(namespace,pod,interface) group_left(network_name) ( pod_network_name_info )`}
-          description={getNetworkName}
-        />
-      </div>
-      <div className="col-md-12 col-lg-4">
-        <Stack
-          title="Network Out"
-          humanize={humanizeDecimalBytesPerSec}
-          namespace={pod.metadata.namespace}
-          query={`(sum(irate(container_network_transmit_bytes_total{pod='${pod.metadata.name}', namespace='${pod.metadata.namespace}'}[5m])) by (pod, namespace, interface)) + on(namespace,pod,interface) group_left(network_name) ( pod_network_name_info )`}
-          description={getNetworkName}
-        />
-      </div>
-    </div>
-    <br />
-  </>
-));
+      <br />
+    </>
+  );
+});
 
-export const PodStatus: React.FC<PodStatusProps> = ({ pod }) => <Status status={podPhase(pod)} />;
+const PodStatusPopover: React.FC<PodStatusPopoverProps> = ({
+  bodyContent,
+  headerContent,
+  status,
+}) => {
+  return (
+    <Popover headerContent={headerContent} bodyContent={bodyContent}>
+      <Button variant="link" isInline>
+        <Status status={status} />
+      </Button>
+    </Popover>
+  );
+};
+
+export const PodStatus: React.FC<PodStatusProps> = ({ pod }) => {
+  const status = podPhase(pod);
+  const unschedulableCondition = pod.status?.conditions?.find(
+    (condition) => condition.reason === 'Unschedulable' && condition.status === 'False',
+  );
+  const containerStatusStateWaiting = pod.status?.containerStatuses?.find(
+    (cs) => cs.state?.waiting,
+  );
+  const { t } = useTranslation();
+
+  if (status === 'Pending' && unschedulableCondition) {
+    return (
+      <PodStatusPopover
+        bodyContent={unschedulableCondition.message}
+        headerContent={t('public~Pod unschedulable')}
+        status={status}
+      />
+    );
+  }
+  if (
+    (status === 'CrashLoopBackOff' || status === 'ErrImagePull' || status === 'ImagePullBackOff') &&
+    containerStatusStateWaiting
+  ) {
+    return (
+      <PodStatusPopover
+        bodyContent={containerStatusStateWaiting.state.waiting.message}
+        status={status}
+      />
+    );
+  }
+
+  return <Status status={status} />;
+};
 
 export const PodDetailsList: React.FC<PodDetailsListProps> = ({ pod }) => {
+  const { t } = useTranslation();
   return (
     <dl className="co-m-pane__details">
-      <dt>Status</dt>
+      <dt>{t('public~Status')}</dt>
       <dd>
         <PodStatus pod={pod} />
       </dd>
-      <DetailsItem label="Restart Policy" obj={pod} path="spec.restartPolicy">
+      <DetailsItem label={t('public~Restart policy')} obj={pod} path="spec.restartPolicy">
         {getRestartPolicyLabel(pod)}
       </DetailsItem>
-      <DetailsItem label="Active Deadline Seconds" obj={pod} path="spec.activeDeadlineSeconds">
+      <DetailsItem
+        label={t('public~Active deadline seconds')}
+        obj={pod}
+        path="spec.activeDeadlineSeconds"
+      >
         {pod.spec.activeDeadlineSeconds
-          ? pluralize(pod.spec.activeDeadlineSeconds, 'second')
-          : 'Not Configured'}
+          ? t('public~{{count}} second', { count: pod.spec.activeDeadlineSeconds })
+          : t('public~Not configured')}
       </DetailsItem>
-      <DetailsItem label="Pod IP" obj={pod} path="status.podIP" />
-      <DetailsItem label="Node" obj={pod} path="spec.nodeName" hideEmpty>
+      <DetailsItem label={t('public~Pod IP')} obj={pod} path="status.podIP" />
+      <DetailsItem label={t('public~Node')} obj={pod} path="spec.nodeName" hideEmpty>
         <NodeLink name={pod.spec.nodeName} />
       </DetailsItem>
     </dl>
@@ -587,12 +694,12 @@ const Details: React.FC<PodDetailsProps> = ({ obj: pod }) => {
     },
     0,
   );
-
+  const { t } = useTranslation();
   return (
     <>
       <ScrollToTopOnMount />
       <div className="co-m-pane__body">
-        <SectionHeading text="Pod Details" />
+        <SectionHeading text={t('public~Pod details')} />
         <PodGraphs pod={pod} />
         <div className="row">
           <div className="col-sm-6">
@@ -607,7 +714,7 @@ const Details: React.FC<PodDetailsProps> = ({ obj: pod }) => {
         <div className="co-m-pane__body">
           <PodContainerTable
             key="initContainerTable"
-            heading="Init Containers"
+            heading={t('public~Init containers')}
             containers={pod.spec.initContainers}
             pod={pod}
           />
@@ -616,16 +723,16 @@ const Details: React.FC<PodDetailsProps> = ({ obj: pod }) => {
       <div className="co-m-pane__body">
         <PodContainerTable
           key="containerTable"
-          heading="Containers"
+          heading={t('public~Containers')}
           containers={pod.spec.containers}
           pod={pod}
         />
       </div>
       <div className="co-m-pane__body">
-        <VolumesTable resource={pod} heading="Volumes" />
+        <VolumesTable resource={pod} heading={t('public~Volumes')} />
       </div>
       <div className="co-m-pane__body">
-        <SectionHeading text="Conditions" />
+        <SectionHeading text={t('public~Conditions')} />
         <Conditions conditions={pod.status.conditions} />
       </div>
     </>
@@ -660,25 +767,28 @@ export const PodExecLoader: React.FC<PodExecLoaderProps> = ({ obj, message }) =>
   </div>
 );
 
-export const PodsDetailsPage: React.FC<PodDetailsPageProps> = (props) => (
-  <DetailsPage
-    {...props}
-    getResourceStatus={podPhase}
-    menuActions={menuActions}
-    pages={[
-      navFactory.details(Details),
-      navFactory.editYaml(),
-      navFactory.envEditor(PodEnvironmentComponent),
-      navFactory.logs(PodLogs),
-      navFactory.events(ResourceEventStream),
-      {
-        href: 'terminal',
-        name: 'Terminal',
-        component: PodExecLoader,
-      },
-    ]}
-  />
-);
+export const PodsDetailsPage: React.FC<PodDetailsPageProps> = (props) => {
+  // t('details-page~Terminal')
+  return (
+    <DetailsPage
+      {...props}
+      getResourceStatus={podPhase}
+      menuActions={menuActions}
+      pages={[
+        navFactory.details(Details),
+        navFactory.editYaml(),
+        navFactory.envEditor(PodEnvironmentComponent),
+        navFactory.logs(PodLogs),
+        navFactory.events(ResourceEventStream),
+        {
+          href: 'terminal',
+          nameKey: 'details-page~Terminal',
+          component: PodExecLoader,
+        },
+      ]}
+    />
+  );
+};
 PodsDetailsPage.displayName = 'PodsDetailsPage';
 
 const getRow = (showNodes) => {
@@ -693,19 +803,33 @@ const getRow = (showNodes) => {
   );
 };
 
-export const PodList: React.FC<PodListProps> = (props) => {
+export const PodList: React.FC<PodListProps> = withUserSettingsCompatibility<
+  PodListProps & WithUserSettingsCompatibilityProps<TableColumnsType>,
+  TableColumnsType
+>(
+  COLUMN_MANAGEMENT_CONFIGMAP_KEY,
+  COLUMN_MANAGEMENT_LOCAL_STORAGE_KEY,
+  undefined,
+  true,
+)(({ userSettingState: tableColumns, ...props }) => {
   const showNodes = props?.customData?.showNodes;
+  const { t } = useTranslation();
+  const selectedColumns: Set<string> =
+    tableColumns?.[columnManagementID]?.length > 0
+      ? new Set(tableColumns[columnManagementID])
+      : null;
   return (
     <Table
       {...props}
+      activeColumns={selectedColumns}
       columnManagementID={columnManagementID}
-      aria-label="Pods"
+      aria-label={t('public~Pods')}
       Header={getHeader(showNodes)}
       Row={getRow(showNodes)}
       virtualize
     />
   );
-};
+});
 PodList.displayName = 'PodList';
 
 export const filters = [
@@ -734,51 +858,75 @@ const dispatchToProps = (dispatch): PodPagePropsFromDispatch => ({
 export const PodsPage = connect<{}, PodPagePropsFromDispatch, PodPageProps>(
   null,
   dispatchToProps,
-)((props: PodPageProps & PodPagePropsFromDispatch) => {
-  const { canCreate = true, namespace, setPodMetrics, customData, ...listProps } = props;
-  const selectedColumns: Set<string> = new Set(
-    useSelector<RootState, string>(({ UI }) => UI.getIn(['columnManagement', columnManagementID])),
-  );
-  /* eslint-disable react-hooks/exhaustive-deps */
-  React.useEffect(() => {
-    if (showMetrics) {
-      const updateMetrics = () =>
-        fetchPodMetrics(namespace)
-          .then(setPodMetrics)
-          .catch((e) => {
-            // Just log the error here. Showing a warning alert could be more annoying
-            // than helpful. It should be obvious there are no metrics in the list, and
-            // if monitoring is broken, it'll be really apparent since none of the
-            // graphs and dashboards will load in the UI.
-            // eslint-disable-next-line no-console
-            console.error('Unable to fetch pod metrics', e);
-          });
-      updateMetrics();
-      const id = setInterval(updateMetrics, 30 * 1000);
-      return () => clearInterval(id);
-    }
-  }, [namespace]);
-  /* eslint-enable react-hooks/exhaustive-deps */
-  return (
-    <ListPage
-      {...listProps}
-      canCreate={canCreate}
-      kind={kind}
-      ListComponent={PodList}
-      rowFilters={filters}
-      namespace={namespace}
-      customData={customData}
-      columnLayout={{
-        columns: getHeader(props?.customData?.showNodes)().map((column) =>
-          _.pick(column, ['title', 'additional', 'id']),
-        ),
-        id: columnManagementID,
-        selectedColumns,
-        type: 'Pod',
-      }}
-    />
-  );
-});
+)(
+  withUserSettingsCompatibility<
+    PodPagePropsFromDispatch & PodPageProps & WithUserSettingsCompatibilityProps<TableColumnsType>,
+    TableColumnsType
+  >(
+    COLUMN_MANAGEMENT_CONFIGMAP_KEY,
+    COLUMN_MANAGEMENT_LOCAL_STORAGE_KEY,
+    undefined,
+    true,
+  )(
+    (
+      props: PodPageProps &
+        PodPagePropsFromDispatch &
+        WithUserSettingsCompatibilityProps<TableColumnsType>,
+    ) => {
+      const {
+        canCreate = true,
+        namespace,
+        setPodMetrics,
+        customData,
+        userSettingState: tableColumns,
+        ...listProps
+      } = props;
+      const { t } = useTranslation();
+      /* eslint-disable react-hooks/exhaustive-deps */
+      React.useEffect(() => {
+        if (showMetrics) {
+          const updateMetrics = () =>
+            fetchPodMetrics(namespace)
+              .then(setPodMetrics)
+              .catch((e) => {
+                // Just log the error here. Showing a warning alert could be more annoying
+                // than helpful. It should be obvious there are no metrics in the list, and
+                // if monitoring is broken, it'll be really apparent since none of the
+                // graphs and dashboards will load in the UI.
+                // eslint-disable-next-line no-console
+                console.error('Unable to fetch pod metrics', e);
+              });
+          updateMetrics();
+          const id = setInterval(updateMetrics, 30 * 1000);
+          return () => clearInterval(id);
+        }
+      }, [namespace]);
+      /* eslint-enable react-hooks/exhaustive-deps */
+      return (
+        <ListPage
+          {...listProps}
+          canCreate={canCreate}
+          kind={kind}
+          ListComponent={PodList}
+          rowFilters={filters}
+          namespace={namespace}
+          customData={customData}
+          columnLayout={{
+            columns: getHeader(props?.customData?.showNodes)().map((column) =>
+              _.pick(column, ['title', 'additional', 'id']),
+            ),
+            id: columnManagementID,
+            selectedColumns:
+              tableColumns?.[columnManagementID]?.length > 0
+                ? new Set(tableColumns[columnManagementID])
+                : null,
+            type: t('public~Pod'),
+          }}
+        />
+      );
+    },
+  ),
+);
 
 type ContainerLinkProps = {
   pod: PodKind;
@@ -796,6 +944,12 @@ type PodContainerTableProps = {
   pod: PodKind;
 };
 
+type PodStatusPopoverProps = {
+  bodyContent: string;
+  headerContent?: string;
+  status: string;
+};
+
 type PodStatusProps = {
   pod: PodKind;
 };
@@ -827,7 +981,6 @@ type PodTableRowProps = {
 
 type PodTableRowPropsFromState = {
   metrics: UIActions.PodMetrics;
-  selectedColumns: Map<string, Set<string>>;
 };
 
 type PodListProps = {
