@@ -1,4 +1,5 @@
 import { Map as ImmutableMap } from 'immutable';
+import { ResourceDetailsPage, ResourcePage, ResourceListPage } from '@console/plugin-sdk';
 
 import { ReportReference, ReportGenerationQueryReference } from './chargeback';
 import { referenceForModel, GroupVersionKind } from '../module/k8s';
@@ -30,7 +31,6 @@ import {
   MachineAutoscalerModel,
   MachineConfigModel,
   MachineConfigPoolModel,
-  MachineDeploymentModel,
   MachineHealthCheckModel,
   MachineModel,
   MachineSetModel,
@@ -59,13 +59,13 @@ import {
   StorageClassModel,
   TemplateInstanceModel,
   UserModel,
+  VolumeSnapshotModel,
+  VolumeSnapshotClassModel,
 } from '../models';
 
-import * as plugins from '../plugins';
-
 const addResourcePage = (
   map: ImmutableMap<ResourceMapKey, ResourceMapValue>,
-  page: plugins.ResourcePage,
+  page: ResourcePage,
 ) => {
   const key = page.properties?.modelParser
     ? page.properties?.modelParser(page.properties.model)
@@ -178,11 +178,6 @@ export const baseDetailsPages = ImmutableMap<ResourceMapKey, ResourceMapValue>()
       (m) => m.MachineSetDetailsPage,
     ),
   )
-  .set(referenceForModel(MachineDeploymentModel), () =>
-    import('./machine-deployment' /* webpackChunkName: "machine-deployment" */).then(
-      (m) => m.MachineDeploymentDetailsPage,
-    ),
-  )
   .set(referenceForModel(MachineHealthCheckModel), () =>
     import('./machine-health-check' /* webpackChunkName: "machine-health-check" */).then(
       (m) => m.MachineHealthCheckDetailsPage,
@@ -317,15 +312,26 @@ export const baseDetailsPages = ImmutableMap<ResourceMapKey, ResourceMapValue>()
     import('./cluster-settings/oauth' /* webpackChunkName: "oauth" */).then(
       (m) => m.OAuthDetailsPage,
     ),
+  )
+  .set(referenceForModel(VolumeSnapshotModel), () =>
+    import(
+      '@console/app/src/components/volume-snapshot/volume-snapshot-details' /* webpackChunkName: "volume-snapshot-details" */
+    ).then((m) => m.default),
+  )
+  .set(referenceForModel(VolumeSnapshotClassModel), () =>
+    import(
+      '@console/app/src/components/volume-snapshot/volume-snapshot-class-details' /* webpackChunkName: "volume-snapshot-class-details" */
+    ).then((m) => m.default),
   );
 
-export const resourceDetailsPages = ImmutableMap<ResourceMapKey, ResourceMapValue>()
-  .merge(baseDetailsPages)
-  .withMutations((map) => {
-    plugins.registry.getResourceDetailsPages().forEach((page) => {
-      addResourcePage(map, page);
+export const getResourceDetailsPages = (pluginPages: ResourceDetailsPage[] = []) =>
+  ImmutableMap<ResourceMapKey, ResourceMapValue>()
+    .merge(baseDetailsPages)
+    .withMutations((map) => {
+      pluginPages.forEach((page) => {
+        addResourcePage(map, page);
+      });
     });
-  });
 
 export const baseListPages = ImmutableMap<ResourceMapKey, ResourceMapValue>()
   .set(referenceForModel(ClusterServiceClassModel), () =>
@@ -406,11 +412,6 @@ export const baseListPages = ImmutableMap<ResourceMapKey, ResourceMapValue>()
   .set(referenceForModel(MachineModel), () =>
     import('./machine' /* webpackChunkName: "machine" */).then((m) => m.MachinePage),
   )
-  .set(referenceForModel(MachineDeploymentModel), () =>
-    import('./machine-deployment' /* webpackChunkName: "machine-deployment" */).then(
-      (m) => m.MachineDeploymentPage,
-    ),
-  )
   .set(referenceForModel(MachineHealthCheckModel), () =>
     import('./machine-health-check' /* webpackChunkName: "machine-health-check" */).then(
       (m) => m.MachineHealthCheckPage,
@@ -535,12 +536,23 @@ export const baseListPages = ImmutableMap<ResourceMapKey, ResourceMapValue>()
     import('./cluster-settings/cluster-operator' /* webpackChunkName: "cluster-operator" */).then(
       (m) => m.ClusterOperatorPage,
     ),
+  )
+  .set(referenceForModel(VolumeSnapshotModel), () =>
+    import(
+      '@console/app/src/components/volume-snapshot/volume-snapshot' /* webpackChunkName: "volume-snapshot" */
+    ).then((m) => m.default),
+  )
+  .set(referenceForModel(VolumeSnapshotClassModel), () =>
+    import(
+      '@console/app/src/components/volume-snapshot/volume-snapshot-class' /* webpackChunkName: "volume-snapshot-class" */
+    ).then((m) => m.default),
   );
 
-export const resourceListPages = ImmutableMap<ResourceMapKey, ResourceMapValue>()
-  .merge(baseListPages)
-  .withMutations((map) => {
-    plugins.registry.getResourceListPages().forEach((page) => {
-      addResourcePage(map, page);
+export const getResourceListPages = (pluginPages: ResourceListPage[] = []) =>
+  ImmutableMap<ResourceMapKey, ResourceMapValue>()
+    .merge(baseListPages)
+    .withMutations((map) => {
+      pluginPages.forEach((page) => {
+        addResourcePage(map, page);
+      });
     });
-  });
